package cn.bertsir.zbar;

import android.content.Context;
import android.hardware.Camera;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import cn.bertsir.zbar.Qr.Image;
import cn.bertsir.zbar.Qr.ImageScanner;
import cn.bertsir.zbar.Qr.Symbol;
import cn.bertsir.zbar.utils.QRUtils;
import com.google.zxing.BinaryBitmap;
import com.google.zxing.NotFoundException;
import com.google.zxing.PlanarYUVLuminanceSource;
import com.google.zxing.ResultPoint;
import com.google.zxing.common.HybridBinarizer;
import com.google.zxing.datamatrix.detector.Detector;
import java.util.Iterator;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

/* access modifiers changed from: package-private */
public class CameraScanAnalysis implements Camera.PreviewCallback {
    private static final String TAG = "CameraScanAnalysis";
    private boolean allowAnalysis = true;
    private Image barcode;
    private Camera camera;
    private Context context;
    private int cropHeight;
    private int cropWidth;
    private byte[] data;
    private ExecutorService executorService = Executors.newSingleThreadExecutor();
    private Runnable mAnalysisTask = new Runnable() {
        /* class cn.bertsir.zbar.CameraScanAnalysis.AnonymousClass2 */

        public void run() {
            if (Symbol.is_auto_zoom && Symbol.scanType == 1 && QRUtils.getInstance().isScreenOriatationPortrait(CameraScanAnalysis.this.context)) {
                try {
                    ResultPoint[] points = new Detector(new BinaryBitmap(new HybridBinarizer(new PlanarYUVLuminanceSource(CameraScanAnalysis.this.data, CameraScanAnalysis.this.size.width, CameraScanAnalysis.this.size.height, Symbol.cropX, Symbol.cropY, CameraScanAnalysis.this.cropWidth, CameraScanAnalysis.this.cropHeight, true))).getBlackMatrix()).detect().getPoints();
                    float x = points[0].getX();
                    float y = points[0].getY();
                    float x2 = points[1].getX();
                    float f = x - x2;
                    float y2 = y - points[1].getY();
                    int sqrt = (int) Math.sqrt((double) ((Math.abs(f) * Math.abs(f)) + (Math.abs(y2) * Math.abs(y2))));
                    if (sqrt < CameraScanAnalysis.this.cropWidth / 4 && sqrt > 10) {
                        CameraScanAnalysis.this.cameraZoom(CameraScanAnalysis.this.camera);
                    }
                } catch (NotFoundException e) {
                    e.printStackTrace();
                }
            }
            String str = null;
            if (CameraScanAnalysis.this.mImageScanner.scanImage(CameraScanAnalysis.this.barcode) != 0) {
                Iterator<Symbol> it = CameraScanAnalysis.this.mImageScanner.getResults().iterator();
                while (it.hasNext()) {
                    str = it.next().getData();
                }
            }
            if (!TextUtils.isEmpty(str)) {
                Message obtainMessage = CameraScanAnalysis.this.mHandler.obtainMessage();
                obtainMessage.obj = str;
                obtainMessage.sendToTarget();
                return;
            }
            CameraScanAnalysis.this.allowAnalysis = true;
        }
    };
    private ScanCallback mCallback;
    private Handler mHandler;
    private ImageScanner mImageScanner;
    private Camera.Size size;

    CameraScanAnalysis(Context context2) {
        this.context = context2;
        this.mImageScanner = new ImageScanner();
        if (Symbol.scanType == 1) {
            this.mImageScanner.setConfig(0, 0, 0);
            this.mImageScanner.setConfig(64, 0, 1);
        } else if (Symbol.scanType == 2) {
            this.mImageScanner.setConfig(0, 0, 0);
            this.mImageScanner.setConfig(128, 0, 1);
            this.mImageScanner.setConfig(39, 0, 1);
            this.mImageScanner.setConfig(13, 0, 1);
            this.mImageScanner.setConfig(8, 0, 1);
            this.mImageScanner.setConfig(12, 0, 1);
            this.mImageScanner.setConfig(9, 0, 1);
            this.mImageScanner.setConfig(9, 0, 1);
        } else if (Symbol.scanType == 3) {
            this.mImageScanner.setConfig(0, 256, 3);
            this.mImageScanner.setConfig(0, 257, 3);
        } else if (Symbol.scanType == 4) {
            this.mImageScanner.setConfig(0, 0, 0);
            this.mImageScanner.setConfig(Symbol.scanFormat, 0, 1);
        } else {
            this.mImageScanner.setConfig(0, 256, 3);
            this.mImageScanner.setConfig(0, 257, 3);
        }
        this.mHandler = new Handler(Looper.getMainLooper()) {
            /* class cn.bertsir.zbar.CameraScanAnalysis.AnonymousClass1 */

            public void handleMessage(Message message) {
                if (CameraScanAnalysis.this.mCallback != null) {
                    CameraScanAnalysis.this.mCallback.onScanResult((String) message.obj);
                }
            }
        };
    }

    /* access modifiers changed from: package-private */
    public void setScanCallback(ScanCallback scanCallback) {
        this.mCallback = scanCallback;
    }

    /* access modifiers changed from: package-private */
    public void onStop() {
        this.allowAnalysis = false;
    }

    /* access modifiers changed from: package-private */
    public void onStart() {
        this.allowAnalysis = true;
    }

    public void onPreviewFrame(byte[] bArr, Camera camera2) {
        if (this.allowAnalysis) {
            this.allowAnalysis = false;
            this.data = bArr;
            this.camera = camera2;
            this.size = camera2.getParameters().getPreviewSize();
            Image image = new Image(this.size.width, this.size.height, "Y800");
            this.barcode = image;
            image.setData(bArr);
            if (Symbol.is_only_scan_center) {
                this.cropWidth = (int) (((float) Symbol.cropWidth) * (((float) this.size.height) / ((float) Symbol.screenWidth)));
                this.cropHeight = (int) (((float) Symbol.cropHeight) * (((float) this.size.width) / ((float) Symbol.screenHeight)));
                Symbol.cropX = (this.size.width / 2) - (this.cropHeight / 2);
                Symbol.cropY = (this.size.height / 2) - (this.cropWidth / 2);
                this.barcode.setCrop(Symbol.cropX, Symbol.cropY, this.cropHeight, this.cropWidth);
            }
            this.executorService.execute(this.mAnalysisTask);
        }
    }

    public void cameraZoom(Camera camera2) {
        if (camera2 != null) {
            Camera.Parameters parameters = camera2.getParameters();
            if (parameters.isZoomSupported() && parameters.getMaxZoom() != 0 && parameters.getZoom() + 10 <= parameters.getMaxZoom()) {
                parameters.setZoom(parameters.getZoom() + 10);
                camera2.setParameters(parameters);
            }
        }
    }
}
