package cn.bertsir.zbar.view;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.View;

public class CornerView extends View {
    public static final int LEFT_BOTTOM = 1;
    public static final int LEFT_TOP = 0;
    public static final int RIGHT_BOTTOM = 3;
    public static final int RIGHT_TOP = 2;
    private static final String TAG = "CornerView";
    private Canvas canvas;
    private int cornerColor;
    private int cornerGravity;
    private int cornerWidth;
    private int height;
    private Paint paint;
    private int width;

    public CornerView(Context context) {
        super(context, null);
        this.width = 0;
        this.height = 0;
        this.cornerColor = Color.parseColor("#ff5f00");
        this.cornerWidth = 10;
        this.cornerGravity = 1;
    }

    public CornerView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.width = 0;
        this.height = 0;
        this.cornerColor = Color.parseColor("#ff5f00");
        this.cornerWidth = 10;
        this.cornerGravity = 1;
        this.paint = new Paint();
        this.canvas = new Canvas();
        this.paint.setStyle(Paint.Style.FILL);
        this.paint.setStrokeWidth((float) this.cornerWidth);
        this.paint.setColor(this.cornerColor);
        this.paint.setAntiAlias(true);
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i, int i2) {
        super.onMeasure(i, i2);
        this.width = getMeasuredWidth();
        this.height = getMeasuredHeight();
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas2) {
        super.onDraw(canvas2);
        int i = this.cornerGravity;
        if (i == 0) {
            canvas2.drawLine(0.0f, 0.0f, (float) this.width, 0.0f, this.paint);
            canvas2.drawLine(0.0f, 0.0f, 0.0f, (float) this.height, this.paint);
        } else if (i == 1) {
            canvas2.drawLine(0.0f, 0.0f, 0.0f, (float) this.height, this.paint);
            int i2 = this.height;
            canvas2.drawLine(0.0f, (float) i2, (float) this.width, (float) i2, this.paint);
        } else if (i == 2) {
            canvas2.drawLine(0.0f, 0.0f, (float) this.width, 0.0f, this.paint);
            int i3 = this.width;
            canvas2.drawLine((float) i3, 0.0f, (float) i3, (float) this.height, this.paint);
        } else if (i == 3) {
            int i4 = this.width;
            canvas2.drawLine((float) i4, 0.0f, (float) i4, (float) this.height, this.paint);
            int i5 = this.height;
            canvas2.drawLine(0.0f, (float) i5, (float) this.width, (float) i5, this.paint);
        }
    }

    public void setColor(int i) {
        this.cornerColor = i;
        this.paint.setColor(i);
        invalidate();
    }

    public void setLineWidth(int i) {
        int dip2px = dip2px(i);
        this.cornerWidth = dip2px;
        this.paint.setStrokeWidth((float) dip2px);
        invalidate();
    }

    public void setConverGravity(int i) {
        this.cornerGravity = i;
    }

    public int dip2px(int i) {
        double d = (double) (((float) i) * getContext().getResources().getDisplayMetrics().density);
        Double.isNaN(d);
        return (int) (d + 0.5d);
    }
}
