package com.apicloud.arcfacepublic.faceserver;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Rect;
import android.graphics.YuvImage;
import android.text.TextUtils;
import android.util.Base64;
import android.util.Log;
import com.apicloud.arcfacepublic.Utils.LogUtil;
import com.apicloud.arcfacepublic.Utils.MouleUtil;
import com.arcsoft.face.FaceEngine;
import com.arcsoft.face.FaceFeature;
import com.arcsoft.face.FaceInfo;
import com.arcsoft.face.FaceSimilar;
import com.arcsoft.face.enums.DetectFaceOrientPriority;
import com.arcsoft.face.enums.DetectMode;
import com.arcsoft.face.enums.ExtractType;
import com.arcsoft.face.util.ImageUtils;
import com.uzmap.pkg.uzkit.UZUtility;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class FaceServer {
    public static final String IMG_SUFFIX = ".jpg";
    public static String ROOT_PATH = null;
    private static final String SAVE_FEATURE_DIR = ("register" + File.separator + "features");
    public static final String SAVE_IMG_DIR = ("register" + File.separator + "imgs");
    private static final String TAG = "FaceServer";
    private static FaceEngine faceEngine;
    private static List<FaceRegisterInfo> faceRegisterInfoList = new ArrayList();
    private static FaceServer faceServer;
    private boolean isProcessing = false;

    public static FaceServer getInstance() {
        if (faceServer == null) {
            synchronized (FaceServer.class) {
                if (faceServer == null) {
                    faceServer = new FaceServer();
                }
            }
        }
        return faceServer;
    }

    public boolean init(Context context) {
        synchronized (this) {
            if (faceEngine != null || context == null) {
                return false;
            }
            FaceEngine faceEngine2 = new FaceEngine();
            faceEngine = faceEngine2;
            int init = faceEngine2.init(context, DetectMode.ASF_DETECT_MODE_IMAGE, DetectFaceOrientPriority.ASF_OP_0_ONLY, 16, 5);
            if (init == 0) {
                initFaceList(context);
                return true;
            }
            faceEngine = null;
            Log.e(TAG, "init: failed! code = " + init);
            return false;
        }
    }

    public void unInit() {
        synchronized (this) {
            if (faceRegisterInfoList != null) {
                faceRegisterInfoList.clear();
                faceRegisterInfoList = null;
            }
            if (faceEngine != null) {
                faceEngine.unInit();
                faceEngine = null;
            }
        }
    }

    private void initFaceList(Context context) {
        synchronized (this) {
            if (ROOT_PATH == null) {
                ROOT_PATH = context.getFilesDir().getAbsolutePath();
            }
            File file = new File(ROOT_PATH + File.separator + SAVE_FEATURE_DIR);
            if (file.exists()) {
                if (file.isDirectory()) {
                    File[] listFiles = file.listFiles();
                    if (listFiles != null) {
                        if (listFiles.length != 0) {
                            faceRegisterInfoList = new ArrayList();
                            for (File file2 : listFiles) {
                                try {
                                    FileInputStream fileInputStream = new FileInputStream(file2);
                                    byte[] bArr = new byte[FaceFeature.FEATURE_SIZE];
                                    fileInputStream.read(bArr);
                                    fileInputStream.close();
                                    faceRegisterInfoList.add(new FaceRegisterInfo(bArr, file2.getName()));
                                } catch (IOException e) {
                                    e.printStackTrace();
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x0076  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0077  */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x007a  */
    public int getFaceNumber(Context context) {
        int i;
        File file;
        String[] list;
        synchronized (this) {
            int i2 = 0;
            if (context == null) {
                return 0;
            }
            if (ROOT_PATH == null) {
                ROOT_PATH = context.getFilesDir().getAbsolutePath();
            }
            File file2 = new File(ROOT_PATH + File.separator + SAVE_FEATURE_DIR);
            if (file2.exists() && file2.isDirectory()) {
                String[] list2 = file2.list();
                if (list2 != null) {
                    i = list2.length;
                    file = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
                    if (file.exists() && file.isDirectory()) {
                        list = file.list();
                        if (list == null) {
                            i2 = list.length;
                        }
                    }
                    if (i > i2) {
                        i = i2;
                    }
                    return i;
                }
            }
            i = 0;
            file = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
            list = file.list();
            if (list == null) {
            }
            if (i > i2) {
            }
            return i;
        }
    }

    public int clearAllFaces(Context context) {
        int i;
        File[] listFiles;
        File[] listFiles2;
        synchronized (this) {
            int i2 = 0;
            if (context == null) {
                return 0;
            }
            if (ROOT_PATH == null) {
                ROOT_PATH = context.getFilesDir().getAbsolutePath();
            }
            if (faceRegisterInfoList != null) {
                faceRegisterInfoList.clear();
            }
            File file = new File(ROOT_PATH + File.separator + SAVE_FEATURE_DIR);
            if (!file.exists() || !file.isDirectory() || (listFiles2 = file.listFiles()) == null || listFiles2.length <= 0) {
                i = 0;
            } else {
                i = 0;
                for (File file2 : listFiles2) {
                    if (file2.delete()) {
                        i++;
                    }
                }
            }
            File file3 = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
            if (file3.exists() && file3.isDirectory() && (listFiles = file3.listFiles()) != null && listFiles.length > 0) {
                int length = listFiles.length;
                int i3 = 0;
                while (i2 < length) {
                    if (listFiles[i2].delete()) {
                        i3++;
                    }
                    i2++;
                }
                i2 = i3;
            }
            if (i > i2) {
                i = i2;
            }
            return i;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:53:0x0129  */
    /* JADX WARNING: Removed duplicated region for block: B:56:0x015d  */
    public boolean registerNv21(Context context, byte[] bArr, int i, int i2, FaceInfo faceInfo, String str) {
        boolean z;
        synchronized (this) {
            if (!(faceEngine == null || context == null || bArr == null || i % 4 != 0)) {
                if (bArr.length == ((i * i2) * 3) / 2) {
                    if (ROOT_PATH == null) {
                        ROOT_PATH = context.getFilesDir().getAbsolutePath();
                    }
                    File file = new File(ROOT_PATH + File.separator + SAVE_FEATURE_DIR);
                    boolean mkdirs = !file.exists() ? file.mkdirs() : true;
                    if (!mkdirs) {
                        return false;
                    }
                    File file2 = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
                    if (!file2.exists()) {
                        mkdirs = file2.mkdirs();
                    }
                    if (!mkdirs) {
                        return false;
                    }
                    FaceFeature faceFeature = new FaceFeature();
                    int extractFaceFeature = faceEngine.extractFaceFeature(bArr, i, i2, FaceEngine.CP_PAF_NV21, faceInfo, ExtractType.REGISTER, 0, faceFeature);
                    String valueOf = str == null ? String.valueOf(System.currentTimeMillis()) : str;
                    if (extractFaceFeature == 0) {
                        try {
                            YuvImage yuvImage = new YuvImage(bArr, 17, i, i2, null);
                            Rect bestRect = getBestRect(i, i2, faceInfo.getRect());
                            if (bestRect == null) {
                                return false;
                            }
                            File file3 = new File(file2 + File.separator + valueOf + IMG_SUFFIX);
                            FileOutputStream fileOutputStream = new FileOutputStream(file3);
                            yuvImage.compressToJpeg(bestRect, 100, fileOutputStream);
                            fileOutputStream.close();
                            Bitmap decodeFile = BitmapFactory.decodeFile(file3.getAbsolutePath());
                            if (decodeFile != null) {
                                int orient = faceInfo.getOrient();
                                if (orient == 2) {
                                    decodeFile = ImageUtils.rotateBitmap(decodeFile, 90.0f);
                                } else if (orient == 3) {
                                    decodeFile = ImageUtils.rotateBitmap(decodeFile, 270.0f);
                                } else if (orient == 4) {
                                    decodeFile = ImageUtils.rotateBitmap(decodeFile, 180.0f);
                                }
                                z = true;
                                if (z) {
                                    FileOutputStream fileOutputStream2 = new FileOutputStream(file3);
                                    decodeFile.compress(Bitmap.CompressFormat.JPEG, 100, fileOutputStream2);
                                    fileOutputStream2.close();
                                }
                                FileOutputStream fileOutputStream3 = new FileOutputStream(file + File.separator + valueOf);
                                fileOutputStream3.write(faceFeature.getFeatureData());
                                fileOutputStream3.close();
                                if (faceRegisterInfoList == null) {
                                    faceRegisterInfoList = new ArrayList();
                                }
                                faceRegisterInfoList.add(new FaceRegisterInfo(faceFeature.getFeatureData(), valueOf));
                                return true;
                            }
                            z = false;
                            if (z) {
                            }
                            FileOutputStream fileOutputStream32 = new FileOutputStream(file + File.separator + valueOf);
                            fileOutputStream32.write(faceFeature.getFeatureData());
                            fileOutputStream32.close();
                            if (faceRegisterInfoList == null) {
                            }
                            faceRegisterInfoList.add(new FaceRegisterInfo(faceFeature.getFeatureData(), valueOf));
                            return true;
                        } catch (IOException e) {
                            e.printStackTrace();
                        }
                    }
                    return false;
                }
            }
            return false;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:62:0x0175  */
    /* JADX WARNING: Removed duplicated region for block: B:65:0x01a9  */
    public boolean registerBgr24(Context context, byte[] bArr, int i, int i2, String str) {
        boolean z;
        synchronized (this) {
            if (!(faceEngine == null || context == null || bArr == null || i % 4 != 0)) {
                if (bArr.length == i * i2 * 3) {
                    if (ROOT_PATH == null) {
                        ROOT_PATH = context.getFilesDir().getAbsolutePath();
                    }
                    File file = new File(ROOT_PATH + File.separator + SAVE_FEATURE_DIR);
                    boolean mkdirs = !file.exists() ? file.mkdirs() : true;
                    if (!mkdirs) {
                        return false;
                    }
                    File file2 = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
                    if (!file2.exists()) {
                        mkdirs = file2.mkdirs();
                    }
                    if (!mkdirs) {
                        return false;
                    }
                    ArrayList arrayList = new ArrayList();
                    if (faceEngine.detectFaces(bArr, i, i2, 513, arrayList) == 0 && arrayList.size() > 0) {
                        FaceFeature faceFeature = new FaceFeature();
                        int extractFaceFeature = faceEngine.extractFaceFeature(bArr, i, i2, 513, (FaceInfo) arrayList.get(0), ExtractType.REGISTER, 0, faceFeature);
                        String valueOf = str == null ? String.valueOf(System.currentTimeMillis()) : str;
                        if (extractFaceFeature == 0) {
                            try {
                                Rect bestRect = getBestRect(i, i2, ((FaceInfo) arrayList.get(0)).getRect());
                                if (bestRect == null) {
                                    return false;
                                }
                                if ((bestRect.width() & 1) == 1) {
                                    bestRect.right--;
                                }
                                if ((bestRect.height() & 1) == 1) {
                                    bestRect.bottom--;
                                }
                                File file3 = new File(file2 + File.separator + valueOf + IMG_SUFFIX);
                                FileOutputStream fileOutputStream = new FileOutputStream(file3);
                                ImageUtils.bgrToBitmap(ImageUtils.cropBgr24(bArr, i, i2, bestRect), bestRect.width(), bestRect.height()).compress(Bitmap.CompressFormat.JPEG, 100, fileOutputStream);
                                fileOutputStream.close();
                                Bitmap decodeFile = BitmapFactory.decodeFile(file3.getAbsolutePath());
                                if (decodeFile != null) {
                                    int orient = ((FaceInfo) arrayList.get(0)).getOrient();
                                    if (orient == 2) {
                                        decodeFile = ImageUtils.rotateBitmap(decodeFile, 90.0f);
                                    } else if (orient == 3) {
                                        decodeFile = ImageUtils.rotateBitmap(decodeFile, 270.0f);
                                    } else if (orient == 4) {
                                        decodeFile = ImageUtils.rotateBitmap(decodeFile, 180.0f);
                                    }
                                    z = true;
                                    if (z) {
                                        FileOutputStream fileOutputStream2 = new FileOutputStream(file3);
                                        decodeFile.compress(Bitmap.CompressFormat.JPEG, 100, fileOutputStream2);
                                        fileOutputStream2.close();
                                    }
                                    FileOutputStream fileOutputStream3 = new FileOutputStream(file + File.separator + valueOf);
                                    fileOutputStream3.write(faceFeature.getFeatureData());
                                    fileOutputStream3.close();
                                    if (faceRegisterInfoList == null) {
                                        faceRegisterInfoList = new ArrayList();
                                    }
                                    faceRegisterInfoList.add(new FaceRegisterInfo(faceFeature.getFeatureData(), valueOf));
                                    return true;
                                }
                                z = false;
                                if (z) {
                                }
                                FileOutputStream fileOutputStream32 = new FileOutputStream(file + File.separator + valueOf);
                                fileOutputStream32.write(faceFeature.getFeatureData());
                                fileOutputStream32.close();
                                if (faceRegisterInfoList == null) {
                                }
                                faceRegisterInfoList.add(new FaceRegisterInfo(faceFeature.getFeatureData(), valueOf));
                                return true;
                            } catch (IOException e) {
                                e.printStackTrace();
                            }
                        }
                    }
                    return false;
                }
            }
            return false;
        }
    }

    public FaceFeature getFeature(byte[] bArr, int i, int i2, FaceInfo faceInfo) {
        FaceFeature faceFeature = new FaceFeature();
        int extractFaceFeature = faceEngine.extractFaceFeature(bArr, i, i2, FaceEngine.CP_PAF_NV21, faceInfo, ExtractType.REGISTER, 0, faceFeature);
        Log.i("asher", "get feature code - " + extractFaceFeature);
        if (extractFaceFeature == 0) {
            return faceFeature;
        }
        return null;
    }

    /* JADX WARNING: Removed duplicated region for block: B:61:0x015d  */
    /* JADX WARNING: Removed duplicated region for block: B:64:0x0191  */
    public boolean registerBitMap(Context context, Bitmap bitmap, int i, int i2, String str) {
        boolean z;
        Bitmap bitmap2 = bitmap;
        synchronized (this) {
            if (!(faceEngine == null || context == null || bitmap2 == null)) {
                if (i % 4 == 0) {
                    if (ROOT_PATH == null) {
                        ROOT_PATH = context.getFilesDir().getAbsolutePath();
                    }
                    File file = new File(ROOT_PATH + File.separator + SAVE_FEATURE_DIR);
                    boolean mkdirs = !file.exists() ? file.mkdirs() : true;
                    if (!mkdirs) {
                        return false;
                    }
                    File file2 = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
                    if (!file2.exists()) {
                        mkdirs = file2.mkdirs();
                    }
                    if (!mkdirs) {
                        LogUtil.logi("imgDir = err");
                        return false;
                    }
                    byte[] bitmapToBgr24 = ImageUtils.bitmapToBgr24(ImageUtils.alignBitmapForBgr24(bitmap));
                    ArrayList arrayList = new ArrayList();
                    if (faceEngine.detectFaces(bitmapToBgr24, i, i2, 513, arrayList) == 0 && arrayList.size() > 0) {
                        FaceFeature faceFeature = new FaceFeature();
                        int extractFaceFeature = faceEngine.extractFaceFeature(bitmapToBgr24, i, i2, 513, (FaceInfo) arrayList.get(0), ExtractType.REGISTER, 0, faceFeature);
                        String valueOf = str == null ? String.valueOf(System.currentTimeMillis()) : str;
                        if (extractFaceFeature == 0) {
                            try {
                                Rect bestRect = getBestRect(i, i2, ((FaceInfo) arrayList.get(0)).getRect());
                                if (bestRect == null) {
                                    return false;
                                }
                                if ((bestRect.width() & 1) == 1) {
                                    bestRect.right--;
                                }
                                if ((bestRect.height() & 1) == 1) {
                                    bestRect.bottom--;
                                }
                                File file3 = new File(file2 + File.separator + valueOf + IMG_SUFFIX);
                                FileOutputStream fileOutputStream = new FileOutputStream(file3);
                                bitmap2.compress(Bitmap.CompressFormat.JPEG, 100, fileOutputStream);
                                fileOutputStream.close();
                                if (bitmap2 != 0) {
                                    int orient = ((FaceInfo) arrayList.get(0)).getOrient();
                                    if (orient == 2) {
                                        bitmap2 = ImageUtils.rotateBitmap(bitmap2, 90.0f);
                                    } else if (orient == 3) {
                                        bitmap2 = ImageUtils.rotateBitmap(bitmap2, 270.0f);
                                    } else if (orient == 4) {
                                        bitmap2 = ImageUtils.rotateBitmap(bitmap2, 180.0f);
                                    }
                                    z = true;
                                    if (z) {
                                        FileOutputStream fileOutputStream2 = new FileOutputStream(file3);
                                        bitmap2.compress(Bitmap.CompressFormat.JPEG, 100, fileOutputStream2);
                                        fileOutputStream2.close();
                                    }
                                    FileOutputStream fileOutputStream3 = new FileOutputStream(file + File.separator + valueOf);
                                    fileOutputStream3.write(faceFeature.getFeatureData());
                                    fileOutputStream3.close();
                                    if (faceRegisterInfoList == null) {
                                        faceRegisterInfoList = new ArrayList();
                                    }
                                    faceRegisterInfoList.add(new FaceRegisterInfo(faceFeature.getFeatureData(), valueOf));
                                    return true;
                                }
                                z = false;
                                if (z) {
                                }
                                FileOutputStream fileOutputStream32 = new FileOutputStream(file + File.separator + valueOf);
                                fileOutputStream32.write(faceFeature.getFeatureData());
                                fileOutputStream32.close();
                                if (faceRegisterInfoList == null) {
                                }
                                faceRegisterInfoList.add(new FaceRegisterInfo(faceFeature.getFeatureData(), valueOf));
                                return true;
                            } catch (IOException e) {
                                e.printStackTrace();
                                Log.i("asher", "Exception" + e.getMessage());
                            }
                        }
                    }
                    return false;
                }
            }
            Log.i("asher", "width %4 = " + (i % 4));
            Log.i("asher", "faceEngine = " + faceEngine);
            Log.i("asher", "bitmap = " + bitmap2);
            return false;
        }
    }

    public boolean delByName(String str) {
        File file = new File(ROOT_PATH + File.separator + SAVE_FEATURE_DIR);
        if (!file.exists()) {
            LogUtil.logi("delByName -- featureDir not exists");
            return false;
        }
        File file2 = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
        if (!file2.exists()) {
            LogUtil.logi("delByName -- imgDir not exists");
            return false;
        }
        File file3 = new File(file + File.separator + str);
        File file4 = new File(file2 + File.separator + str + IMG_SUFFIX);
        if (file3.exists()) {
            file3.delete();
        }
        if (file4.exists()) {
            file4.delete();
        }
        for (int i = 0; i < faceRegisterInfoList.size(); i++) {
            if (TextUtils.equals(faceRegisterInfoList.get(i).getName(), str)) {
                faceRegisterInfoList.remove(i);
            }
        }
        return true;
    }

    public boolean isNameExits(String str) {
        List<FaceRegisterInfo> list = faceRegisterInfoList;
        if (list != null && list.size() > 0) {
            for (int i = 0; i < faceRegisterInfoList.size(); i++) {
                if (TextUtils.equals(faceRegisterInfoList.get(i).getName(), str)) {
                    return true;
                }
            }
        }
        return false;
    }

    public CompareResult getTopOfFaceLib(FaceFeature faceFeature) {
        List<FaceRegisterInfo> list;
        if (!(faceEngine == null || this.isProcessing || faceFeature == null || (list = faceRegisterInfoList) == null || list.size() == 0)) {
            FaceFeature faceFeature2 = new FaceFeature();
            FaceSimilar faceSimilar = new FaceSimilar();
            float f = 0.0f;
            this.isProcessing = true;
            int i = -1;
            for (int i2 = 0; i2 < faceRegisterInfoList.size(); i2++) {
                faceFeature2.setFeatureData(faceRegisterInfoList.get(i2).getFeatureData());
                faceEngine.compareFaceFeature(faceFeature, faceFeature2, faceSimilar);
                if (faceSimilar.getScore() > f) {
                    f = faceSimilar.getScore();
                    i = i2;
                }
            }
            this.isProcessing = false;
            if (i != -1) {
                return new CompareResult(faceRegisterInfoList.get(i).getName(), f);
            }
        }
        return null;
    }

    public HashMap<String, Object> getTopOfFaceLib(byte[] bArr) {
        List<FaceRegisterInfo> list;
        if (!(faceEngine == null || this.isProcessing || bArr == null || (list = faceRegisterInfoList) == null || list.size() == 0)) {
            FaceFeature faceFeature = new FaceFeature();
            FaceFeature faceFeature2 = new FaceFeature();
            faceFeature2.setFeatureData(bArr);
            FaceSimilar faceSimilar = new FaceSimilar();
            float f = 0.0f;
            this.isProcessing = true;
            int i = -1;
            for (int i2 = 0; i2 < faceRegisterInfoList.size(); i2++) {
                faceFeature.setFeatureData(faceRegisterInfoList.get(i2).getFeatureData());
                faceEngine.compareFaceFeature(faceFeature2, faceFeature, faceSimilar);
                if (faceSimilar.getScore() > f) {
                    f = faceSimilar.getScore();
                    i = i2;
                }
            }
            this.isProcessing = false;
            if (i != -1) {
                HashMap<String, Object> hashMap = new HashMap<>();
                File file = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
                Bitmap bitmap = MouleUtil.getBitmap(file + File.separator + faceRegisterInfoList.get(i).getName() + IMG_SUFFIX);
                if (bitmap != null) {
                    JSONObject jSONObject = new JSONObject();
                    try {
                        jSONObject.put("content", Base64.encodeToString(MouleUtil.bitmapToByte(bitmap), 0));
                        jSONObject.put("width", bitmap.getWidth());
                        jSONObject.put("height", bitmap.getHeight());
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                    hashMap.put("img", jSONObject);
                    bitmap.recycle();
                }
                hashMap.put("score", Float.valueOf(f));
                hashMap.put("name", faceRegisterInfoList.get(i).getName());
                return hashMap;
            }
        }
        return null;
    }

    public JSONArray getAllFace() {
        if (faceEngine == null || faceRegisterInfoList == null) {
            return null;
        }
        File file = new File(ROOT_PATH + File.separator + SAVE_IMG_DIR);
        JSONArray jSONArray = new JSONArray();
        for (int i = 0; i < faceRegisterInfoList.size(); i++) {
            JSONObject jSONObject = new JSONObject();
            try {
                jSONObject.put("feature", Base64.encodeToString(faceRegisterInfoList.get(i).getFeatureData(), 0));
                jSONObject.put("name", faceRegisterInfoList.get(i).getName());
                Bitmap localImage = UZUtility.getLocalImage(file + File.separator + faceRegisterInfoList.get(i).getName() + IMG_SUFFIX);
                if (localImage != null) {
                    byte[] bitmapToByte = MouleUtil.bitmapToByte(localImage);
                    JSONObject jSONObject2 = new JSONObject();
                    jSONObject2.put("content", Base64.encodeToString(bitmapToByte, 0));
                    jSONObject2.put("width", localImage.getWidth());
                    jSONObject2.put("height", localImage.getHeight());
                    jSONObject.put("img", jSONObject2);
                }
            } catch (JSONException e) {
                e.printStackTrace();
            }
            jSONArray.put(jSONObject);
        }
        return jSONArray;
    }

    private static Rect getBestRect(int i, int i2, Rect rect) {
        int i3;
        int i4;
        int i5;
        if (rect == null) {
            return null;
        }
        Rect rect2 = new Rect(rect);
        int i6 = 0;
        if (rect2.left < 0) {
            i6 = -rect2.left;
        }
        if (rect2.top < 0 && (i5 = -rect2.top) > i6) {
            i6 = i5;
        }
        if (rect2.right > i && (i4 = rect2.right - i) > i6) {
            i6 = i4;
        }
        if (rect2.bottom > i2 && (i3 = rect2.bottom - i2) > i6) {
            i6 = i3;
        }
        if (i6 != 0) {
            rect2.left += i6;
            rect2.top += i6;
            rect2.right -= i6;
            rect2.bottom -= i6;
            return rect2;
        }
        int height = rect2.height() / 2;
        if (rect2.left - height <= 0 || rect2.right + height >= i || rect2.top - height <= 0 || rect2.bottom + height >= i2) {
            height = Math.min(Math.min(Math.min(rect2.left, i - rect2.right), i2 - rect2.bottom), rect2.top);
        }
        rect2.left -= height;
        rect2.top -= height;
        rect2.right += height;
        rect2.bottom += height;
        return rect2;
    }
}
