package com.apicloud.audiostreamer;

import android.content.Context;
import android.content.res.AssetFileDescriptor;
import android.media.AudioManager;
import android.media.MediaPlayer;
import android.os.Build;
import android.os.Handler;
import android.os.Message;
import android.text.TextUtils;
import android.util.Log;
import com.uzmap.pkg.uzcore.uzmodule.UZModuleContext;
import java.io.FileDescriptor;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.Hashtable;
import org.json.JSONException;
import org.json.JSONObject;

public class MediaService implements MediaPlayer.OnErrorListener, MediaPlayer.OnCompletionListener, MediaPlayer.OnBufferingUpdateListener, MediaPlayer.OnPreparedListener, MediaPlayer.OnInfoListener {
    static Hashtable<String, MediaService> MediaList = new Hashtable<>();
    static int mDuration = 0;
    private AudioManager mAudioManager;
    private String mCurSource = "";
    private boolean mInPrepareing;
    private PlayListener mPlayListener;
    private MediaPlayer mPlayer;
    private int mPrecent;
    private String mSource;
    private UZModuleContext moduleContext;
    private Handler report = new Handler() {
        /* class com.apicloud.audiostreamer.MediaService.AnonymousClass1 */

        public void handleMessage(Message message) {
            if (MediaService.this.isPlaying()) {
                int currentPosition = MediaService.this.mPlayer.getCurrentPosition();
                if (MediaService.this.mPlayListener != null) {
                    MediaService.this.mPlayListener.onPercent(MediaService.mDuration, currentPosition);
                }
                sendEmptyMessageDelayed(0, 350);
            }
        }
    };
    private FileInputStream tempInput;

    private MediaService() {
    }

    public static MediaService instance(String str) {
        if (TextUtils.isEmpty(str)) {
            return null;
        }
        MediaService mediaService = MediaList.get(str);
        if (mediaService != null) {
            return mediaService;
        }
        MediaService mediaService2 = new MediaService();
        MediaList.put(str, mediaService2);
        return mediaService2;
    }

    public void setPlayListener(PlayListener playListener) {
        this.mPlayListener = playListener;
    }

    public boolean play(Context context, String str) {
        this.mSource = str;
        if (this.mInPrepareing) {
            return false;
        }
        if (this.mPlayer == null || (isPlaying() && !TextUtils.isEmpty(str) && !this.mCurSource.equals(str))) {
            stop();
            MediaPlayer mediaPlayer = new MediaPlayer();
            this.mPlayer = mediaPlayer;
            mediaPlayer.setOnErrorListener(this);
            this.mPlayer.setOnCompletionListener(this);
            this.mPlayer.setOnBufferingUpdateListener(this);
            this.mPlayer.setOnPreparedListener(this);
            setPlayerPath(context, str);
            try {
                this.mPlayer.prepareAsync();
                this.mInPrepareing = true;
                this.mCurSource = str;
                return true;
            } catch (Exception e) {
                e.printStackTrace();
                errorCallback("prepare in an invalid state", "prepare in an invalid state");
                return false;
            }
        } else {
            this.mPlayer.start();
            setCallback();
            this.report.sendEmptyMessage(0);
            return true;
        }
    }

    private void setCallback() {
        try {
            if (this.moduleContext != null) {
                JSONObject jSONObject = new JSONObject();
                jSONObject.put("state", "resume");
                this.moduleContext.success(jSONObject, false);
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

    public void addEventListener(UZModuleContext uZModuleContext) {
        this.moduleContext = uZModuleContext;
    }

    private boolean setPlayerPath(Context context, String str) {
        FileDescriptor fileDescriptor;
        long j;
        if (str.startsWith("http")) {
            try {
                this.mPlayer.setDataSource(str);
                return true;
            } catch (Exception e) {
                e.printStackTrace();
                errorCallback("source error", "source error");
                return false;
            }
        } else {
            int indexOf = str.indexOf("?");
            if (indexOf > -1) {
                str = str.substring(0, indexOf);
            }
            long j2 = 0;
            if (str.contains("android_asset")) {
                if (str.startsWith("file://")) {
                    str = str.substring(7);
                }
                try {
                    AssetFileDescriptor openFd = context.getAssets().openFd(str.substring(15));
                    fileDescriptor = openFd.getFileDescriptor();
                    j2 = openFd.getStartOffset();
                    j = openFd.getLength();
                } catch (IOException e2) {
                    e2.printStackTrace();
                    errorCallback("source error", "source error");
                    return false;
                }
            } else {
                if (str.startsWith("file://")) {
                    str = str.substring(7);
                }
                try {
                    FileInputStream fileInputStream = new FileInputStream(str);
                    this.tempInput = fileInputStream;
                    fileDescriptor = fileInputStream.getFD();
                    j = (long) this.tempInput.available();
                } catch (Exception e3) {
                    e3.printStackTrace();
                    errorCallback("source error", "source error");
                    return false;
                }
            }
            try {
                this.mPlayer.setDataSource(fileDescriptor, j2, j);
                return true;
            } catch (Exception e4) {
                e4.printStackTrace();
                errorCallback("source error", "source error");
                return false;
            }
        }
    }

    public void pause() {
        if (isPlaying()) {
            try {
                this.mPlayer.pause();
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public void setLoop(boolean z) {
        MediaPlayer mediaPlayer = this.mPlayer;
        if (mediaPlayer != null) {
            mediaPlayer.setLooping(z);
        }
    }

    public void setSeek(int i) {
        int i2;
        MediaPlayer mediaPlayer = this.mPlayer;
        if (mediaPlayer != null) {
            int i3 = 0;
            try {
                i2 = mediaPlayer.getDuration();
            } catch (Exception unused) {
                i2 = 0;
            }
            if (i2 > 0) {
                int i4 = i * 1000;
                if (i4 >= 0) {
                    i3 = i4;
                }
                if (i3 > i2) {
                    double d = (double) i2;
                    Double.isNaN(d);
                    i3 = (int) (d - 500.0d);
                }
                this.mPlayer.seekTo(i3);
            }
        }
    }

    public void setVolume(float f) {
        MediaPlayer mediaPlayer = this.mPlayer;
        if (mediaPlayer != null) {
            try {
                mediaPlayer.setVolume(f, f);
            } catch (Exception unused) {
            }
        }
    }

    public void stop() {
        MediaPlayer mediaPlayer = this.mPlayer;
        if (mediaPlayer != null) {
            try {
                mediaPlayer.release();
                this.mPlayer = null;
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        FileInputStream fileInputStream = this.tempInput;
        if (fileInputStream != null) {
            try {
                fileInputStream.close();
                this.tempInput = null;
            } catch (IOException e2) {
                e2.printStackTrace();
            }
        }
        mDuration = 0;
        this.mCurSource = "";
        this.mInPrepareing = false;
    }

    public void onPrepared(MediaPlayer mediaPlayer) {
        try {
            mDuration = mediaPlayer.getDuration();
            mediaPlayer.start();
            if (this.mPlayListener != null) {
                this.mPlayListener.onPrepared(mDuration / 1000);
                this.report.sendEmptyMessage(0);
            }
            this.mInPrepareing = false;
        } catch (Exception e) {
            e.printStackTrace();
            stop();
            errorCallback("start in an invalid state", "start in an invalid state");
        }
    }

    public void onBufferingUpdate(MediaPlayer mediaPlayer, int i) {
        Log.e("TAG", "缓冲进度---：" + i);
        PlayListener playListener = this.mPlayListener;
        if (playListener != null) {
            playListener.onBufferingRatio(i);
        }
    }

    public void onCompletion(MediaPlayer mediaPlayer) {
        stop();
        PlayListener playListener = this.mPlayListener;
        if (playListener != null) {
            playListener.onCompletion(mDuration);
        }
    }

    public boolean onError(MediaPlayer mediaPlayer, int i, int i2) {
        if (this.mPlayListener != null) {
            String str = "" + i;
            if (i == 1) {
                str = "MEDIA_ERROR_UNKNOWN";
            } else if (i == 100) {
                str = "MEDIA_ERROR_SERVER_DIED";
            }
            String str2 = "" + i2;
            if (i == -1010) {
                str = "MEDIA_ERROR_UNSUPPORTED ";
            } else if (i == -1007) {
                str = "MEDIA_ERROR_MALFORMED ";
            } else if (i == -1004) {
                str = "MEDIA_ERROR_IO ";
            } else if (i == -110) {
                str = "MEDIA_ERROR_TIMED_OUT ";
            }
            errorCallback(str, str2);
        }
        stop();
        return true;
    }

    private void errorCallback(String str, String str2) {
        PlayListener playListener = this.mPlayListener;
        if (playListener != null) {
            playListener.onError(str, str2);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean isPlaying() {
        MediaPlayer mediaPlayer = this.mPlayer;
        if (mediaPlayer == null) {
            return false;
        }
        try {
            return mediaPlayer.isPlaying();
        } catch (Exception unused) {
            return false;
        }
    }

    public void onClean() {
        stop();
        Handler handler = this.report;
        if (handler != null) {
            handler.removeMessages(0);
        }
    }

    public boolean onInfo(MediaPlayer mediaPlayer, int i, int i2) {
        this.mPlayListener.onBufferingInfo(i != 701 ? i != 702 ? null : "缓冲结束" : "缓冲中", mDuration);
        return false;
    }

    public MediaPlayer getMediaPlayer() {
        return this.mPlayer;
    }

    public void onCall(Context context) {
        if (this.mAudioManager == null) {
            this.mAudioManager = (AudioManager) context.getSystemService("audio");
        }
        this.mAudioManager.setSpeakerphoneOn(false);
        if (Build.VERSION.SDK_INT >= 11) {
            this.mAudioManager.setMode(3);
            try {
                if (this.mPlayer != null && this.mPlayer.isPlaying()) {
                    this.mPrecent = this.mPlayer.getCurrentPosition();
                    this.mPlayer.stop();
                    this.mPlayer.reset();
                    this.mAudioManager.setSpeakerphoneOn(false);
                    this.mAudioManager.setMode(3);
                    this.mPlayer.setAudioStreamType(0);
                    this.mPlayer.setDataSource(this.mSource);
                    this.mPlayer.prepare();
                    this.mPlayer.start();
                    this.mPlayer.seekTo(this.mPrecent);
                }
            } catch (Exception unused) {
            }
        } else {
            this.mAudioManager.setMode(2);
        }
    }

    public void onNormal(Context context) {
        if (this.mAudioManager == null) {
            this.mAudioManager = (AudioManager) context.getSystemService("audio");
        }
        this.mAudioManager.setMode(0);
        this.mAudioManager.setSpeakerphoneOn(true);
    }
}
