package com.apicloud.barteksc.pdfviewer;

import android.graphics.RectF;
import com.apicloud.barteksc.pdfviewer.util.Constants;
import com.apicloud.barteksc.pdfviewer.util.MathUtils;
import com.apicloud.barteksc.pdfviewer.util.Util;
import com.shockwave.pdfium.util.SizeF;

/* access modifiers changed from: package-private */
public class PagesLoader {
    private int cacheOrder;
    private final GridSize firstGrid = new GridSize();
    private final Holder firstHolder = new Holder();
    private final GridSize lastGrid = new GridSize();
    private final Holder lastHolder = new Holder();
    private final GridSize middleGrid = new GridSize();
    private float pageRelativePartHeight;
    private float pageRelativePartWidth;
    private float partRenderHeight;
    private float partRenderWidth;
    private PDFView pdfView;
    private final int preloadOffset;
    private final RectF thumbnailRect = new RectF(0.0f, 0.0f, 1.0f, 1.0f);
    private float xOffset;
    private float yOffset;

    /* access modifiers changed from: private */
    public class Holder {
        int col;
        int page;
        int row;

        private Holder() {
        }
    }

    /* access modifiers changed from: private */
    public class GridSize {
        int cols;
        int rows;

        private GridSize() {
        }
    }

    PagesLoader(PDFView pDFView) {
        this.pdfView = pDFView;
        this.preloadOffset = Util.getDP(pDFView.getContext(), Constants.PRELOAD_OFFSET);
    }

    private void getPageColsRows(GridSize gridSize, int i) {
        SizeF pageSize = this.pdfView.pdfFile.getPageSize(i);
        float height = (Constants.PART_SIZE * (1.0f / pageSize.getHeight())) / this.pdfView.getZoom();
        float width = (Constants.PART_SIZE * (1.0f / pageSize.getWidth())) / this.pdfView.getZoom();
        gridSize.rows = MathUtils.ceil(1.0f / height);
        gridSize.cols = MathUtils.ceil(1.0f / width);
    }

    private Holder getPageAndCoordsByOffset(Holder holder, GridSize gridSize, float f, float f2, boolean z) {
        float f3;
        float f4;
        float f5 = -MathUtils.max(f, 0.0f);
        float f6 = -MathUtils.max(f2, 0.0f);
        holder.page = this.pdfView.pdfFile.getPageAtOffset(this.pdfView.isSwipeVertical() ? f6 : f5, this.pdfView.getZoom());
        getPageColsRows(gridSize, holder.page);
        SizeF scaledPageSize = this.pdfView.pdfFile.getScaledPageSize(holder.page, this.pdfView.getZoom());
        float height = scaledPageSize.getHeight() / ((float) gridSize.rows);
        float width = scaledPageSize.getWidth() / ((float) gridSize.cols);
        float secondaryPageOffset = this.pdfView.pdfFile.getSecondaryPageOffset(holder.page, this.pdfView.getZoom());
        if (this.pdfView.isSwipeVertical()) {
            f3 = Math.abs(f6 - this.pdfView.pdfFile.getPageOffset(holder.page, this.pdfView.getZoom())) / height;
            f4 = MathUtils.min(f5 - secondaryPageOffset, 0.0f) / width;
        } else {
            f3 = MathUtils.min(f6 - secondaryPageOffset, 0.0f) / height;
            f4 = Math.abs(f5 - this.pdfView.pdfFile.getPageOffset(holder.page, this.pdfView.getZoom())) / width;
        }
        if (z) {
            holder.row = MathUtils.ceil(f3);
            holder.col = MathUtils.ceil(f4);
        } else {
            holder.row = MathUtils.floor(f3);
            holder.col = MathUtils.floor(f4);
        }
        return holder;
    }

    private void calculatePartSize(GridSize gridSize) {
        this.pageRelativePartWidth = 1.0f / ((float) gridSize.cols);
        this.pageRelativePartHeight = 1.0f / ((float) gridSize.rows);
        this.partRenderWidth = Constants.PART_SIZE / this.pageRelativePartWidth;
        this.partRenderHeight = Constants.PART_SIZE / this.pageRelativePartHeight;
    }

    private void loadVisible() {
        int loadWholePage;
        float zoom = ((float) this.preloadOffset) * this.pdfView.getZoom();
        float f = this.xOffset;
        float f2 = (-f) + zoom;
        float width = ((-f) - ((float) this.pdfView.getWidth())) - zoom;
        float f3 = this.yOffset;
        getPageAndCoordsByOffset(this.firstHolder, this.firstGrid, f2, (-f3) + zoom, false);
        getPageAndCoordsByOffset(this.lastHolder, this.lastGrid, width, ((-f3) - ((float) this.pdfView.getHeight())) - zoom, true);
        for (int i = this.firstHolder.page; i <= this.lastHolder.page; i++) {
            loadThumbnail(i);
        }
        int i2 = (this.lastHolder.page - this.firstHolder.page) + 1;
        int i3 = 0;
        for (int i4 = this.firstHolder.page; i4 <= this.lastHolder.page && i3 < Constants.Cache.CACHE_SIZE; i4++) {
            if (i4 == this.firstHolder.page && i2 > 1) {
                loadWholePage = loadPageEnd(this.firstHolder, this.firstGrid, Constants.Cache.CACHE_SIZE - i3);
            } else if (i4 == this.lastHolder.page && i2 > 1) {
                loadWholePage = loadPageStart(this.lastHolder, this.lastGrid, Constants.Cache.CACHE_SIZE - i3);
            } else if (i2 == 1) {
                loadWholePage = loadPageCenter(this.firstHolder, this.lastHolder, this.firstGrid, Constants.Cache.CACHE_SIZE - i3);
            } else {
                getPageColsRows(this.middleGrid, i4);
                loadWholePage = loadWholePage(i4, this.middleGrid, Constants.Cache.CACHE_SIZE - i3);
            }
            i3 += loadWholePage;
        }
    }

    private int loadWholePage(int i, GridSize gridSize, int i2) {
        calculatePartSize(gridSize);
        return loadPage(i, 0, gridSize.rows - 1, 0, gridSize.cols - 1, i2);
    }

    private int loadPageCenter(Holder holder, Holder holder2, GridSize gridSize, int i) {
        calculatePartSize(gridSize);
        return loadPage(holder.page, holder.row, holder2.row, holder.col, holder2.col, i);
    }

    private int loadPageEnd(Holder holder, GridSize gridSize, int i) {
        calculatePartSize(gridSize);
        if (this.pdfView.isSwipeVertical()) {
            return loadPage(holder.page, holder.row, gridSize.rows - 1, 0, gridSize.cols - 1, i);
        }
        return loadPage(holder.page, 0, gridSize.rows - 1, holder.col, gridSize.cols - 1, i);
    }

    private int loadPageStart(Holder holder, GridSize gridSize, int i) {
        calculatePartSize(gridSize);
        if (this.pdfView.isSwipeVertical()) {
            return loadPage(holder.page, 0, holder.row, 0, gridSize.cols - 1, i);
        }
        return loadPage(holder.page, 0, gridSize.rows - 1, 0, holder.col, i);
    }

    private int loadPage(int i, int i2, int i3, int i4, int i5, int i6) {
        int i7 = 0;
        while (i2 <= i3) {
            for (int i8 = i4; i8 <= i5; i8++) {
                if (loadCell(i, i2, i8, this.pageRelativePartWidth, this.pageRelativePartHeight)) {
                    i7++;
                }
                if (i7 >= i6) {
                    return i7;
                }
            }
            i2++;
        }
        return i7;
    }

    private boolean loadCell(int i, int i2, int i3, float f, float f2) {
        float f3 = ((float) i3) * f;
        float f4 = ((float) i2) * f2;
        float f5 = this.partRenderWidth;
        float f6 = this.partRenderHeight;
        float f7 = f3 + f > 1.0f ? 1.0f - f3 : f;
        float f8 = f4 + f2 > 1.0f ? 1.0f - f4 : f2;
        float f9 = f5 * f7;
        float f10 = f6 * f8;
        RectF rectF = new RectF(f3, f4, f7 + f3, f8 + f4);
        if (f9 <= 0.0f || f10 <= 0.0f) {
            return false;
        }
        if (!this.pdfView.cacheManager.upPartIfContained(i, rectF, this.cacheOrder)) {
            this.pdfView.renderingHandler.addRenderingTask(i, f9, f10, rectF, false, this.cacheOrder, this.pdfView.isBestQuality(), this.pdfView.isAnnotationRendering());
        }
        this.cacheOrder++;
        return true;
    }

    private void loadThumbnail(int i) {
        SizeF pageSize = this.pdfView.pdfFile.getPageSize(i);
        float width = pageSize.getWidth() * Constants.THUMBNAIL_RATIO;
        float height = pageSize.getHeight() * Constants.THUMBNAIL_RATIO;
        if (!this.pdfView.cacheManager.containsThumbnail(i, this.thumbnailRect)) {
            this.pdfView.renderingHandler.addRenderingTask(i, width, height, this.thumbnailRect, true, 0, this.pdfView.isBestQuality(), this.pdfView.isAnnotationRendering());
        }
    }

    /* access modifiers changed from: package-private */
    public void loadPages() {
        this.cacheOrder = 1;
        this.xOffset = -MathUtils.max(this.pdfView.getCurrentXOffset(), 0.0f);
        this.yOffset = -MathUtils.max(this.pdfView.getCurrentYOffset(), 0.0f);
        loadVisible();
    }
}
