package com.arcsoft.face;

import android.content.Context;
import android.graphics.Rect;
import com.arcsoft.face.enums.CompareModel;
import com.arcsoft.face.enums.DetectFaceOrientPriority;
import com.arcsoft.face.enums.DetectMode;
import com.arcsoft.face.enums.DetectModel;
import com.arcsoft.face.enums.DeviceIdPriority;
import com.arcsoft.face.enums.ExtractType;
import com.arcsoft.face.enums.MACPriority;
import com.arcsoft.face.enums.RuntimeABI;
import com.arcsoft.face.model.ActiveDeviceInfo;
import com.arcsoft.face.model.ArcSoftImageInfo;
import java.util.List;

public class FaceEngine {
    public static final int ASF_AGE = 8;
    public static final int ASF_FACE_DETECT = 1;
    public static final int ASF_FACE_RECOGNITION = 4;
    public static final int ASF_GENDER = 16;
    public static final int ASF_IMAGEQUALITY = 512;
    public static final int ASF_IR_LIVENESS = 1024;
    public static final int ASF_LIVENESS = 128;
    public static final int ASF_MASK_DETECT = 4096;
    public static final int ASF_NONE = 0;
    public static final int ASF_OC_0 = 1;
    public static final int ASF_OC_120 = 7;
    public static final int ASF_OC_150 = 8;
    public static final int ASF_OC_180 = 4;
    public static final int ASF_OC_210 = 9;
    public static final int ASF_OC_240 = 10;
    public static final int ASF_OC_270 = 3;
    public static final int ASF_OC_30 = 5;
    public static final int ASF_OC_300 = 11;
    public static final int ASF_OC_330 = 12;
    public static final int ASF_OC_60 = 6;
    public static final int ASF_OC_90 = 2;
    public static final int ASF_UPDATE_FACEDATA = 8192;
    public static final int CP_PAF_BGR24 = 513;
    public static final int CP_PAF_DEPTH_U16 = 3074;
    public static final int CP_PAF_GRAY = 1793;
    public static final int CP_PAF_NV21 = 2050;
    private ErrorInfo detectError = new ErrorInfo();
    private ErrorInfo detectQualityError = new ErrorInfo();
    private ErrorInfo faceDataError = new ErrorInfo();
    private ErrorInfo frError = new ErrorInfo();
    private long handle = 0;
    private float[] imageQualityArray;
    private ErrorInfo initError = new ErrorInfo();
    private AgeInfo[] mAgeInfoArray;
    private FaceInfo[] mFaceInfoArray;
    private GenderInfo[] mGenderInfoArray;
    private LivenessInfo[] mIrLivenessInfoArray;
    private LivenessInfo[] mLivenessInfoArray;
    private MaskInfo[] mMaskInfoArray;
    private ErrorInfo processError = new ErrorInfo();
    private ErrorInfo processIrError = new ErrorInfo();

    private static native int nativeActiveFaceEngineOffline(Context context, String str);

    private static native int nativeActiveFaceEngineOnline(Context context, String str, String str2, String str3);

    private native int nativeDetectFaces(long j, ArcSoftImageInfo arcSoftImageInfo, int i, FaceInfo[] faceInfoArr, ErrorInfo errorInfo);

    private native int nativeDetectFaces(long j, byte[] bArr, int i, int i2, int i3, int i4, FaceInfo[] faceInfoArr, ErrorInfo errorInfo);

    private native void nativeExtractFaceFeature(long j, ArcSoftImageInfo arcSoftImageInfo, Rect rect, int i, byte[] bArr, int i2, int i3, int i4, byte[] bArr2, ErrorInfo errorInfo);

    private native void nativeExtractFaceFeature(long j, byte[] bArr, int i, int i2, int i3, Rect rect, int i4, byte[] bArr2, int i5, int i6, int i7, byte[] bArr3, ErrorInfo errorInfo);

    private static native int nativeGetActiveDeviceInfo(Context context, ActiveDeviceInfo activeDeviceInfo);

    private static native int nativeGetActiveFile(Context context, ActiveFileInfo activeFileInfo);

    private native int nativeGetAge(long j, AgeInfo[] ageInfoArr, ErrorInfo errorInfo);

    private native int nativeGetFaceCount(long j);

    private native FaceFeatureInfo nativeGetFaceFeature(long j, int i);

    private native int nativeGetGender(long j, GenderInfo[] genderInfoArr, ErrorInfo errorInfo);

    private native int nativeGetIrLiveness(long j, LivenessInfo[] livenessInfoArr, ErrorInfo errorInfo);

    private native int nativeGetLiveness(long j, LivenessInfo[] livenessInfoArr, ErrorInfo errorInfo);

    private native LivenessParam nativeGetLivenessParam(long j);

    private native int nativeGetMask(long j, MaskInfo[] maskInfoArr, ErrorInfo errorInfo);

    private static native int nativeGetRuntimeABI();

    private static native void nativeGetVersion(VersionInfo versionInfo);

    private native float nativeImageQualityDetect(long j, ArcSoftImageInfo arcSoftImageInfo, Rect rect, int i, byte[] bArr, int i2, int i3, ErrorInfo errorInfo);

    private native float nativeImageQualityDetect(long j, byte[] bArr, int i, int i2, int i3, Rect rect, int i4, byte[] bArr2, int i5, int i6, ErrorInfo errorInfo);

    private native long nativeInitFaceEngine(Context context, long j, int i, int i2, int i3, ErrorInfo errorInfo);

    private native float nativePairMatching(long j, byte[] bArr, byte[] bArr2, int i, ErrorInfo errorInfo);

    private native void nativeProcess(long j, ArcSoftImageInfo arcSoftImageInfo, FaceInfo[] faceInfoArr, int i, ErrorInfo errorInfo);

    private native void nativeProcess(long j, byte[] bArr, int i, int i2, int i3, FaceInfo[] faceInfoArr, int i4, ErrorInfo errorInfo);

    private native void nativeProcessIr(long j, ArcSoftImageInfo arcSoftImageInfo, FaceInfo[] faceInfoArr, int i, ErrorInfo errorInfo);

    private native void nativeProcessIr(long j, byte[] bArr, int i, int i2, int i3, FaceInfo[] faceInfoArr, int i4, ErrorInfo errorInfo);

    private native int nativeRegisterFaceFeature(long j, FaceFeatureInfo faceFeatureInfo);

    private native int nativeRegisterFaceFeatureArray(long j, FaceFeatureInfo[] faceFeatureInfoArr);

    private native int nativeRemoveFaceFeature(long j, int i);

    private native SearchResult nativeSearchFaceFeature(long j, byte[] bArr, int i);

    private static native void nativeSetDeviceIdPriority(int i);

    private native int nativeSetFaceAttributeParam(long j, FaceAttributeParam faceAttributeParam);

    private native int nativeSetLivenessParam(long j, LivenessParam livenessParam);

    private static native void nativeSetMACPriority(int i);

    private native int nativeUnInitFaceEngine(long j);

    private native int nativeUpdateFaceData(long j, ArcSoftImageInfo arcSoftImageInfo, FaceInfo[] faceInfoArr, ErrorInfo errorInfo);

    private native int nativeUpdateFaceData(long j, byte[] bArr, int i, int i2, int i3, FaceInfo[] faceInfoArr, ErrorInfo errorInfo);

    private native int nativeUpdateFaceFeature(long j, FaceFeatureInfo faceFeatureInfo);

    public static RuntimeABI getRuntimeABI() {
        int nativeGetRuntimeABI = nativeGetRuntimeABI();
        if (nativeGetRuntimeABI == 1) {
            return RuntimeABI.ANDROID_ABI_ARM64;
        }
        if (nativeGetRuntimeABI != 2) {
            return RuntimeABI.ANDROID_ABI_UNSUPPORTED;
        }
        return RuntimeABI.ANDROID_ABI_ARM32;
    }

    public static int getActiveDeviceInfo(Context context, ActiveDeviceInfo activeDeviceInfo) {
        return nativeGetActiveDeviceInfo(context, activeDeviceInfo);
    }

    public static int setMACPriority(MACPriority mACPriority) {
        if (mACPriority == null) {
            return 2;
        }
        nativeSetMACPriority(mACPriority.getPriority());
        return 0;
    }

    public static int setDeviceIdPriority(DeviceIdPriority deviceIdPriority) {
        if (deviceIdPriority == null) {
            return 2;
        }
        nativeSetDeviceIdPriority(deviceIdPriority.getPriority());
        return 0;
    }

    public static int activeOnline(Context context, String str, String str2, String str3) {
        if (context == null || str == null || str2 == null || str3 == null) {
            return 2;
        }
        return nativeActiveFaceEngineOnline(context, str, str2, str3);
    }

    public static int activeOffline(Context context, String str) {
        if (context == null || str == null) {
            return 2;
        }
        return nativeActiveFaceEngineOffline(context, str);
    }

    public static int getActiveFileInfo(Context context, ActiveFileInfo activeFileInfo) {
        if (activeFileInfo == null) {
            return 2;
        }
        return nativeGetActiveFile(context, activeFileInfo);
    }

    public int init(Context context, DetectMode detectMode, DetectFaceOrientPriority detectFaceOrientPriority, int i, int i2) {
        if (this.handle != 0) {
            return 5;
        }
        if (context == null || detectMode == null || detectFaceOrientPriority == null) {
            return 2;
        }
        this.handle = nativeInitFaceEngine(context, detectMode.getMode(), detectFaceOrientPriority.getPriority(), i, i2, this.initError);
        if (this.initError.getCode() == 0) {
            if ((i2 & 1) != 0) {
                this.mFaceInfoArray = new FaceInfo[i];
                for (int i3 = 0; i3 < i; i3++) {
                    this.mFaceInfoArray[i3] = new FaceInfo();
                }
            }
            if ((i2 & 8) != 0) {
                this.mAgeInfoArray = new AgeInfo[i];
                for (int i4 = 0; i4 < i; i4++) {
                    this.mAgeInfoArray[i4] = new AgeInfo();
                }
            }
            if ((i2 & 16) != 0) {
                this.mGenderInfoArray = new GenderInfo[i];
                for (int i5 = 0; i5 < i; i5++) {
                    this.mGenderInfoArray[i5] = new GenderInfo();
                }
            }
            if ((i2 & 128) != 0) {
                this.mLivenessInfoArray = new LivenessInfo[i];
                for (int i6 = 0; i6 < i; i6++) {
                    this.mLivenessInfoArray[i6] = new LivenessInfo();
                }
            }
            if ((i2 & 1024) != 0) {
                this.mIrLivenessInfoArray = new LivenessInfo[i];
                for (int i7 = 0; i7 < i; i7++) {
                    this.mIrLivenessInfoArray[i7] = new LivenessInfo();
                }
            }
            if ((i2 & 4096) != 0) {
                this.mMaskInfoArray = new MaskInfo[i];
                for (int i8 = 0; i8 < i; i8++) {
                    this.mMaskInfoArray[i8] = new MaskInfo();
                }
            }
            if ((i2 & 512) != 0) {
                this.imageQualityArray = new float[i];
                for (int i9 = 0; i9 < i; i9++) {
                    this.imageQualityArray[i9] = 0.0f;
                }
            }
        }
        return this.initError.code;
    }

    public int unInit() {
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        int nativeUnInitFaceEngine = nativeUnInitFaceEngine(j);
        if (nativeUnInitFaceEngine == 0) {
            this.handle = 0;
        }
        return nativeUnInitFaceEngine;
    }

    public int setFaceAttributeParam(FaceAttributeParam faceAttributeParam) {
        if (faceAttributeParam == null || faceAttributeParam.getEyeopenThreshold() > 1.0f || faceAttributeParam.getEyeopenThreshold() < 0.0f || faceAttributeParam.getMouthcloseThreshold() > 1.0f || faceAttributeParam.getMouthcloseThreshold() < 0.0f || faceAttributeParam.getWearGlassesThreshold() > 1.0f || faceAttributeParam.getWearGlassesThreshold() < 0.0f) {
            return 2;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        return nativeSetFaceAttributeParam(j, faceAttributeParam);
    }

    public int detectFaces(byte[] bArr, int i, int i2, int i3, List<FaceInfo> list) {
        return detectFaces(bArr, i, i2, i3, DetectModel.RGB, list);
    }

    public int detectFaces(byte[] bArr, int i, int i2, int i3, DetectModel detectModel, List<FaceInfo> list) {
        if (!(i3 == 2050 || i3 == 513 || i3 == 1793 || i3 == 3074)) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (i <= 0 || i2 <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (list == null || bArr == null || detectModel == null) {
            return 2;
        }
        if (!isImageDataValid(bArr, i, i2, i3)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        if (this.handle == 0) {
            return 5;
        }
        list.clear();
        int nativeDetectFaces = nativeDetectFaces(this.handle, bArr, i, i2, i3, detectModel.getModel(), this.mFaceInfoArray, this.detectError);
        if (nativeDetectFaces > 0) {
            for (int i4 = 0; i4 < nativeDetectFaces; i4++) {
                list.add(new FaceInfo(this.mFaceInfoArray[i4]));
            }
        }
        return this.detectError.code;
    }

    public int detectFaces(ArcSoftImageInfo arcSoftImageInfo, List<FaceInfo> list) {
        return detectFaces(arcSoftImageInfo, DetectModel.RGB, list);
    }

    public int detectFaces(ArcSoftImageInfo arcSoftImageInfo, DetectModel detectModel, List<FaceInfo> list) {
        if (list == null || arcSoftImageInfo == null) {
            return 2;
        }
        int imageFormat = arcSoftImageInfo.getImageFormat();
        if (!(imageFormat == 2050 || imageFormat == 513 || imageFormat == 1793 || imageFormat == 3074)) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (arcSoftImageInfo.getWidth() <= 0 || arcSoftImageInfo.getHeight() <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (!isImageDataValid(arcSoftImageInfo)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        if (this.handle == 0) {
            return 5;
        }
        list.clear();
        int nativeDetectFaces = nativeDetectFaces(this.handle, arcSoftImageInfo, detectModel.getModel(), this.mFaceInfoArray, this.detectError);
        if (nativeDetectFaces > 0) {
            for (int i = 0; i < nativeDetectFaces; i++) {
                list.add(new FaceInfo(this.mFaceInfoArray[i]));
            }
        }
        return this.detectError.code;
    }

    public int updateFaceData(byte[] bArr, int i, int i2, int i3, List<FaceInfo> list) {
        if (i3 != 2050 && i3 != 513 && i3 != 1793 && i3 != 3074) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (i <= 0 || i2 <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (list == null || bArr == null) {
            return 2;
        }
        if (!isImageDataValid(bArr, i, i2, i3)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        nativeUpdateFaceData(j, bArr, i, i2, i3, (FaceInfo[]) list.toArray(new FaceInfo[0]), this.faceDataError);
        return this.faceDataError.code;
    }

    public int updateFaceData(ArcSoftImageInfo arcSoftImageInfo, List<FaceInfo> list) {
        if (list == null || arcSoftImageInfo == null) {
            return 2;
        }
        int imageFormat = arcSoftImageInfo.getImageFormat();
        if (imageFormat != 2050 && imageFormat != 513 && imageFormat != 1793 && imageFormat != 3074) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (arcSoftImageInfo.getWidth() <= 0 || arcSoftImageInfo.getHeight() <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (!isImageDataValid(arcSoftImageInfo)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        nativeUpdateFaceData(j, arcSoftImageInfo, (FaceInfo[]) list.toArray(new FaceInfo[0]), this.faceDataError);
        return this.faceDataError.code;
    }

    public int process(byte[] bArr, int i, int i2, int i3, List<FaceInfo> list, int i4) {
        if (i3 != 2050 && i3 != 513) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (i <= 0 || i2 <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (list == null || bArr == null) {
            return 2;
        }
        if (!isImageDataValid(bArr, i, i2, i3)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        nativeProcess(j, bArr, i, i2, i3, (FaceInfo[]) list.toArray(new FaceInfo[0]), i4, this.processError);
        return this.processError.code;
    }

    public int process(ArcSoftImageInfo arcSoftImageInfo, List<FaceInfo> list, int i) {
        if (list == null || arcSoftImageInfo == null) {
            return 2;
        }
        if (arcSoftImageInfo.getImageFormat() != 2050 && arcSoftImageInfo.getImageFormat() != 513) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (arcSoftImageInfo.getWidth() <= 0 || arcSoftImageInfo.getHeight() <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (!isImageDataValid(arcSoftImageInfo)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        nativeProcess(j, arcSoftImageInfo, (FaceInfo[]) list.toArray(new FaceInfo[0]), i, this.processError);
        return this.processError.code;
    }

    public int processIr(byte[] bArr, int i, int i2, int i3, List<FaceInfo> list, int i4) {
        if (i3 != 2050 && i3 != 1793 && i3 != 3074) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (i <= 0 || i2 <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (list == null || bArr == null) {
            return 2;
        }
        if (!isImageDataValid(bArr, i, i2, i3)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        nativeProcessIr(j, bArr, i, i2, i3, (FaceInfo[]) list.toArray(new FaceInfo[0]), i4, this.processIrError);
        return this.processIrError.code;
    }

    public int processIr(ArcSoftImageInfo arcSoftImageInfo, List<FaceInfo> list, int i) {
        if (list == null || arcSoftImageInfo == null) {
            return 2;
        }
        if (arcSoftImageInfo.getImageFormat() != 2050 && arcSoftImageInfo.getImageFormat() != 1793 && arcSoftImageInfo.getImageFormat() != 3074) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (arcSoftImageInfo.getWidth() <= 0 || arcSoftImageInfo.getHeight() <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (!isImageDataValid(arcSoftImageInfo)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        nativeProcessIr(j, arcSoftImageInfo, (FaceInfo[]) list.toArray(new FaceInfo[0]), i, this.processIrError);
        return this.processIrError.code;
    }

    public int imageQualityDetect(byte[] bArr, int i, int i2, int i3, FaceInfo faceInfo, int i4, ImageQualitySimilar imageQualitySimilar) {
        if (i <= 0 || i2 <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (faceInfo == null || bArr == null) {
            return 2;
        }
        if (i3 != 2050 && i3 != 1793 && i3 != 513) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (!isImageDataValid(bArr, i, i2, i3)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        imageQualitySimilar.score = nativeImageQualityDetect(j, bArr, i, i2, i3, faceInfo.getRect(), faceInfo.getOrient(), faceInfo.getFaceData(), 5000, i4, this.detectQualityError);
        return this.detectQualityError.code;
    }

    public int imageQualityDetect(ArcSoftImageInfo arcSoftImageInfo, FaceInfo faceInfo, int i, ImageQualitySimilar imageQualitySimilar) {
        if (faceInfo == null || arcSoftImageInfo == null) {
            return 2;
        }
        if (arcSoftImageInfo.getWidth() <= 0 || arcSoftImageInfo.getHeight() <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (arcSoftImageInfo.getImageFormat() != 2050 && arcSoftImageInfo.getImageFormat() != 1793 && arcSoftImageInfo.getImageFormat() != 513) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (!isImageDataValid(arcSoftImageInfo)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        imageQualitySimilar.score = nativeImageQualityDetect(j, arcSoftImageInfo, faceInfo.getRect(), faceInfo.getOrient(), faceInfo.getFaceData(), 5000, i, this.detectQualityError);
        return this.detectQualityError.code;
    }

    public int extractFaceFeature(byte[] bArr, int i, int i2, int i3, FaceInfo faceInfo, ExtractType extractType, int i4, FaceFeature faceFeature) {
        if (i3 != 2050 && i3 != 513 && i3 != 1793) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (i <= 0 || i2 <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (faceFeature == null || faceFeature.getFeatureData() == null || faceFeature.getFeatureData().length < 2056 || faceInfo == null || extractType == null || bArr == null) {
            return 2;
        }
        if (!isImageDataValid(bArr, i, i2, i3)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        if (this.handle == 0) {
            return 5;
        }
        nativeExtractFaceFeature(this.handle, bArr, i, i2, i3, faceInfo.getRect(), faceInfo.getOrient(), faceInfo.getFaceData(), 5000, extractType.getExtractType(), i4 != 1 ? 0 : i4, faceFeature.getFeatureData(), this.frError);
        return this.frError.code;
    }

    public int extractFaceFeature(ArcSoftImageInfo arcSoftImageInfo, FaceInfo faceInfo, ExtractType extractType, int i, FaceFeature faceFeature) {
        if (faceFeature == null || faceFeature.getFeatureData() == null || faceFeature.getFeatureData().length < 2056 || faceInfo == null || extractType == null || arcSoftImageInfo == null) {
            return 2;
        }
        if (arcSoftImageInfo.getImageFormat() != 2050 && arcSoftImageInfo.getImageFormat() != 513 && arcSoftImageInfo.getImageFormat() != 1793) {
            return ErrorInfo.MERR_ASF_COLOR_SPACE_NOT_SUPPORT;
        }
        if (arcSoftImageInfo.getWidth() <= 0 || arcSoftImageInfo.getHeight() <= 0) {
            return ErrorInfo.MERR_ASF_IMAGE_WIDTH_HEIGHT_NOT_SUPPORT;
        }
        if (!isImageDataValid(arcSoftImageInfo)) {
            return ErrorInfo.MERR_ASF_EX_INVALID_IMAGE_INFO;
        }
        if (this.handle == 0) {
            return 5;
        }
        nativeExtractFaceFeature(this.handle, arcSoftImageInfo, faceInfo.getRect(), faceInfo.getOrient(), faceInfo.getFaceData(), 5000, extractType.getExtractType(), i != 1 ? 0 : i, faceFeature.getFeatureData(), this.frError);
        return this.frError.code;
    }

    public int compareFaceFeature(FaceFeature faceFeature, FaceFeature faceFeature2, FaceSimilar faceSimilar) {
        return compareFaceFeature(faceFeature, faceFeature2, CompareModel.LIFE_PHOTO, faceSimilar);
    }

    public int compareFaceFeature(FaceFeature faceFeature, FaceFeature faceFeature2, CompareModel compareModel, FaceSimilar faceSimilar) {
        if (faceFeature == null || faceFeature.getFeatureData() == null || faceFeature2 == null || faceFeature2.getFeatureData() == null || faceSimilar == null || compareModel == null) {
            return 2;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        faceSimilar.score = nativePairMatching(j, faceFeature.getFeatureData(), faceFeature2.getFeatureData(), compareModel.getModel(), this.frError);
        return this.frError.code;
    }

    public SearchResult searchFaceFeature(FaceFeature faceFeature) throws IllegalArgumentException {
        return searchFaceFeature(faceFeature, CompareModel.LIFE_PHOTO);
    }

    public SearchResult searchFaceFeature(FaceFeature faceFeature, CompareModel compareModel) throws IllegalArgumentException {
        if (faceFeature == null || faceFeature.getFeatureData() == null || compareModel == null) {
            throw new IllegalArgumentException(String.format("%d: invalid parameters", 2));
        }
        long j = this.handle;
        if (j != 0) {
            return nativeSearchFaceFeature(j, faceFeature.getFeatureData(), compareModel.getModel());
        }
        throw new IllegalArgumentException(String.format("%d: bad state", 5));
    }

    public int registerFaceFeature(FaceFeatureInfo faceFeatureInfo) {
        if (faceFeatureInfo == null || faceFeatureInfo.getFeatureData() == null) {
            return 2;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        return nativeRegisterFaceFeature(j, faceFeatureInfo);
    }

    public int registerFaceFeature(List<FaceFeatureInfo> list) {
        if (list == null || list.isEmpty()) {
            return 2;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        return nativeRegisterFaceFeatureArray(j, (FaceFeatureInfo[]) list.toArray(new FaceFeatureInfo[0]));
    }

    public int removeFaceFeature(int i) {
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        return nativeRemoveFaceFeature(j, i);
    }

    public int updateFaceFeature(FaceFeatureInfo faceFeatureInfo) {
        if (faceFeatureInfo == null || faceFeatureInfo.getFeatureData() == null) {
            return 2;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        return nativeUpdateFaceFeature(j, faceFeatureInfo);
    }

    public FaceFeatureInfo getFaceFeature(int i) throws IllegalArgumentException {
        long j = this.handle;
        if (j != 0) {
            return nativeGetFaceFeature(j, i);
        }
        throw new IllegalArgumentException(String.format("%d: bad state", 5));
    }

    public int getFaceCount() throws IllegalArgumentException {
        long j = this.handle;
        if (j != 0) {
            return nativeGetFaceCount(j);
        }
        throw new IllegalArgumentException(String.format("%d: bad state", 5));
    }

    public int getAge(List<AgeInfo> list) {
        if (list == null) {
            return 2;
        }
        if (this.handle == 0) {
            return 5;
        }
        list.clear();
        int nativeGetAge = nativeGetAge(this.handle, this.mAgeInfoArray, this.processError);
        if (nativeGetAge > 0) {
            for (int i = 0; i < nativeGetAge; i++) {
                list.add(new AgeInfo(this.mAgeInfoArray[i]));
            }
        }
        return this.processError.code;
    }

    public int getGender(List<GenderInfo> list) {
        if (list == null) {
            return 2;
        }
        if (this.handle == 0) {
            return 5;
        }
        list.clear();
        int nativeGetGender = nativeGetGender(this.handle, this.mGenderInfoArray, this.processError);
        if (nativeGetGender > 0) {
            for (int i = 0; i < nativeGetGender; i++) {
                list.add(new GenderInfo(this.mGenderInfoArray[i]));
            }
        }
        return this.processError.code;
    }

    public LivenessParam getLivenessParam() throws IllegalArgumentException {
        long j = this.handle;
        if (j != 0) {
            return nativeGetLivenessParam(j);
        }
        throw new IllegalArgumentException(String.format("%d: bad state", 5));
    }

    public int setLivenessParam(LivenessParam livenessParam) {
        if (livenessParam == null || livenessParam.getIrThreshold() > 1.0f || livenessParam.getIrThreshold() < 0.0f || livenessParam.getRgbThreshold() > 1.0f || livenessParam.getRgbThreshold() < 0.0f || livenessParam.getFqThreshold() > 1.0f || livenessParam.getFqThreshold() < 0.0f) {
            return 2;
        }
        long j = this.handle;
        if (j == 0) {
            return 5;
        }
        return nativeSetLivenessParam(j, livenessParam);
    }

    public int getLiveness(List<LivenessInfo> list) {
        if (list == null) {
            return 2;
        }
        if (this.handle == 0) {
            return 5;
        }
        list.clear();
        int nativeGetLiveness = nativeGetLiveness(this.handle, this.mLivenessInfoArray, this.processError);
        for (int i = 0; i < nativeGetLiveness; i++) {
            list.add(new LivenessInfo(this.mLivenessInfoArray[i]));
        }
        return this.processError.code;
    }

    public int getIrLiveness(List<LivenessInfo> list) {
        if (list == null) {
            return 2;
        }
        if (this.handle == 0) {
            return 5;
        }
        list.clear();
        int nativeGetIrLiveness = nativeGetIrLiveness(this.handle, this.mIrLivenessInfoArray, this.processIrError);
        for (int i = 0; i < nativeGetIrLiveness; i++) {
            list.add(new LivenessInfo(this.mIrLivenessInfoArray[i]));
        }
        return this.processIrError.code;
    }

    public int getMask(List<MaskInfo> list) {
        if (list == null) {
            return 2;
        }
        if (this.handle == 0) {
            return 5;
        }
        list.clear();
        int nativeGetMask = nativeGetMask(this.handle, this.mMaskInfoArray, this.processError);
        for (int i = 0; i < nativeGetMask; i++) {
            list.add(new MaskInfo(this.mMaskInfoArray[i]));
        }
        return this.processError.code;
    }

    public static int getVersion(VersionInfo versionInfo) {
        if (versionInfo == null) {
            return 2;
        }
        nativeGetVersion(versionInfo);
        return 0;
    }

    private static boolean isImageDataValid(byte[] bArr, int i, int i2, int i3) {
        return (i3 == 2050 && (i2 & 1) == 0 && bArr.length == ((i * i2) * 3) / 2) || (i3 == 513 && bArr.length == (i * i2) * 3) || ((i3 == 1793 && bArr.length == i * i2) || (i3 == 3074 && bArr.length == (i * i2) * 2));
    }

    private static boolean isImageDataValid(ArcSoftImageInfo arcSoftImageInfo) {
        byte[][] planes = arcSoftImageInfo.getPlanes();
        int[] strides = arcSoftImageInfo.getStrides();
        if (planes == null || strides == null || planes.length != strides.length) {
            return false;
        }
        for (byte[] bArr : planes) {
            if (bArr == null || bArr.length == 0) {
                return false;
            }
        }
        int imageFormat = arcSoftImageInfo.getImageFormat();
        if (!(imageFormat == 513 || imageFormat == 1793)) {
            if (imageFormat != 2050) {
                if (imageFormat != 3074) {
                    return false;
                }
            } else if ((arcSoftImageInfo.getHeight() & 1) == 0 && planes.length == 2 && planes[0].length == planes[1].length * 2 && planes[0].length == arcSoftImageInfo.getStrides()[0] * arcSoftImageInfo.getHeight() && planes[1].length == (arcSoftImageInfo.getStrides()[1] * arcSoftImageInfo.getHeight()) / 2) {
                return true;
            } else {
                return false;
            }
        }
        if (planes.length == 1 && planes[0].length == arcSoftImageInfo.getStrides()[0] * arcSoftImageInfo.getHeight()) {
            return true;
        }
        return false;
    }

    static {
        System.loadLibrary("arcsoft_face_engine");
    }
}
