package com.arcsoft.face.util;

import android.graphics.Bitmap;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.support.v4.view.ViewCompat;
import java.nio.ByteBuffer;

public class ImageUtils {
    private static final int FACE_DETECT_IMAGE_HEIGHT_LIMIT = 2;
    private static final int FACE_DETECT_IMAGE_WIDTH_LIMIT = 4;
    private static final int VALUE_FOR_2_ALIGN = 1;
    private static final int VALUE_FOR_4_ALIGN = 3;

    public static byte[] bitmapToBgr24(Bitmap bitmap) {
        if (bitmap == null) {
            return null;
        }
        if (bitmap.getConfig() != Bitmap.Config.ARGB_8888) {
            bitmap = bitmap.copy(Bitmap.Config.ARGB_8888, true);
        }
        ByteBuffer allocate = ByteBuffer.allocate(bitmap.getByteCount());
        bitmap.copyPixelsToBuffer(allocate);
        byte[] array = allocate.array();
        int length = array.length / 4;
        byte[] bArr = new byte[(length * 3)];
        int i = 0;
        int i2 = 0;
        for (int i3 = 0; i3 < length; i3++) {
            bArr[i] = array[i2 + 2];
            bArr[i + 1] = array[i2 + 1];
            bArr[i + 2] = array[i2];
            i += 3;
            i2 += 4;
        }
        return bArr;
    }

    public static Bitmap bgrToBitmap(byte[] bArr, int i, int i2) {
        int[] convertBgrToColor = convertBgrToColor(bArr);
        if (convertBgrToColor == null) {
            return null;
        }
        return Bitmap.createBitmap(convertBgrToColor, 0, i, i, i2, Bitmap.Config.ARGB_8888);
    }

    private static int[] convertBgrToColor(byte[] bArr) {
        int length = bArr.length;
        if (length == 0 || length % 3 != 0) {
            return null;
        }
        int i = length / 3;
        int[] iArr = new int[i];
        int i2 = 0;
        for (int i3 = 0; i3 < i; i3++) {
            iArr[i3] = ((bArr[i2 + 2] & 255) << 16) | ((bArr[i2 + 1] & 255) << 8) | (bArr[i2] & 255) | ViewCompat.MEASURED_STATE_MASK;
            i2 += 3;
        }
        return iArr;
    }

    public static Bitmap alignBitmapForBgr24(Bitmap bitmap) {
        if (bitmap == null || bitmap.getWidth() < 4) {
            return null;
        }
        int width = bitmap.getWidth();
        return (width & 3) != 0 ? cropImage(bitmap, new Rect(0, 0, width & -4, bitmap.getHeight())) : bitmap;
    }

    public static Bitmap cropImage(Bitmap bitmap, Rect rect) {
        if (bitmap == null || rect == null || rect.isEmpty() || bitmap.getWidth() < rect.right || bitmap.getHeight() < rect.bottom) {
            return null;
        }
        return Bitmap.createBitmap(bitmap, rect.left, rect.top, rect.width(), rect.height(), (Matrix) null, false);
    }

    public static Bitmap rotateBitmap(Bitmap bitmap, float f) {
        if (bitmap == null) {
            return null;
        }
        Matrix matrix = new Matrix();
        matrix.postRotate(f);
        return Bitmap.createBitmap(bitmap, 0, 0, bitmap.getWidth(), bitmap.getHeight(), matrix, false);
    }

    public static byte[] cropNv21(byte[] bArr, int i, int i2, Rect rect) {
        if (!(bArr == null || bArr.length == 0)) {
            int i3 = i * i2;
            if ((i3 * 3) / 2 == bArr.length && rect != null) {
                if (rect.left < 0 || rect.top < 0 || rect.right > i || rect.bottom > i2) {
                    throw new IllegalArgumentException("rect out of bounds!");
                } else if (rect.right <= rect.left || rect.bottom <= rect.top) {
                    throw new IllegalArgumentException("invalid rect!");
                } else if (((rect.right - rect.left) & 1) == 1 || ((rect.bottom - rect.top) & 1) == 1) {
                    throw new IllegalArgumentException("nv21 width and height must be even!");
                } else {
                    int i4 = rect.right - rect.left;
                    int i5 = (rect.bottom - rect.top) * i4;
                    byte[] bArr2 = new byte[((i5 * 3) / 2)];
                    int i6 = rect.top * i;
                    int i7 = 0;
                    int i8 = i3 + ((rect.top * i) / 2);
                    for (int i9 = rect.top; i9 < rect.bottom; i9++) {
                        System.arraycopy(bArr, rect.left + i6, bArr2, i7, i4);
                        i6 += i;
                        i7 += i4;
                        if ((i9 & 1) == 0) {
                            System.arraycopy(bArr, rect.left + i8, bArr2, i5, i4);
                            i8 += i;
                            i5 += i4;
                        }
                    }
                    return bArr2;
                }
            }
        }
        throw new IllegalArgumentException("invalid image params!");
    }

    public static byte[] cropBgr24(byte[] bArr, int i, int i2, Rect rect) {
        if (bArr == null || bArr.length == 0 || i * i2 * 3 != bArr.length || rect == null) {
            throw new IllegalArgumentException("invalid image params!");
        } else if (rect.left < 0 || rect.top < 0 || rect.right > i || rect.bottom > i2) {
            throw new IllegalArgumentException("rect out of bounds!");
        } else if (rect.right <= rect.left || rect.bottom <= rect.top) {
            throw new IllegalArgumentException("invalid rect!");
        } else {
            int i3 = rect.right - rect.left;
            byte[] bArr2 = new byte[((rect.bottom - rect.top) * i3 * 3)];
            int i4 = rect.top * i * 3;
            int i5 = 0;
            for (int i6 = rect.top; i6 < rect.bottom; i6++) {
                int i7 = i3 * 3;
                System.arraycopy(bArr, (rect.left * 3) + i4, bArr2, i5, i7);
                i4 += i * 3;
                i5 += i7;
            }
            return bArr2;
        }
    }
}
