package com.artifex.mupdf;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.database.Cursor;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.RectF;
import android.graphics.drawable.BitmapDrawable;
import android.net.Uri;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.text.Editable;
import android.text.TextWatcher;
import android.text.method.PasswordTransformationMethod;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.ScaleGestureDetector;
import android.view.View;
import android.view.ViewGroup;
import android.view.animation.Animation;
import android.view.animation.TranslateAnimation;
import android.view.inputmethod.InputMethodManager;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.RelativeLayout;
import android.widget.SeekBar;
import android.widget.TextView;
import android.widget.ViewSwitcher;
import com.apicloud.pdfReader.BtnConfig;
import com.apicloud.pdfReader.PdfReader;
import com.apicloud.pdfReader.Utils;
import com.uzmap.pkg.uzcore.UZResourcesIDFinder;
import com.uzmap.pkg.uzkit.UZUtility;
import java.io.PrintStream;

public class MuPDFActivity extends Activity {
    private static final int SEARCH_PROGRESS_DELAY = 200;
    private final int TAP_PAGE_MARGIN = 5;
    private MuPDFCore core;
    private AlertDialog.Builder mAlertBuilder;
    private TextView mBackButton;
    private View mButtonsView;
    private boolean mButtonsVisible;
    private ImageButton mCancelButton;
    private BtnConfig mConfig;
    private ReaderView mDocView;
    private String mFileName;
    private TextView mFilenameView;
    private final Handler mHandler = new Handler();
    private LinkState mLinkState = LinkState.DEFAULT;
    private ImageButton mOutlineButton;
    private TextView mPageNumberView;
    private SeekBar mPageSlider;
    private EditText mPasswordView;
    private ImageButton mSearchBack;
    private ImageButton mSearchButton;
    private ImageButton mSearchFwd;
    private AsyncTask<Integer, Integer, SearchTaskResult> mSearchTask;
    private EditText mSearchText;
    private boolean mTopBarIsSearch;
    private ViewSwitcher mTopBarSwitcher;

    /* access modifiers changed from: private */
    public enum LinkState {
        DEFAULT,
        HIGHLIGHT,
        INHIBIT
    }

    private MuPDFCore openFile(String str) {
        String str2;
        int lastIndexOf = str.lastIndexOf(47);
        if (lastIndexOf == -1) {
            str2 = str;
        } else {
            str2 = str.substring(lastIndexOf + 1);
        }
        this.mFileName = new String(str2);
        PrintStream printStream = System.out;
        printStream.println("Trying to open " + str);
        try {
            this.core = new MuPDFCore(str);
            OutlineActivityData.set(null);
            return this.core;
        } catch (Exception e) {
            System.out.println(e);
            return null;
        }
    }

    public void onCreate(Bundle bundle) {
        super.onCreate(bundle);
        this.mConfig = (BtnConfig) getIntent().getSerializableExtra(PdfReader.BACK_BTN_TAG);
        this.mAlertBuilder = new AlertDialog.Builder(this);
        if (this.core == null) {
            this.core = (MuPDFCore) getLastNonConfigurationInstance();
            if (bundle != null && bundle.containsKey("FileName")) {
                this.mFileName = bundle.getString("FileName");
            }
        }
        if (this.core == null) {
            Intent intent = getIntent();
            if ("android.intent.action.VIEW".equals(intent.getAction())) {
                Uri data = intent.getData();
                if (data.toString().startsWith("content://media/external/file")) {
                    Cursor query = getContentResolver().query(data, new String[]{"_data"}, null, null, null);
                    if (query.moveToFirst()) {
                        data = Uri.parse(query.getString(0));
                    }
                }
                this.core = openFile(Uri.decode(data.getEncodedPath()));
            }
            MuPDFCore muPDFCore = this.core;
            if (muPDFCore != null && muPDFCore.needsPassword()) {
                requestPassword(bundle);
                return;
            }
        }
        if (this.core == null) {
            AlertDialog create = this.mAlertBuilder.create();
            create.setTitle(UZResourcesIDFinder.getResStringID("open_failed"));
            create.setButton(-1, "Dismiss", new DialogInterface.OnClickListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass1 */

                public void onClick(DialogInterface dialogInterface, int i) {
                    MuPDFActivity.this.finish();
                }
            });
            create.show();
            return;
        }
        createUI(bundle);
    }

    public void requestPassword(final Bundle bundle) {
        EditText editText = new EditText(this);
        this.mPasswordView = editText;
        editText.setInputType(128);
        this.mPasswordView.setTransformationMethod(new PasswordTransformationMethod());
        AlertDialog create = this.mAlertBuilder.create();
        create.setTitle(UZResourcesIDFinder.getResStringID("enter_password"));
        create.setView(this.mPasswordView);
        create.setButton(-1, "Ok", new DialogInterface.OnClickListener() {
            /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass2 */

            public void onClick(DialogInterface dialogInterface, int i) {
                if (MuPDFActivity.this.core.authenticatePassword(MuPDFActivity.this.mPasswordView.getText().toString())) {
                    MuPDFActivity.this.createUI(bundle);
                } else {
                    MuPDFActivity.this.requestPassword(bundle);
                }
            }
        });
        create.setButton(-2, "Cancel", new DialogInterface.OnClickListener() {
            /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass3 */

            public void onClick(DialogInterface dialogInterface, int i) {
                MuPDFActivity.this.finish();
            }
        });
        create.show();
    }

    public void createUI(Bundle bundle) {
        if (this.core != null) {
            AnonymousClass4 r0 = new ReaderView(this) {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass4 */
                private boolean showButtonsDisabled;

                @Override // com.artifex.mupdf.ReaderView
                public boolean onSingleTapUp(MotionEvent motionEvent) {
                    if (motionEvent.getX() < ((float) (super.getWidth() / 5))) {
                        super.moveToPrevious();
                    } else if (motionEvent.getX() > ((float) ((super.getWidth() * 4) / 5))) {
                        super.moveToNext();
                    } else if (!this.showButtonsDisabled) {
                        if (MuPDFActivity.this.mLinkState != LinkState.INHIBIT) {
                            MuPDFPageView muPDFPageView = (MuPDFPageView) MuPDFActivity.this.mDocView.getDisplayedView();
                        }
                        if (!MuPDFActivity.this.mButtonsVisible) {
                            MuPDFActivity.this.showButtons();
                        } else {
                            MuPDFActivity.this.hideButtons();
                        }
                    }
                    return super.onSingleTapUp(motionEvent);
                }

                @Override // com.artifex.mupdf.ReaderView
                public boolean onScroll(MotionEvent motionEvent, MotionEvent motionEvent2, float f, float f2) {
                    if (!this.showButtonsDisabled) {
                        MuPDFActivity.this.hideButtons();
                    }
                    return super.onScroll(motionEvent, motionEvent2, f, f2);
                }

                @Override // com.artifex.mupdf.ReaderView
                public boolean onScaleBegin(ScaleGestureDetector scaleGestureDetector) {
                    this.showButtonsDisabled = true;
                    return super.onScaleBegin(scaleGestureDetector);
                }

                @Override // com.artifex.mupdf.ReaderView
                public boolean onTouchEvent(MotionEvent motionEvent) {
                    if (motionEvent.getActionMasked() == 0) {
                        this.showButtonsDisabled = false;
                    }
                    return super.onTouchEvent(motionEvent);
                }

                /* access modifiers changed from: protected */
                @Override // com.artifex.mupdf.ReaderView
                public void onChildSetup(int i, View view) {
                    if (SearchTaskResult.get() == null || SearchTaskResult.get().pageNumber != i) {
                        ((PageView) view).setSearchBoxes(null);
                    } else {
                        ((PageView) view).setSearchBoxes(SearchTaskResult.get().searchBoxes);
                    }
                    ((PageView) view).setLinkHighlighting(MuPDFActivity.this.mLinkState == LinkState.HIGHLIGHT);
                }

                /* access modifiers changed from: protected */
                @Override // com.artifex.mupdf.ReaderView
                public void onMoveToChild(int i) {
                    if (MuPDFActivity.this.core != null) {
                        MuPDFActivity.this.mPageNumberView.setText(String.format("%d/%d", Integer.valueOf(i + 1), Integer.valueOf(MuPDFActivity.this.core.countPages())));
                        MuPDFActivity.this.mPageSlider.setMax(MuPDFActivity.this.core.countPages() - 1);
                        MuPDFActivity.this.mPageSlider.setProgress(i);
                        if (SearchTaskResult.get() != null && SearchTaskResult.get().pageNumber != i) {
                            SearchTaskResult.set(null);
                            MuPDFActivity.this.mDocView.resetupChildren();
                        }
                    }
                }

                /* access modifiers changed from: protected */
                @Override // com.artifex.mupdf.ReaderView
                public void onSettle(View view) {
                    ((PageView) view).addHq();
                }

                /* access modifiers changed from: protected */
                @Override // com.artifex.mupdf.ReaderView
                public void onUnsettle(View view) {
                    ((PageView) view).removeHq();
                }
            };
            this.mDocView = r0;
            r0.setAdapter(new MuPDFPageAdapter(this, this.core));
            makeButtonsView();
            this.mFilenameView.setText(this.mFileName);
            this.mPageSlider.setOnSeekBarChangeListener(new SeekBar.OnSeekBarChangeListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass5 */

                public void onStartTrackingTouch(SeekBar seekBar) {
                }

                public void onStopTrackingTouch(SeekBar seekBar) {
                    MuPDFActivity.this.mDocView.setDisplayedViewIndex(seekBar.getProgress());
                }

                public void onProgressChanged(SeekBar seekBar, int i, boolean z) {
                    MuPDFActivity.this.updatePageNumView(i);
                }
            });
            this.mSearchButton.setOnClickListener(new View.OnClickListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass6 */

                public void onClick(View view) {
                    MuPDFActivity.this.searchModeOn();
                }
            });
            this.mBackButton.setOnClickListener(new View.OnClickListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass7 */

                public void onClick(View view) {
                    MuPDFActivity.this.finish();
                }
            });
            this.mCancelButton.setOnClickListener(new View.OnClickListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass8 */

                public void onClick(View view) {
                    MuPDFActivity.this.searchModeOff();
                }
            });
            this.mSearchBack.setEnabled(false);
            this.mSearchFwd.setEnabled(false);
            this.mSearchText.addTextChangedListener(new TextWatcher() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass9 */

                public void beforeTextChanged(CharSequence charSequence, int i, int i2, int i3) {
                }

                public void onTextChanged(CharSequence charSequence, int i, int i2, int i3) {
                }

                public void afterTextChanged(Editable editable) {
                    boolean z = editable.toString().length() > 0;
                    MuPDFActivity.this.mSearchBack.setEnabled(z);
                    MuPDFActivity.this.mSearchFwd.setEnabled(z);
                    if (SearchTaskResult.get() != null && !MuPDFActivity.this.mSearchText.getText().toString().equals(SearchTaskResult.get().txt)) {
                        SearchTaskResult.set(null);
                        MuPDFActivity.this.mDocView.resetupChildren();
                    }
                }
            });
            this.mSearchText.setOnEditorActionListener(new TextView.OnEditorActionListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass10 */

                public boolean onEditorAction(TextView textView, int i, KeyEvent keyEvent) {
                    if (i != 6) {
                        return false;
                    }
                    MuPDFActivity.this.search(1);
                    return false;
                }
            });
            this.mSearchText.setOnKeyListener(new View.OnKeyListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass11 */

                public boolean onKey(View view, int i, KeyEvent keyEvent) {
                    if (keyEvent.getAction() != 0 || i != 66) {
                        return false;
                    }
                    MuPDFActivity.this.search(1);
                    return false;
                }
            });
            this.mSearchBack.setOnClickListener(new View.OnClickListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass12 */

                public void onClick(View view) {
                    MuPDFActivity.this.search(-1);
                }
            });
            this.mSearchFwd.setOnClickListener(new View.OnClickListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass13 */

                public void onClick(View view) {
                    MuPDFActivity.this.search(1);
                }
            });
            if (this.core.hasOutline()) {
                this.mOutlineButton.setOnClickListener(new View.OnClickListener() {
                    /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass14 */

                    public void onClick(View view) {
                        OutlineItem[] outline = MuPDFActivity.this.core.getOutline();
                        if (outline != null) {
                            OutlineActivityData.get().items = outline;
                            MuPDFActivity.this.startActivityForResult(new Intent(MuPDFActivity.this, OutlineActivity.class), 0);
                        }
                    }
                });
            } else {
                this.mOutlineButton.setVisibility(8);
            }
            SharedPreferences preferences = getPreferences(0);
            ReaderView readerView = this.mDocView;
            readerView.setDisplayedViewIndex(preferences.getInt("page" + this.mFileName, 0));
            if (bundle == null || !bundle.getBoolean("ButtonsHidden", false)) {
                showButtons();
            }
            if (bundle != null && bundle.getBoolean("SearchMode", false)) {
                searchModeOn();
            }
            RelativeLayout relativeLayout = new RelativeLayout(this);
            relativeLayout.addView(this.mDocView);
            relativeLayout.addView(this.mButtonsView);
            relativeLayout.setBackgroundResource(UZResourcesIDFinder.getResDrawableID("tiled_background"));
            setContentView(relativeLayout);
        }
    }

    /* access modifiers changed from: protected */
    public void onActivityResult(int i, int i2, Intent intent) {
        if (i2 >= 0) {
            this.mDocView.setDisplayedViewIndex(i2);
        }
        super.onActivityResult(i, i2, intent);
    }

    public Object onRetainNonConfigurationInstance() {
        MuPDFCore muPDFCore = this.core;
        this.core = null;
        return muPDFCore;
    }

    /* access modifiers changed from: protected */
    public void onSaveInstanceState(Bundle bundle) {
        super.onSaveInstanceState(bundle);
        String str = this.mFileName;
        if (!(str == null || this.mDocView == null)) {
            bundle.putString("FileName", str);
            SharedPreferences.Editor edit = getPreferences(0).edit();
            edit.putInt("page" + this.mFileName, this.mDocView.getDisplayedViewIndex());
            edit.commit();
        }
        if (!this.mButtonsVisible) {
            bundle.putBoolean("ButtonsHidden", true);
        }
        if (this.mTopBarIsSearch) {
            bundle.putBoolean("SearchMode", true);
        }
    }

    /* access modifiers changed from: protected */
    public void onPause() {
        super.onPause();
        killSearch();
        if (this.mFileName != null && this.mDocView != null) {
            SharedPreferences.Editor edit = getPreferences(0).edit();
            edit.putInt("page" + this.mFileName, this.mDocView.getDisplayedViewIndex());
            edit.commit();
        }
    }

    public void onDestroy() {
        MuPDFCore muPDFCore = this.core;
        if (muPDFCore != null) {
            muPDFCore.onDestroy();
        }
        this.core = null;
        super.onDestroy();
    }

    /* access modifiers changed from: package-private */
    public void showButtons() {
        if (this.core != null && !this.mButtonsVisible) {
            this.mButtonsVisible = true;
            int displayedViewIndex = this.mDocView.getDisplayedViewIndex();
            updatePageNumView(displayedViewIndex);
            this.mPageSlider.setMax(this.core.countPages() - 1);
            this.mPageSlider.setProgress(displayedViewIndex);
            if (this.mTopBarIsSearch) {
                this.mSearchText.requestFocus();
                showKeyboard();
            }
            TranslateAnimation translateAnimation = new TranslateAnimation(0.0f, 0.0f, (float) (-this.mTopBarSwitcher.getHeight()), 0.0f);
            translateAnimation.setDuration(200);
            translateAnimation.setAnimationListener(new Animation.AnimationListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass15 */

                public void onAnimationEnd(Animation animation) {
                }

                public void onAnimationRepeat(Animation animation) {
                }

                public void onAnimationStart(Animation animation) {
                    MuPDFActivity.this.mTopBarSwitcher.setVisibility(0);
                }
            });
            this.mTopBarSwitcher.startAnimation(translateAnimation);
            TranslateAnimation translateAnimation2 = new TranslateAnimation(0.0f, 0.0f, (float) this.mPageSlider.getHeight(), 0.0f);
            translateAnimation2.setDuration(200);
            translateAnimation2.setAnimationListener(new Animation.AnimationListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass16 */

                public void onAnimationRepeat(Animation animation) {
                }

                public void onAnimationStart(Animation animation) {
                    MuPDFActivity.this.mPageSlider.setVisibility(0);
                }

                public void onAnimationEnd(Animation animation) {
                    MuPDFActivity.this.mPageNumberView.setVisibility(0);
                }
            });
            if (this.mConfig.bottomProgress) {
                this.mPageSlider.startAnimation(translateAnimation2);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void hideButtons() {
        if (this.mButtonsVisible) {
            this.mButtonsVisible = false;
            hideKeyboard();
            TranslateAnimation translateAnimation = new TranslateAnimation(0.0f, 0.0f, 0.0f, (float) (-this.mTopBarSwitcher.getHeight()));
            translateAnimation.setDuration(200);
            translateAnimation.setAnimationListener(new Animation.AnimationListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass17 */

                public void onAnimationRepeat(Animation animation) {
                }

                public void onAnimationStart(Animation animation) {
                }

                public void onAnimationEnd(Animation animation) {
                    MuPDFActivity.this.mTopBarSwitcher.setVisibility(4);
                }
            });
            this.mTopBarSwitcher.startAnimation(translateAnimation);
            TranslateAnimation translateAnimation2 = new TranslateAnimation(0.0f, 0.0f, 0.0f, (float) this.mPageSlider.getHeight());
            translateAnimation2.setDuration(200);
            translateAnimation2.setAnimationListener(new Animation.AnimationListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass18 */

                public void onAnimationRepeat(Animation animation) {
                }

                public void onAnimationStart(Animation animation) {
                    MuPDFActivity.this.mPageNumberView.setVisibility(4);
                }

                public void onAnimationEnd(Animation animation) {
                    MuPDFActivity.this.mPageSlider.setVisibility(4);
                }
            });
            if (this.mConfig.bottomProgress) {
                this.mPageSlider.startAnimation(translateAnimation2);
            }
        }
    }

    /* access modifiers changed from: package-private */
    public void searchModeOn() {
        this.mTopBarIsSearch = true;
        this.mSearchText.requestFocus();
        showKeyboard();
        this.mTopBarSwitcher.showNext();
    }

    /* access modifiers changed from: package-private */
    public void searchModeOff() {
        this.mTopBarIsSearch = false;
        hideKeyboard();
        this.mTopBarSwitcher.showPrevious();
        SearchTaskResult.set(null);
        this.mDocView.resetupChildren();
    }

    /* access modifiers changed from: package-private */
    public void updatePageNumView(int i) {
        if (this.core != null) {
            this.mPageNumberView.setText(String.format("%d/%d", Integer.valueOf(i + 1), Integer.valueOf(this.core.countPages())));
        }
    }

    /* access modifiers changed from: package-private */
    public void makeButtonsView() {
        Bitmap bitmap;
        Bitmap bitmap2;
        this.mButtonsView = getLayoutInflater().inflate(UZResourcesIDFinder.getResLayoutID("buttons"), (ViewGroup) null);
        this.mBackButton = (TextView) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID(PdfReader.BACK_BTN_TAG));
        BtnConfig btnConfig = this.mConfig;
        if (btnConfig != null && !btnConfig.isNull) {
            RelativeLayout.LayoutParams layoutParams = (RelativeLayout.LayoutParams) this.mBackButton.getLayoutParams();
            layoutParams.width = this.mConfig.w;
            layoutParams.height = this.mConfig.h;
            Bitmap localImage = UZUtility.getLocalImage(this.mConfig.bgNormal);
            if (localImage != null) {
                bitmap = Utils.getRoundBitmap(localImage, this.mConfig.corner, this.mConfig.w, this.mConfig.h);
            } else {
                bitmap = Utils.getRoundBitmap(Utils.createColorBitmap(UZUtility.parseCssColor(this.mConfig.bgNormal), this.mConfig.w, this.mConfig.h), this.mConfig.corner, this.mConfig.w, this.mConfig.h);
            }
            Bitmap localImage2 = UZUtility.getLocalImage(this.mConfig.bgHighlight);
            if (localImage2 != null) {
                bitmap2 = Utils.getRoundBitmap(localImage2, this.mConfig.corner, this.mConfig.w, this.mConfig.h);
            } else {
                bitmap2 = Utils.getRoundBitmap(Utils.createColorBitmap(UZUtility.parseCssColor(this.mConfig.bgHighlight), this.mConfig.w, this.mConfig.h), this.mConfig.corner, this.mConfig.w, this.mConfig.h);
            }
            this.mBackButton.setBackgroundDrawable(Utils.addStateDrawable(new BitmapDrawable(bitmap), new BitmapDrawable(bitmap2)));
            this.mBackButton.setText(this.mConfig.titleText);
            this.mBackButton.setTextColor(UZUtility.parseCssColor(this.mConfig.titleColor));
            this.mBackButton.setTextSize((float) this.mConfig.titleSize);
            if ("left".equals(this.mConfig.titleAlignment)) {
                this.mBackButton.setGravity(19);
            } else if ("right".equals(this.mConfig.titleAlignment)) {
                this.mBackButton.setGravity(21);
            } else {
                this.mBackButton.setGravity(17);
            }
        }
        BtnConfig btnConfig2 = this.mConfig;
        if (btnConfig2 != null && btnConfig2.isNull) {
            RelativeLayout.LayoutParams layoutParams2 = (RelativeLayout.LayoutParams) this.mBackButton.getLayoutParams();
            layoutParams2.width = this.mConfig.w;
            layoutParams2.height = this.mConfig.h;
            this.mBackButton.setBackgroundDrawable(new BitmapDrawable(BitmapFactory.decodeResource(getResources(), UZResourcesIDFinder.getResDrawableID("ic_arrow_left"))));
            this.mBackButton.setLayoutParams(layoutParams2);
        }
        this.mFilenameView = (TextView) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("docNameText"));
        this.mPageSlider = (SeekBar) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("pageSlider"));
        this.mPageNumberView = (TextView) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("pageNumber"));
        this.mSearchButton = (ImageButton) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("searchButton"));
        this.mCancelButton = (ImageButton) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("cancel"));
        this.mOutlineButton = (ImageButton) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("outlineButton"));
        this.mTopBarSwitcher = (ViewSwitcher) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("switcher"));
        this.mSearchBack = (ImageButton) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("searchBack"));
        this.mSearchFwd = (ImageButton) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("searchForward"));
        this.mSearchText = (EditText) this.mButtonsView.findViewById(UZResourcesIDFinder.getResIdID("searchText"));
        this.mTopBarSwitcher.setVisibility(4);
        this.mPageNumberView.setVisibility(4);
        this.mPageSlider.setVisibility(4);
        if (!this.mConfig.topBackButton) {
            this.mBackButton.setVisibility(4);
        }
        if (!this.mConfig.topListButton) {
            this.mOutlineButton.setVisibility(4);
        }
        if (!this.mConfig.topSearchButton) {
            this.mSearchButton.setVisibility(4);
        }
    }

    /* access modifiers changed from: package-private */
    public void showKeyboard() {
        InputMethodManager inputMethodManager = (InputMethodManager) getSystemService("input_method");
        if (inputMethodManager != null) {
            inputMethodManager.showSoftInput(this.mSearchText, 0);
        }
    }

    /* access modifiers changed from: package-private */
    public void hideKeyboard() {
        InputMethodManager inputMethodManager = (InputMethodManager) getSystemService("input_method");
        if (inputMethodManager != null) {
            inputMethodManager.hideSoftInputFromWindow(this.mSearchText.getWindowToken(), 0);
        }
    }

    /* access modifiers changed from: package-private */
    public void killSearch() {
        AsyncTask<Integer, Integer, SearchTaskResult> asyncTask = this.mSearchTask;
        if (asyncTask != null) {
            asyncTask.cancel(true);
            this.mSearchTask = null;
        }
    }

    /* access modifiers changed from: package-private */
    public void search(int i) {
        hideKeyboard();
        if (this.core != null) {
            killSearch();
            final ProgressDialogX progressDialogX = new ProgressDialogX(this);
            progressDialogX.setProgressStyle(1);
            progressDialogX.setTitle(getString(UZResourcesIDFinder.getResStringID("searching_")));
            progressDialogX.setOnCancelListener(new DialogInterface.OnCancelListener() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass19 */

                public void onCancel(DialogInterface dialogInterface) {
                    MuPDFActivity.this.killSearch();
                }
            });
            progressDialogX.setMax(this.core.countPages());
            AnonymousClass20 r2 = new AsyncTask<Integer, Integer, SearchTaskResult>() {
                /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass20 */

                /* access modifiers changed from: protected */
                public SearchTaskResult doInBackground(Integer... numArr) {
                    int i;
                    int intValue;
                    if (SearchTaskResult.get() == null) {
                        i = MuPDFActivity.this.mDocView.getDisplayedViewIndex();
                        if (i >= 0 || i >= MuPDFActivity.this.core.countPages() || isCancelled()) {
                            return null;
                        }
                        publishProgress(Integer.valueOf(i));
                        RectF[] searchPage = MuPDFActivity.this.core.searchPage(i, MuPDFActivity.this.mSearchText.getText().toString());
                        if (searchPage != null && searchPage.length > 0) {
                            return new SearchTaskResult(MuPDFActivity.this.mSearchText.getText().toString(), i, searchPage);
                        }
                        intValue = numArr[0].intValue();
                        intValue = numArr[0].intValue();
                    } else {
                        i = SearchTaskResult.get().pageNumber;
                        intValue = numArr[0].intValue();
                    }
                    i += intValue;
                    if (i >= 0) {
                        return null;
                    }
                    return null;
                }

                /* access modifiers changed from: protected */
                public void onPostExecute(SearchTaskResult searchTaskResult) {
                    progressDialogX.cancel();
                    if (searchTaskResult != null) {
                        MuPDFActivity.this.mDocView.setDisplayedViewIndex(searchTaskResult.pageNumber);
                        SearchTaskResult.set(searchTaskResult);
                        MuPDFActivity.this.mDocView.resetupChildren();
                        return;
                    }
                    MuPDFActivity.this.mAlertBuilder.setTitle(UZResourcesIDFinder.getResStringID("text_not_found"));
                    AlertDialog create = MuPDFActivity.this.mAlertBuilder.create();
                    create.setButton(-1, "Dismiss", (DialogInterface.OnClickListener) null);
                    create.show();
                }

                /* access modifiers changed from: protected */
                public void onCancelled() {
                    super.onCancelled();
                    progressDialogX.cancel();
                }

                /* access modifiers changed from: protected */
                public void onProgressUpdate(Integer... numArr) {
                    super.onProgressUpdate((Object[]) numArr);
                    progressDialogX.setProgress(numArr[0].intValue());
                }

                /* access modifiers changed from: protected */
                public void onPreExecute() {
                    super.onPreExecute();
                    MuPDFActivity.this.mHandler.postDelayed(new Runnable() {
                        /* class com.artifex.mupdf.MuPDFActivity.AnonymousClass20.AnonymousClass1 */

                        public void run() {
                            if (!progressDialogX.isCancelled()) {
                                progressDialogX.show();
                            }
                        }
                    }, 200);
                }
            };
            this.mSearchTask = r2;
            r2.execute(new Integer(i));
        }
    }
}
