package com.artifex.mupdf;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.RectF;
import android.os.AsyncTask;
import android.os.Build;
import android.os.Handler;
import android.support.v4.widget.ExploreByTouchHelper;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.ProgressBar;
import com.uzmap.pkg.uzcore.UZResourcesIDFinder;

public abstract class PageView extends ViewGroup {
    private static final int BACKGROUND_COLOR = -1;
    private static final int HIGHLIGHT_COLOR = -2141891073;
    private static final int LINK_COLOR = -2130719608;
    private static final int PROGRESS_DIALOG_DELAY = 200;
    private ProgressBar mBusyIndicator;
    private final Context mContext;
    private AsyncTask<Void, Void, LinkInfo[]> mDrawEntire;
    private AsyncTask<PatchInfo, Void, PatchInfo> mDrawPatch;
    private ImageView mEntire;
    private Bitmap mEntireBm;
    private final Handler mHandler = new Handler();
    private boolean mHighlightLinks;
    private boolean mIsBlank;
    private LinkInfo[] mLinks;
    protected int mPageNumber;
    private Point mParentSize;
    private ImageView mPatch;
    private Rect mPatchArea;
    private Point mPatchViewSize;
    private RectF[] mSearchBoxes;
    private View mSearchView;
    protected Point mSize;
    protected float mSourceScale;
    private boolean mUsingHardwareAcceleration;

    /* access modifiers changed from: protected */
    public abstract void drawPage(Bitmap bitmap, int i, int i2, int i3, int i4, int i5, int i6);

    /* access modifiers changed from: protected */
    public abstract LinkInfo[] getLinkInfo();

    public boolean isOpaque() {
        return true;
    }

    public PageView(Context context, Point point) {
        super(context);
        this.mContext = context;
        this.mParentSize = point;
        setBackgroundColor(-1);
        this.mUsingHardwareAcceleration = Build.VERSION.SDK != null && Integer.valueOf(Build.VERSION.SDK).intValue() >= 14;
    }

    public void blank(int i) {
        AsyncTask<Void, Void, LinkInfo[]> asyncTask = this.mDrawEntire;
        if (asyncTask != null) {
            asyncTask.cancel(true);
            this.mDrawEntire = null;
        }
        this.mIsBlank = true;
        this.mPageNumber = i;
        if (this.mSize == null) {
            this.mSize = this.mParentSize;
        }
        ImageView imageView = this.mEntire;
        if (imageView != null) {
            imageView.setImageBitmap(null);
        }
        ImageView imageView2 = this.mPatch;
        if (imageView2 != null) {
            imageView2.setImageBitmap(null);
        }
        if (this.mBusyIndicator == null) {
            ProgressBar progressBar = new ProgressBar(this.mContext);
            this.mBusyIndicator = progressBar;
            progressBar.setIndeterminate(true);
            this.mBusyIndicator.setBackgroundResource(UZResourcesIDFinder.getResDrawableID("busy"));
            addView(this.mBusyIndicator);
        }
    }

    public void setPage(int i, PointF pointF) {
        AsyncTask<Void, Void, LinkInfo[]> asyncTask = this.mDrawEntire;
        if (asyncTask != null) {
            asyncTask.cancel(true);
            this.mDrawEntire = null;
        }
        this.mIsBlank = false;
        this.mPageNumber = i;
        if (this.mEntire == null) {
            OpaqueImageView opaqueImageView = new OpaqueImageView(this.mContext);
            this.mEntire = opaqueImageView;
            opaqueImageView.setScaleType(ImageView.ScaleType.FIT_CENTER);
            addView(this.mEntire);
        }
        this.mSourceScale = Math.min(((float) this.mParentSize.x) / pointF.x, ((float) this.mParentSize.y) / pointF.y);
        Point point = new Point((int) (pointF.x * this.mSourceScale), (int) (pointF.y * this.mSourceScale));
        this.mSize = point;
        if (this.mUsingHardwareAcceleration) {
            this.mEntire.setImageBitmap(null);
            this.mEntireBm = null;
        }
        Bitmap bitmap = this.mEntireBm;
        if (!(bitmap != null && bitmap.getWidth() == point.x && this.mEntireBm.getHeight() == point.y)) {
            this.mEntireBm = Bitmap.createBitmap(this.mSize.x, this.mSize.y, Bitmap.Config.ARGB_8888);
        }
        AnonymousClass1 r5 = new AsyncTask<Void, Void, LinkInfo[]>() {
            /* class com.artifex.mupdf.PageView.AnonymousClass1 */

            /* access modifiers changed from: protected */
            public LinkInfo[] doInBackground(Void... voidArr) {
                PageView pageView = PageView.this;
                pageView.drawPage(pageView.mEntireBm, PageView.this.mSize.x, PageView.this.mSize.y, 0, 0, PageView.this.mSize.x, PageView.this.mSize.y);
                return PageView.this.getLinkInfo();
            }

            /* access modifiers changed from: protected */
            public void onPreExecute() {
                PageView.this.mEntire.setImageBitmap(null);
                if (PageView.this.mBusyIndicator == null) {
                    PageView.this.mBusyIndicator = new ProgressBar(PageView.this.mContext);
                    PageView.this.mBusyIndicator.setIndeterminate(true);
                    PageView.this.mBusyIndicator.setBackgroundResource(UZResourcesIDFinder.getResDrawableID("busy"));
                    PageView pageView = PageView.this;
                    pageView.addView(pageView.mBusyIndicator);
                    PageView.this.mBusyIndicator.setVisibility(4);
                    PageView.this.mHandler.postDelayed(new Runnable() {
                        /* class com.artifex.mupdf.PageView.AnonymousClass1.AnonymousClass1 */

                        public void run() {
                            if (PageView.this.mBusyIndicator != null) {
                                PageView.this.mBusyIndicator.setVisibility(0);
                            }
                        }
                    }, 200);
                }
            }

            /* access modifiers changed from: protected */
            public void onPostExecute(LinkInfo[] linkInfoArr) {
                PageView pageView = PageView.this;
                pageView.removeView(pageView.mBusyIndicator);
                PageView.this.mBusyIndicator = null;
                PageView.this.mEntire.setImageBitmap(PageView.this.mEntireBm);
                PageView.this.mLinks = linkInfoArr;
                PageView.this.invalidate();
            }
        };
        this.mDrawEntire = r5;
        r5.execute(new Void[0]);
        if (this.mSearchView == null) {
            AnonymousClass2 r52 = new View(this.mContext) {
                /* class com.artifex.mupdf.PageView.AnonymousClass2 */

                /* access modifiers changed from: protected */
                public void onDraw(Canvas canvas) {
                    super.onDraw(canvas);
                    float width = (PageView.this.mSourceScale * ((float) getWidth())) / ((float) PageView.this.mSize.x);
                    Paint paint = new Paint();
                    if (!PageView.this.mIsBlank && PageView.this.mSearchBoxes != null) {
                        paint.setColor(PageView.HIGHLIGHT_COLOR);
                        RectF[] rectFArr = PageView.this.mSearchBoxes;
                        for (RectF rectF : rectFArr) {
                            canvas.drawRect(rectF.left * width, rectF.top * width, rectF.right * width, rectF.bottom * width, paint);
                        }
                    }
                    if (!(PageView.this.mIsBlank || PageView.this.mLinks == null || !PageView.this.mHighlightLinks)) {
                        paint.setColor(PageView.LINK_COLOR);
                        LinkInfo[] linkInfoArr = PageView.this.mLinks;
                        for (LinkInfo linkInfo : linkInfoArr) {
                            canvas.drawRect(((RectF) linkInfo).left * width, ((RectF) linkInfo).top * width, ((RectF) linkInfo).right * width, ((RectF) linkInfo).bottom * width, paint);
                        }
                    }
                }
            };
            this.mSearchView = r52;
            addView(r52);
        }
        requestLayout();
    }

    public void setSearchBoxes(RectF[] rectFArr) {
        this.mSearchBoxes = rectFArr;
        View view = this.mSearchView;
        if (view != null) {
            view.invalidate();
        }
    }

    public void setLinkHighlighting(boolean z) {
        this.mHighlightLinks = z;
        View view = this.mSearchView;
        if (view != null) {
            view.invalidate();
        }
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i, int i2) {
        int i3;
        int i4;
        if (View.MeasureSpec.getMode(i) != 0) {
            i3 = View.MeasureSpec.getSize(i);
        } else {
            i3 = this.mSize.x;
        }
        if (View.MeasureSpec.getMode(i2) != 0) {
            i4 = View.MeasureSpec.getSize(i2);
        } else {
            i4 = this.mSize.y;
        }
        setMeasuredDimension(i3, i4);
        if (this.mBusyIndicator != null) {
            ProgressBar progressBar = this.mBusyIndicator;
            int min = (Math.min(this.mParentSize.x, this.mParentSize.y) / 2) | ExploreByTouchHelper.INVALID_ID;
            progressBar.measure(min, min);
        }
    }

    /* access modifiers changed from: protected */
    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        int i5 = i3 - i;
        int i6 = i4 - i2;
        ImageView imageView = this.mEntire;
        if (imageView != null) {
            imageView.layout(0, 0, i5, i6);
        }
        View view = this.mSearchView;
        if (view != null) {
            view.layout(0, 0, i5, i6);
        }
        Point point = this.mPatchViewSize;
        if (point != null) {
            if (point.x == i5 && this.mPatchViewSize.y == i6) {
                this.mPatch.layout(this.mPatchArea.left, this.mPatchArea.top, this.mPatchArea.right, this.mPatchArea.bottom);
            } else {
                this.mPatchViewSize = null;
                this.mPatchArea = null;
                ImageView imageView2 = this.mPatch;
                if (imageView2 != null) {
                    imageView2.setImageBitmap(null);
                }
            }
        }
        ProgressBar progressBar = this.mBusyIndicator;
        if (progressBar != null) {
            int measuredWidth = progressBar.getMeasuredWidth();
            int measuredHeight = this.mBusyIndicator.getMeasuredHeight();
            this.mBusyIndicator.layout((i5 - measuredWidth) / 2, (i6 - measuredHeight) / 2, (i5 + measuredWidth) / 2, (i6 + measuredHeight) / 2);
        }
    }

    public void addHq() {
        Rect rect = new Rect(getLeft(), getTop(), getRight(), getBottom());
        if (rect.width() != this.mSize.x || rect.height() != this.mSize.y) {
            Point point = new Point(rect.width(), rect.height());
            Rect rect2 = new Rect(0, 0, this.mParentSize.x, this.mParentSize.y);
            if (rect2.intersect(rect)) {
                rect2.offset(-rect.left, -rect.top);
                if (!rect2.equals(this.mPatchArea) || !point.equals(this.mPatchViewSize)) {
                    AsyncTask<PatchInfo, Void, PatchInfo> asyncTask = this.mDrawPatch;
                    if (asyncTask != null) {
                        asyncTask.cancel(true);
                        this.mDrawPatch = null;
                    }
                    if (this.mPatch == null) {
                        OpaqueImageView opaqueImageView = new OpaqueImageView(this.mContext);
                        this.mPatch = opaqueImageView;
                        opaqueImageView.setScaleType(ImageView.ScaleType.FIT_CENTER);
                        addView(this.mPatch);
                        this.mSearchView.bringToFront();
                    }
                    Bitmap createBitmap = Bitmap.createBitmap(rect2.width(), rect2.height(), Bitmap.Config.ARGB_8888);
                    AnonymousClass3 r4 = new AsyncTask<PatchInfo, Void, PatchInfo>() {
                        /* class com.artifex.mupdf.PageView.AnonymousClass3 */

                        /* access modifiers changed from: protected */
                        public PatchInfo doInBackground(PatchInfo... patchInfoArr) {
                            PageView.this.drawPage(patchInfoArr[0].bm, patchInfoArr[0].patchViewSize.x, patchInfoArr[0].patchViewSize.y, patchInfoArr[0].patchArea.left, patchInfoArr[0].patchArea.top, patchInfoArr[0].patchArea.width(), patchInfoArr[0].patchArea.height());
                            return patchInfoArr[0];
                        }

                        /* access modifiers changed from: protected */
                        public void onPostExecute(PatchInfo patchInfo) {
                            PageView.this.mPatchViewSize = patchInfo.patchViewSize;
                            PageView.this.mPatchArea = patchInfo.patchArea;
                            PageView.this.mPatch.setImageBitmap(patchInfo.bm);
                            PageView.this.mPatch.layout(PageView.this.mPatchArea.left, PageView.this.mPatchArea.top, PageView.this.mPatchArea.right, PageView.this.mPatchArea.bottom);
                            PageView.this.invalidate();
                        }
                    };
                    this.mDrawPatch = r4;
                    r4.execute(new PatchInfo(createBitmap, point, rect2));
                }
            }
        }
    }

    public void removeHq() {
        AsyncTask<PatchInfo, Void, PatchInfo> asyncTask = this.mDrawPatch;
        if (asyncTask != null) {
            asyncTask.cancel(true);
            this.mDrawPatch = null;
        }
        this.mPatchViewSize = null;
        this.mPatchArea = null;
        ImageView imageView = this.mPatch;
        if (imageView != null) {
            imageView.setImageBitmap(null);
        }
    }

    public int getPage() {
        return this.mPageNumber;
    }
}
