package com.artifex.mupdf;

import android.content.Context;
import android.graphics.Point;
import android.graphics.Rect;
import android.util.AttributeSet;
import android.util.SparseArray;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.ScaleGestureDetector;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Adapter;
import android.widget.AdapterView;
import android.widget.Scroller;
import com.uzmap.pkg.uzkit.fineHttp.RequestParam;
import java.util.LinkedList;
import java.util.NoSuchElementException;

public class ReaderView extends AdapterView<Adapter> implements GestureDetector.OnGestureListener, ScaleGestureDetector.OnScaleGestureListener, Runnable {
    private static final int FLING_MARGIN = 100;
    private static final int GAP = 20;
    private static final float MAX_SCALE = 5.0f;
    private static final float MIN_SCALE = 1.0f;
    private static final int MOVING_DIAGONALLY = 0;
    private static final int MOVING_DOWN = 4;
    private static final int MOVING_LEFT = 1;
    private static final int MOVING_RIGHT = 2;
    private static final int MOVING_UP = 3;
    private Adapter mAdapter;
    private final SparseArray<View> mChildViews = new SparseArray<>(3);
    private int mCurrent;
    private final GestureDetector mGestureDetector = new GestureDetector(this);
    private boolean mResetLayout;
    private float mScale = 1.0f;
    private final ScaleGestureDetector mScaleGestureDetector;
    private boolean mScaling;
    private boolean mScrollDisabled;
    private final Scroller mScroller;
    private int mScrollerLastX;
    private int mScrollerLastY;
    private boolean mUserInteracting;
    private final LinkedList<View> mViewCache = new LinkedList<>();
    private int mXScroll;
    private int mYScroll;

    public View getSelectedView() {
        return this;
    }

    /* access modifiers changed from: protected */
    public void onChildSetup(int i, View view) {
    }

    public void onLongPress(MotionEvent motionEvent) {
    }

    /* access modifiers changed from: protected */
    public void onMoveToChild(int i) {
    }

    /* access modifiers changed from: protected */
    public void onSettle(View view) {
    }

    public void onShowPress(MotionEvent motionEvent) {
    }

    public boolean onSingleTapUp(MotionEvent motionEvent) {
        return false;
    }

    /* access modifiers changed from: protected */
    public void onUnsettle(View view) {
    }

    public ReaderView(Context context) {
        super(context);
        this.mScaleGestureDetector = new ScaleGestureDetector(context, this);
        this.mScroller = new Scroller(context);
    }

    public ReaderView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        this.mScaleGestureDetector = new ScaleGestureDetector(context, this);
        this.mScroller = new Scroller(context);
    }

    public ReaderView(Context context, AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.mScaleGestureDetector = new ScaleGestureDetector(context, this);
        this.mScroller = new Scroller(context);
    }

    public int getDisplayedViewIndex() {
        return this.mCurrent;
    }

    public void setDisplayedViewIndex(int i) {
        if (i >= 0 && i < this.mAdapter.getCount()) {
            this.mCurrent = i;
            onMoveToChild(i);
            this.mResetLayout = true;
            requestLayout();
        }
    }

    public void moveToNext() {
        View view = this.mChildViews.get(this.mCurrent + 1);
        if (view != null) {
            slideViewOntoScreen(view);
        }
    }

    public void moveToPrevious() {
        View view = this.mChildViews.get(this.mCurrent - 1);
        if (view != null) {
            slideViewOntoScreen(view);
        }
    }

    public void resetupChildren() {
        for (int i = 0; i < this.mChildViews.size(); i++) {
            onChildSetup(this.mChildViews.keyAt(i), this.mChildViews.valueAt(i));
        }
    }

    public View getDisplayedView() {
        return this.mChildViews.get(this.mCurrent);
    }

    public void run() {
        if (!this.mScroller.isFinished()) {
            this.mScroller.computeScrollOffset();
            int currX = this.mScroller.getCurrX();
            int currY = this.mScroller.getCurrY();
            this.mXScroll += currX - this.mScrollerLastX;
            this.mYScroll += currY - this.mScrollerLastY;
            this.mScrollerLastX = currX;
            this.mScrollerLastY = currY;
            requestLayout();
            post(this);
        } else if (!this.mUserInteracting) {
            postSettle(this.mChildViews.get(this.mCurrent));
        }
    }

    public boolean onDown(MotionEvent motionEvent) {
        this.mScroller.forceFinished(true);
        return true;
    }

    public boolean onFling(MotionEvent motionEvent, MotionEvent motionEvent2, float f, float f2) {
        View view;
        View view2;
        View view3;
        if (!this.mScrollDisabled && (view = this.mChildViews.get(this.mCurrent)) != null) {
            Rect scrollBounds = getScrollBounds(view);
            int directionOfTravel = directionOfTravel(f, f2);
            if (directionOfTravel != 1) {
                if (directionOfTravel == 2 && scrollBounds.right <= 0 && (view3 = this.mChildViews.get(this.mCurrent - 1)) != null) {
                    slideViewOntoScreen(view3);
                    return true;
                }
            } else if (scrollBounds.left >= 0 && (view2 = this.mChildViews.get(this.mCurrent + 1)) != null) {
                slideViewOntoScreen(view2);
                return true;
            }
            this.mScrollerLastY = 0;
            this.mScrollerLastX = 0;
            Rect rect = new Rect(scrollBounds);
            rect.inset(-100, -100);
            if (withinBoundsInDirectionOfTravel(scrollBounds, f, f2) && rect.contains(0, 0)) {
                this.mScroller.fling(0, 0, (int) f, (int) f2, scrollBounds.left, scrollBounds.right, scrollBounds.top, scrollBounds.bottom);
                post(this);
            }
        }
        return true;
    }

    public boolean onScroll(MotionEvent motionEvent, MotionEvent motionEvent2, float f, float f2) {
        if (this.mScrollDisabled) {
            return true;
        }
        this.mXScroll = (int) (((float) this.mXScroll) - f);
        this.mYScroll = (int) (((float) this.mYScroll) - f2);
        requestLayout();
        return true;
    }

    public boolean onScale(ScaleGestureDetector scaleGestureDetector) {
        float f = this.mScale;
        float min = Math.min(Math.max(scaleGestureDetector.getScaleFactor() * f, 1.0f), (float) MAX_SCALE);
        this.mScale = min;
        float f2 = min / f;
        View view = this.mChildViews.get(this.mCurrent);
        if (view == null) {
            return true;
        }
        int focusX = ((int) scaleGestureDetector.getFocusX()) - (view.getLeft() + this.mXScroll);
        int top = view.getTop();
        int i = this.mYScroll;
        int focusY = ((int) scaleGestureDetector.getFocusY()) - (top + i);
        float f3 = (float) focusX;
        this.mXScroll = (int) (((float) this.mXScroll) + (f3 - (f3 * f2)));
        float f4 = (float) focusY;
        this.mYScroll = (int) (((float) i) + (f4 - (f2 * f4)));
        requestLayout();
        return true;
    }

    public boolean onScaleBegin(ScaleGestureDetector scaleGestureDetector) {
        this.mScaling = true;
        this.mYScroll = 0;
        this.mXScroll = 0;
        this.mScrollDisabled = true;
        return true;
    }

    public void onScaleEnd(ScaleGestureDetector scaleGestureDetector) {
        this.mScaling = false;
    }

    public boolean onTouchEvent(MotionEvent motionEvent) {
        this.mScaleGestureDetector.onTouchEvent(motionEvent);
        if (!this.mScaling) {
            this.mGestureDetector.onTouchEvent(motionEvent);
        }
        if (motionEvent.getActionMasked() == 0) {
            this.mUserInteracting = true;
        }
        if (motionEvent.getActionMasked() == 1) {
            this.mScrollDisabled = false;
            this.mUserInteracting = false;
            View view = this.mChildViews.get(this.mCurrent);
            if (view != null) {
                if (this.mScroller.isFinished()) {
                    slideViewOntoScreen(view);
                }
                if (this.mScroller.isFinished()) {
                    postSettle(view);
                }
            }
        }
        requestLayout();
        return true;
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i, int i2) {
        super.onMeasure(i, i2);
        int childCount = getChildCount();
        for (int i3 = 0; i3 < childCount; i3++) {
            measureView(getChildAt(i3));
        }
    }

    /* access modifiers changed from: protected */
    /* JADX WARNING: Removed duplicated region for block: B:47:0x0154  */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x018b  */
    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        int i5;
        int i6;
        int i7;
        int i8;
        super.onLayout(z, i, i2, i3, i4);
        View view = this.mChildViews.get(this.mCurrent);
        if (!this.mResetLayout) {
            if (view != null) {
                Point subScreenSizeOffset = subScreenSizeOffset(view);
                if (view.getLeft() + view.getMeasuredWidth() + subScreenSizeOffset.x + 10 + this.mXScroll < getWidth() / 2 && this.mCurrent + 1 < this.mAdapter.getCount()) {
                    postUnsettle(view);
                    post(this);
                    int i9 = this.mCurrent + 1;
                    this.mCurrent = i9;
                    onMoveToChild(i9);
                }
                if (((view.getLeft() - subScreenSizeOffset.x) - 10) + this.mXScroll >= getWidth() / 2 && this.mCurrent > 0) {
                    postUnsettle(view);
                    post(this);
                    int i10 = this.mCurrent - 1;
                    this.mCurrent = i10;
                    onMoveToChild(i10);
                }
            }
            int size = this.mChildViews.size();
            int[] iArr = new int[size];
            for (int i11 = 0; i11 < size; i11++) {
                iArr[i11] = this.mChildViews.keyAt(i11);
            }
            for (int i12 = 0; i12 < size; i12++) {
                int i13 = iArr[i12];
                int i14 = this.mCurrent;
                if (i13 < i14 - 1 || i13 > i14 + 1) {
                    View view2 = this.mChildViews.get(i13);
                    this.mViewCache.add(view2);
                    removeViewInLayout(view2);
                    this.mChildViews.remove(i13);
                }
            }
        } else {
            this.mResetLayout = false;
            this.mYScroll = 0;
            this.mXScroll = 0;
            int size2 = this.mChildViews.size();
            for (int i15 = 0; i15 < size2; i15++) {
                View valueAt = this.mChildViews.valueAt(i15);
                postUnsettle(valueAt);
                this.mViewCache.add(valueAt);
                removeViewInLayout(valueAt);
            }
            this.mChildViews.clear();
            post(this);
        }
        boolean z2 = this.mChildViews.get(this.mCurrent) == null;
        View orCreateChild = getOrCreateChild(this.mCurrent);
        Point subScreenSizeOffset2 = subScreenSizeOffset(orCreateChild);
        if (z2) {
            i5 = subScreenSizeOffset2.x;
            i6 = subScreenSizeOffset2.y;
        } else {
            i5 = orCreateChild.getLeft() + this.mXScroll;
            i6 = orCreateChild.getTop() + this.mYScroll;
        }
        this.mYScroll = 0;
        this.mXScroll = 0;
        int measuredWidth = orCreateChild.getMeasuredWidth() + i5;
        int measuredHeight = orCreateChild.getMeasuredHeight() + i6;
        if (this.mUserInteracting || !this.mScroller.isFinished()) {
            if (orCreateChild.getMeasuredHeight() <= getHeight()) {
                Point correction = getCorrection(getScrollBounds(i5, i6, measuredWidth, measuredHeight));
                i6 += correction.y;
                i8 = correction.y;
            }
            orCreateChild.layout(i5, i6, measuredWidth, measuredHeight);
            i7 = this.mCurrent;
            if (i7 > 0) {
                View orCreateChild2 = getOrCreateChild(i7 - 1);
                int i16 = subScreenSizeOffset(orCreateChild2).x + 20 + subScreenSizeOffset2.x;
                int i17 = measuredHeight + i6;
                orCreateChild2.layout((i5 - orCreateChild2.getMeasuredWidth()) - i16, (i17 - orCreateChild2.getMeasuredHeight()) / 2, i5 - i16, (i17 + orCreateChild2.getMeasuredHeight()) / 2);
            }
            if (this.mCurrent + 1 < this.mAdapter.getCount()) {
                View orCreateChild3 = getOrCreateChild(this.mCurrent + 1);
                int i18 = subScreenSizeOffset2.x + 20 + subScreenSizeOffset(orCreateChild3).x;
                int i19 = measuredHeight + i6;
                orCreateChild3.layout(measuredWidth + i18, (i19 - orCreateChild3.getMeasuredHeight()) / 2, measuredWidth + orCreateChild3.getMeasuredWidth() + i18, (i19 + orCreateChild3.getMeasuredHeight()) / 2);
            }
            invalidate();
        }
        Point correction2 = getCorrection(getScrollBounds(i5, i6, measuredWidth, measuredHeight));
        measuredWidth += correction2.x;
        i5 += correction2.x;
        i6 += correction2.y;
        i8 = correction2.y;
        measuredHeight += i8;
        orCreateChild.layout(i5, i6, measuredWidth, measuredHeight);
        i7 = this.mCurrent;
        if (i7 > 0) {
        }
        if (this.mCurrent + 1 < this.mAdapter.getCount()) {
        }
        invalidate();
    }

    @Override // android.widget.AdapterView
    public Adapter getAdapter() {
        return this.mAdapter;
    }

    @Override // android.widget.AdapterView
    public void setAdapter(Adapter adapter) {
        this.mAdapter = adapter;
        this.mChildViews.clear();
        removeAllViewsInLayout();
        requestLayout();
    }

    public void setSelection(int i) {
        throw new UnsupportedOperationException("Not supported");
    }

    private View getCached() {
        if (this.mViewCache.size() == 0) {
            return null;
        }
        return this.mViewCache.removeFirst();
    }

    private View getOrCreateChild(int i) {
        View view = this.mChildViews.get(i);
        if (view == null) {
            view = this.mAdapter.getView(i, getCached(), this);
            addAndMeasureChild(i, view);
        }
        onChildSetup(i, view);
        return view;
    }

    private void addAndMeasureChild(int i, View view) {
        ViewGroup.LayoutParams layoutParams = view.getLayoutParams();
        if (layoutParams == null) {
            layoutParams = new ViewGroup.LayoutParams(-2, -2);
        }
        addViewInLayout(view, 0, layoutParams, true);
        this.mChildViews.append(i, view);
        measureView(view);
    }

    private void measureView(View view) {
        view.measure(0, 0);
        float min = Math.min(((float) getWidth()) / ((float) view.getMeasuredWidth()), ((float) getHeight()) / ((float) view.getMeasuredHeight()));
        view.measure(((int) (((float) view.getMeasuredWidth()) * min * this.mScale)) | 1073741824, ((int) (((float) view.getMeasuredHeight()) * min * this.mScale)) | 1073741824);
    }

    private Rect getScrollBounds(int i, int i2, int i3, int i4) {
        int width = getWidth() - i3;
        int i5 = -i;
        int height = getHeight() - i4;
        int i6 = -i2;
        if (width > i5) {
            width = (width + i5) / 2;
            i5 = width;
        }
        if (height > i6) {
            height = (height + i6) / 2;
            i6 = height;
        }
        return new Rect(width, height, i5, i6);
    }

    private Rect getScrollBounds(View view) {
        return getScrollBounds(view.getLeft() + this.mXScroll, view.getTop() + this.mYScroll, view.getLeft() + view.getMeasuredWidth() + this.mXScroll, view.getTop() + view.getMeasuredHeight() + this.mYScroll);
    }

    private Point getCorrection(Rect rect) {
        return new Point(Math.min(Math.max(0, rect.left), rect.right), Math.min(Math.max(0, rect.top), rect.bottom));
    }

    private void postSettle(final View view) {
        post(new Runnable() {
            /* class com.artifex.mupdf.ReaderView.AnonymousClass1 */

            public void run() {
                ReaderView.this.onSettle(view);
            }
        });
    }

    private void postUnsettle(final View view) {
        post(new Runnable() {
            /* class com.artifex.mupdf.ReaderView.AnonymousClass2 */

            public void run() {
                ReaderView.this.onUnsettle(view);
            }
        });
    }

    private void slideViewOntoScreen(View view) {
        Point correction = getCorrection(getScrollBounds(view));
        if (correction.x != 0 || correction.y != 0) {
            this.mScrollerLastY = 0;
            this.mScrollerLastX = 0;
            this.mScroller.startScroll(0, 0, correction.x, correction.y, RequestParam.MIN_PROGRESS_TIME);
            post(this);
        }
    }

    private Point subScreenSizeOffset(View view) {
        return new Point(Math.max((getWidth() - view.getMeasuredWidth()) / 2, 0), Math.max((getHeight() - view.getMeasuredHeight()) / 2, 0));
    }

    private static int directionOfTravel(float f, float f2) {
        if (Math.abs(f) > Math.abs(f2) * 2.0f) {
            return f > 0.0f ? 2 : 1;
        }
        if (Math.abs(f2) > Math.abs(f) * 2.0f) {
            return f2 > 0.0f ? 4 : 3;
        }
        return 0;
    }

    private static boolean withinBoundsInDirectionOfTravel(Rect rect, float f, float f2) {
        int directionOfTravel = directionOfTravel(f, f2);
        if (directionOfTravel == 0) {
            return rect.contains(0, 0);
        }
        if (directionOfTravel != 1) {
            if (directionOfTravel != 2) {
                if (directionOfTravel != 3) {
                    if (directionOfTravel != 4) {
                        throw new NoSuchElementException();
                    } else if (rect.bottom >= 0) {
                        return true;
                    } else {
                        return false;
                    }
                } else if (rect.top <= 0) {
                    return true;
                } else {
                    return false;
                }
            } else if (rect.right >= 0) {
                return true;
            } else {
                return false;
            }
        } else if (rect.left <= 0) {
            return true;
        } else {
            return false;
        }
    }
}
