package com.artifex.mupdf.fitz;

import com.deepe.sdk.WebShare;

public class Matrix {
    public float a;
    public float b;
    public float c;
    public float d;
    public float e;
    public float f;

    public Matrix(float f2, float f3, float f4, float f5, float f6, float f7) {
        this.a = f2;
        this.b = f3;
        this.c = f4;
        this.d = f5;
        this.e = f6;
        this.f = f7;
    }

    public Matrix(float f2, float f3, float f4, float f5) {
        this(f2, f3, f4, f5, 0.0f, 0.0f);
    }

    public Matrix(float f2, float f3) {
        this(f2, 0.0f, 0.0f, f3, 0.0f, 0.0f);
    }

    public Matrix(float f2) {
        this(f2, 0.0f, 0.0f, f2, 0.0f, 0.0f);
    }

    public Matrix() {
        this(1.0f, 0.0f, 0.0f, 1.0f, 0.0f, 0.0f);
    }

    public Matrix(Matrix matrix) {
        this(matrix.a, matrix.b, matrix.c, matrix.d, matrix.e, matrix.f);
    }

    public Matrix(Matrix matrix, Matrix matrix2) {
        float f2 = matrix.a * matrix2.a;
        float f3 = matrix.b;
        float f4 = matrix2.c;
        this.a = f2 + (f3 * f4);
        float f5 = matrix.a * matrix2.b;
        float f6 = matrix2.d;
        this.b = f5 + (f3 * f6);
        float f7 = matrix.c;
        float f8 = matrix2.a;
        float f9 = matrix.d;
        this.c = (f7 * f8) + (f4 * f9);
        float f10 = matrix.c;
        float f11 = matrix2.b;
        this.d = (f10 * f11) + (f9 * f6);
        float f12 = matrix.e * f8;
        float f13 = matrix.f;
        this.e = f12 + (matrix2.c * f13) + matrix2.e;
        this.f = (matrix.e * f11) + (f13 * matrix2.d) + matrix2.f;
    }

    public Matrix concat(Matrix matrix) {
        float f2 = this.a;
        float f3 = matrix.a;
        float f4 = this.b;
        float f5 = matrix.c;
        float f6 = (f2 * f3) + (f4 * f5);
        float f7 = matrix.b;
        float f8 = matrix.d;
        float f9 = (f2 * f7) + (f4 * f8);
        float f10 = this.c;
        float f11 = this.d;
        float f12 = (f10 * f3) + (f11 * f5);
        float f13 = (f10 * f7) + (f11 * f8);
        float f14 = this.e;
        float f15 = this.f;
        this.f = (f14 * f7) + (f15 * f8) + matrix.f;
        this.a = f6;
        this.b = f9;
        this.c = f12;
        this.d = f13;
        this.e = (f3 * f14) + (f5 * f15) + matrix.e;
        return this;
    }

    public Matrix scale(float f2, float f3) {
        this.a *= f2;
        this.b *= f2;
        this.c *= f3;
        this.d *= f3;
        return this;
    }

    public Matrix scale(float f2) {
        return scale(f2, f2);
    }

    public Matrix translate(float f2, float f3) {
        this.e += (this.a * f2) + (this.c * f3);
        this.f += (f2 * this.b) + (f3 * this.d);
        return this;
    }

    public Matrix rotate(float f2) {
        while (f2 < 0.0f) {
            f2 += 360.0f;
        }
        while (f2 >= 360.0f) {
            f2 -= 360.0f;
        }
        if (((double) Math.abs(0.0f - f2)) >= 1.0E-4d) {
            if (((double) Math.abs(90.0f - f2)) < 1.0E-4d) {
                float f3 = this.a;
                float f4 = this.b;
                this.a = this.c;
                this.b = this.d;
                this.c = -f3;
                this.d = -f4;
            } else if (((double) Math.abs(180.0f - f2)) < 1.0E-4d) {
                this.a = -this.a;
                this.b = -this.b;
                this.c = -this.c;
                this.d = -this.d;
            } else if (((double) Math.abs(270.0f - f2)) < 1.0E-4d) {
                float f5 = this.a;
                float f6 = this.b;
                this.a = -this.c;
                this.b = -this.d;
                this.c = f5;
                this.d = f6;
            } else {
                double d2 = (double) f2;
                Double.isNaN(d2);
                double d3 = (d2 * 3.141592653589793d) / 180.0d;
                float sin = (float) Math.sin(d3);
                float cos = (float) Math.cos(d3);
                float f7 = this.a;
                float f8 = this.b;
                float f9 = this.c;
                this.a = (cos * f7) + (sin * f9);
                float f10 = this.d;
                this.b = (cos * f8) + (sin * f10);
                float f11 = -sin;
                this.c = (f7 * f11) + (f9 * cos);
                this.d = (f11 * f8) + (cos * f10);
            }
        }
        return this;
    }

    public String toString() {
        return "[" + this.a + " " + this.b + " " + this.c + " " + this.d + " " + this.e + " " + this.f + WebShare.TAG_EXTENDS_END;
    }

    public static Matrix Identity() {
        return new Matrix(1.0f, 0.0f, 0.0f, 1.0f, 0.0f, 0.0f);
    }

    public static Matrix Scale(float f2) {
        return new Matrix(f2, 0.0f, 0.0f, f2, 0.0f, 0.0f);
    }

    public static Matrix Scale(float f2, float f3) {
        return new Matrix(f2, 0.0f, 0.0f, f3, 0.0f, 0.0f);
    }

    public static Matrix Translate(float f2, float f3) {
        return new Matrix(1.0f, 0.0f, 0.0f, 1.0f, f2, f3);
    }

    public static Matrix Rotate(float f2) {
        float f3;
        while (f2 < 0.0f) {
            f2 += 360.0f;
        }
        while (f2 >= 360.0f) {
            f2 -= 360.0f;
        }
        float f4 = 1.0f;
        if (((double) Math.abs(0.0f - f2)) < 1.0E-4d) {
            f4 = 0.0f;
            f3 = 1.0f;
        } else {
            if (((double) Math.abs(90.0f - f2)) >= 1.0E-4d) {
                if (((double) Math.abs(180.0f - f2)) < 1.0E-4d) {
                    f4 = 0.0f;
                    f3 = -1.0f;
                } else if (((double) Math.abs(270.0f - f2)) < 1.0E-4d) {
                    f4 = -1.0f;
                } else {
                    double d2 = (double) f2;
                    Double.isNaN(d2);
                    double d3 = (d2 * 3.141592653589793d) / 180.0d;
                    f4 = (float) Math.sin(d3);
                    f3 = (float) Math.cos(d3);
                }
            }
            f3 = 0.0f;
        }
        return new Matrix(f3, f4, -f4, f3, 0.0f, 0.0f);
    }
}
