package com.artifex.mupdf.fitz;

public class PDFDocument extends Document {

    public interface JsEventListener {
        void onAlert(String str);
    }

    private native PDFObject addPageBuffer(Rect rect, int i, PDFObject pDFObject, Buffer buffer);

    private native PDFObject addPageString(Rect rect, int i, PDFObject pDFObject, String str);

    private native PDFObject addStreamBuffer(Buffer buffer, Object obj, boolean z);

    private native PDFObject addStreamString(String str, Object obj, boolean z);

    private static native long newNative();

    public native PDFObject addCJKFont(Font font, int i, int i2, boolean z);

    public native PDFObject addFont(Font font);

    public native PDFObject addImage(Image image);

    public native PDFObject addObject(PDFObject pDFObject);

    public native PDFObject addSimpleFont(Font font, int i);

    public native void calculate();

    public native boolean canBeSavedIncrementally();

    public native int countObjects();

    public native PDFObject createObject();

    public native void deleteObject(int i);

    public native void deletePage(int i);

    public native void disableJs();

    public native void enableJs();

    public native PDFObject findPage(int i);

    public native PDFObject getTrailer();

    public native PDFObject graftObject(PDFObject pDFObject);

    public native boolean hasUnsavedChanges();

    public native void insertPage(int i, PDFObject pDFObject);

    public native boolean isJsSupported();

    @Override // com.artifex.mupdf.fitz.Document
    public boolean isPDF() {
        return true;
    }

    /* access modifiers changed from: protected */
    public native void nativeSaveWithStream(SeekableOutputStream seekableOutputStream, String str);

    public native PDFObject newArray();

    public native PDFObject newBoolean(boolean z);

    public native PDFObject newByteString(byte[] bArr);

    public native PDFObject newDictionary();

    public native PDFObject newIndirect(int i, int i2);

    public native PDFObject newInteger(int i);

    public native PDFObject newName(String str);

    public native PDFObject newNull();

    public native PDFGraftMap newPDFGraftMap();

    public native PDFObject newReal(float f);

    public native PDFObject newString(String str);

    public native void save(String str, String str2);

    public native void setJsEventListener(JsEventListener jsEventListener);

    static {
        Context.init();
    }

    protected PDFDocument(long j) {
        super(j);
    }

    public PDFDocument() {
        super(newNative());
    }

    public void deleteObject(PDFObject pDFObject) {
        deleteObject(pDFObject.asIndirect());
    }

    public PDFObject addRawStream(Buffer buffer, Object obj) {
        return addStreamBuffer(buffer, obj, true);
    }

    public PDFObject addStream(Buffer buffer, Object obj) {
        return addStreamBuffer(buffer, obj, false);
    }

    public PDFObject addRawStream(String str, Object obj) {
        return addStreamString(str, obj, true);
    }

    public PDFObject addStream(String str, Object obj) {
        return addStreamString(str, obj, false);
    }

    public PDFObject addRawStream(Buffer buffer) {
        return addStreamBuffer(buffer, null, true);
    }

    public PDFObject addStream(Buffer buffer) {
        return addStreamBuffer(buffer, null, false);
    }

    public PDFObject addRawStream(String str) {
        return addStreamString(str, null, true);
    }

    public PDFObject addStream(String str) {
        return addStreamString(str, null, false);
    }

    public PDFObject addPage(Rect rect, int i, PDFObject pDFObject, Buffer buffer) {
        return addPageBuffer(rect, i, pDFObject, buffer);
    }

    public PDFObject addPage(Rect rect, int i, PDFObject pDFObject, String str) {
        return addPageString(rect, i, pDFObject, str);
    }

    public void save(SeekableOutputStream seekableOutputStream, String str) {
        nativeSaveWithStream(seekableOutputStream, str);
    }

    public boolean hasAcroForm() {
        return getTrailer().get("Root").get("AcroForm").get("Fields").size() > 0;
    }

    public boolean hasXFAForm() {
        return !getTrailer().get("Root").get("AcroForm").get("XFA").isNull();
    }
}
