package com.artifex.mupdf.fitz;

import java.util.ArrayList;

public class StructuredText {
    public static final int SELECT_CHARS = 0;
    public static final int SELECT_LINES = 2;
    public static final int SELECT_WORDS = 1;
    private long pointer;

    public native String copy(Point point, Point point2);

    /* access modifiers changed from: protected */
    public native void finalize();

    public native Quad[] highlight(Point point, Point point2);

    public native Quad[] search(String str);

    public native Quad snapSelection(Point point, Point point2, int i);

    public native void walk(StructuredTextWalker structuredTextWalker);

    static {
        Context.init();
    }

    public void destroy() {
        finalize();
        this.pointer = 0;
    }

    private StructuredText(long j) {
        this.pointer = j;
    }

    public TextBlock[] getBlocks() {
        BlockWalker blockWalker = new BlockWalker();
        walk(blockWalker);
        return blockWalker.getBlocks();
    }

    class BlockWalker implements StructuredTextWalker {
        Rect blockBbox;
        ArrayList<TextBlock> blocks = new ArrayList<>();
        ArrayList<TextChar> chrs;
        Rect lineBbox;
        ArrayList<TextLine> lines;

        @Override // com.artifex.mupdf.fitz.StructuredTextWalker
        public void onImageBlock(Rect rect, Matrix matrix, Image image) {
        }

        BlockWalker() {
        }

        @Override // com.artifex.mupdf.fitz.StructuredTextWalker
        public void beginTextBlock(Rect rect) {
            this.lines = new ArrayList<>();
            this.blockBbox = rect;
        }

        @Override // com.artifex.mupdf.fitz.StructuredTextWalker
        public void endTextBlock() {
            TextBlock textBlock = new TextBlock();
            textBlock.bbox = this.blockBbox;
            textBlock.lines = (TextLine[]) this.lines.toArray(new TextLine[0]);
            this.blocks.add(textBlock);
        }

        @Override // com.artifex.mupdf.fitz.StructuredTextWalker
        public void beginLine(Rect rect, int i) {
            this.chrs = new ArrayList<>();
            this.lineBbox = rect;
        }

        @Override // com.artifex.mupdf.fitz.StructuredTextWalker
        public void endLine() {
            TextLine textLine = new TextLine();
            textLine.bbox = this.lineBbox;
            textLine.chars = (TextChar[]) this.chrs.toArray(new TextChar[0]);
            this.lines.add(textLine);
        }

        @Override // com.artifex.mupdf.fitz.StructuredTextWalker
        public void onChar(int i, Point point, Font font, float f, Quad quad) {
            TextChar textChar = new TextChar();
            textChar.c = i;
            textChar.quad = quad;
            this.chrs.add(textChar);
        }

        /* access modifiers changed from: package-private */
        public TextBlock[] getBlocks() {
            return (TextBlock[]) this.blocks.toArray(new TextBlock[0]);
        }
    }

    public class TextBlock {
        public Rect bbox;
        public TextLine[] lines;

        public TextBlock() {
        }
    }

    public class TextLine {
        public Rect bbox;
        public TextChar[] chars;

        public TextLine() {
        }
    }

    public class TextChar {
        public int c;
        public Quad quad;

        public TextChar() {
        }

        public boolean isWhitespace() {
            return Character.isWhitespace(this.c);
        }
    }
}
