package com.google.zxing.aztec.encoder;

import com.google.zxing.common.BitArray;
import java.lang.reflect.Array;
import java.util.Arrays;
import java.util.Collection;
import java.util.Collections;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedList;

public final class HighLevelEncoder {
    private static final int[][] CHAR_MAP;
    static final int[][] LATCH_TABLE;
    static final int MODE_DIGIT = 2;
    static final int MODE_LOWER = 1;
    static final int MODE_MIXED = 3;
    static final String[] MODE_NAMES = {"UPPER", "LOWER", "DIGIT", "MIXED", "PUNCT"};
    static final int MODE_PUNCT = 4;
    static final int MODE_UPPER = 0;
    static final int[][] SHIFT_TABLE;
    private final byte[] text;

    static {
        int[] iArr = new int[5];
        iArr[1] = 327708;
        iArr[2] = 327710;
        iArr[3] = 327709;
        iArr[4] = 656318;
        int[] iArr2 = new int[5];
        iArr2[0] = 590318;
        iArr2[2] = 327710;
        iArr2[3] = 327709;
        iArr2[4] = 656318;
        int[] iArr3 = new int[5];
        iArr3[0] = 262158;
        iArr3[1] = 590300;
        iArr3[3] = 590301;
        iArr3[4] = 932798;
        int[] iArr4 = new int[5];
        iArr4[0] = 327709;
        iArr4[1] = 327708;
        iArr4[2] = 656318;
        iArr4[4] = 327710;
        int[] iArr5 = new int[5];
        iArr5[0] = 327711;
        iArr5[1] = 656380;
        iArr5[2] = 656382;
        iArr5[3] = 656381;
        LATCH_TABLE = new int[][]{iArr, iArr2, iArr3, iArr4, iArr5};
        int[][] iArr6 = (int[][]) Array.newInstance(int.class, 5, 256);
        CHAR_MAP = iArr6;
        iArr6[0][32] = 1;
        for (int i = 65; i <= 90; i++) {
            CHAR_MAP[0][i] = (i - 65) + 2;
        }
        CHAR_MAP[1][32] = 1;
        for (int i2 = 97; i2 <= 122; i2++) {
            CHAR_MAP[1][i2] = (i2 - 97) + 2;
        }
        CHAR_MAP[2][32] = 1;
        for (int i3 = 48; i3 <= 57; i3++) {
            CHAR_MAP[2][i3] = (i3 - 48) + 2;
        }
        int[][] iArr7 = CHAR_MAP;
        iArr7[2][44] = 12;
        iArr7[2][46] = 13;
        int[] iArr8 = new int[28];
        iArr8[1] = 32;
        iArr8[2] = 1;
        iArr8[3] = 2;
        iArr8[4] = 3;
        iArr8[5] = 4;
        iArr8[6] = 5;
        iArr8[7] = 6;
        iArr8[8] = 7;
        iArr8[9] = 8;
        iArr8[10] = 9;
        iArr8[11] = 10;
        iArr8[12] = 11;
        iArr8[13] = 12;
        iArr8[14] = 13;
        iArr8[15] = 27;
        iArr8[16] = 28;
        iArr8[17] = 29;
        iArr8[18] = 30;
        iArr8[19] = 31;
        iArr8[20] = 64;
        iArr8[21] = 92;
        iArr8[22] = 94;
        iArr8[23] = 95;
        iArr8[24] = 96;
        iArr8[25] = 124;
        iArr8[26] = 126;
        iArr8[27] = 127;
        for (int i4 = 0; i4 < 28; i4++) {
            CHAR_MAP[3][iArr8[i4]] = i4;
        }
        int[] iArr9 = new int[31];
        iArr9[1] = 13;
        iArr9[6] = 33;
        iArr9[7] = 39;
        iArr9[8] = 35;
        iArr9[9] = 36;
        iArr9[10] = 37;
        iArr9[11] = 38;
        iArr9[12] = 39;
        iArr9[13] = 40;
        iArr9[14] = 41;
        iArr9[15] = 42;
        iArr9[16] = 43;
        iArr9[17] = 44;
        iArr9[18] = 45;
        iArr9[19] = 46;
        iArr9[20] = 47;
        iArr9[21] = 58;
        iArr9[22] = 59;
        iArr9[23] = 60;
        iArr9[24] = 61;
        iArr9[25] = 62;
        iArr9[26] = 63;
        iArr9[27] = 91;
        iArr9[28] = 93;
        iArr9[29] = 123;
        iArr9[30] = 125;
        for (int i5 = 0; i5 < 31; i5++) {
            if (iArr9[i5] > 0) {
                CHAR_MAP[4][iArr9[i5]] = i5;
            }
        }
        int[][] iArr10 = (int[][]) Array.newInstance(int.class, 6, 6);
        SHIFT_TABLE = iArr10;
        for (int[] iArr11 : iArr10) {
            Arrays.fill(iArr11, -1);
        }
        int[][] iArr12 = SHIFT_TABLE;
        iArr12[0][4] = 0;
        iArr12[1][4] = 0;
        iArr12[1][0] = 28;
        iArr12[3][4] = 0;
        iArr12[2][4] = 0;
        iArr12[2][0] = 15;
    }

    public HighLevelEncoder(byte[] bArr) {
        this.text = bArr;
    }

    /* JADX WARNING: Removed duplicated region for block: B:28:0x0053  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x0059  */
    public BitArray encode() {
        int i;
        Collection<State> singletonList = Collections.singletonList(State.INITIAL_STATE);
        int i2 = 0;
        while (true) {
            byte[] bArr = this.text;
            if (i2 >= bArr.length) {
                return ((State) Collections.min(singletonList, new Comparator<State>() {
                    /* class com.google.zxing.aztec.encoder.HighLevelEncoder.AnonymousClass1 */

                    public int compare(State state, State state2) {
                        return state.getBitCount() - state2.getBitCount();
                    }
                })).toBitArray(this.text);
            }
            int i3 = i2 + 1;
            byte b = i3 < bArr.length ? bArr[i3] : 0;
            byte b2 = this.text[i2];
            if (b2 != 13) {
                if (b2 != 44) {
                    if (b2 != 46) {
                        if (b2 == 58 && b == 32) {
                            i = 5;
                            if (i > 0) {
                                singletonList = updateStateListForPair(singletonList, i2, i);
                                i2 = i3;
                            } else {
                                singletonList = updateStateListForChar(singletonList, i2);
                            }
                            i2++;
                        }
                    } else if (b == 32) {
                        i = 3;
                        if (i > 0) {
                        }
                        i2++;
                    }
                } else if (b == 32) {
                    i = 4;
                    if (i > 0) {
                    }
                    i2++;
                }
            } else if (b == 10) {
                i = 2;
                if (i > 0) {
                }
                i2++;
            }
            i = 0;
            if (i > 0) {
            }
            i2++;
        }
    }

    private Collection<State> updateStateListForChar(Iterable<State> iterable, int i) {
        LinkedList linkedList = new LinkedList();
        for (State state : iterable) {
            updateStateForChar(state, i, linkedList);
        }
        return simplifyStates(linkedList);
    }

    private void updateStateForChar(State state, int i, Collection<State> collection) {
        char c = (char) (this.text[i] & 255);
        boolean z = CHAR_MAP[state.getMode()][c] > 0;
        State state2 = null;
        for (int i2 = 0; i2 <= 4; i2++) {
            int i3 = CHAR_MAP[i2][c];
            if (i3 > 0) {
                if (state2 == null) {
                    state2 = state.endBinaryShift(i);
                }
                if (!z || i2 == state.getMode() || i2 == 2) {
                    collection.add(state2.latchAndAppend(i2, i3));
                }
                if (!z && SHIFT_TABLE[state.getMode()][i2] >= 0) {
                    collection.add(state2.shiftAndAppend(i2, i3));
                }
            }
        }
        if (state.getBinaryShiftByteCount() > 0 || CHAR_MAP[state.getMode()][c] == 0) {
            collection.add(state.addBinaryShiftChar(i));
        }
    }

    private static Collection<State> updateStateListForPair(Iterable<State> iterable, int i, int i2) {
        LinkedList linkedList = new LinkedList();
        for (State state : iterable) {
            updateStateForPair(state, i, i2, linkedList);
        }
        return simplifyStates(linkedList);
    }

    private static void updateStateForPair(State state, int i, int i2, Collection<State> collection) {
        State endBinaryShift = state.endBinaryShift(i);
        collection.add(endBinaryShift.latchAndAppend(4, i2));
        if (state.getMode() != 4) {
            collection.add(endBinaryShift.shiftAndAppend(4, i2));
        }
        if (i2 == 3 || i2 == 4) {
            collection.add(endBinaryShift.latchAndAppend(2, 16 - i2).latchAndAppend(2, 1));
        }
        if (state.getBinaryShiftByteCount() > 0) {
            collection.add(state.addBinaryShiftChar(i).addBinaryShiftChar(i + 1));
        }
    }

    private static Collection<State> simplifyStates(Iterable<State> iterable) {
        LinkedList linkedList = new LinkedList();
        for (State state : iterable) {
            boolean z = true;
            Iterator it = linkedList.iterator();
            while (true) {
                if (!it.hasNext()) {
                    break;
                }
                State state2 = (State) it.next();
                if (state2.isBetterThanOrEqualTo(state)) {
                    z = false;
                    break;
                } else if (state.isBetterThanOrEqualTo(state2)) {
                    it.remove();
                }
            }
            if (z) {
                linkedList.add(state);
            }
        }
        return linkedList;
    }
}
