package com.uzmap.pkg.uzmodules.fs;

import android.content.res.AssetManager;
import android.os.Environment;
import android.support.v4.app.NotificationCompat;
import android.text.TextUtils;
import android.util.Log;
import com.uzmap.pkg.uzcore.UZWebView;
import com.uzmap.pkg.uzcore.annotation.UzJavascriptMethod;
import com.uzmap.pkg.uzcore.uzmodule.ModuleResult;
import com.uzmap.pkg.uzcore.uzmodule.UZModule;
import com.uzmap.pkg.uzcore.uzmodule.UZModuleContext;
import com.uzmap.pkg.uzkit.UZOpenApi;
import com.uzmap.pkg.uzkit.UZUtility;
import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStreamWriter;
import java.io.RandomAccessFile;
import java.math.BigInteger;
import java.nio.channels.FileChannel;
import java.security.MessageDigest;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import net.lingala.zip4j.util.InternalZipConstants;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class UzFsUtils extends UZModule {
    public static final int ERR_CAN_NOT_READ = 2;
    public static final int ERR_NO_SUCH_FILE = 1;
    public static final int ERR_SUCCESS = 0;
    private static int REQ_CODE = 0;
    public static final String TAG = "UzFsUtils";
    private static final int readFlag = 1;
    private static final int read_write_Flag = 3;
    private static final int writeFlag = 2;
    private JSONObject err = new JSONObject();
    private String fd;
    private long fileLen;
    private Map<String, Integer> iomap = new HashMap();
    private int readoffset;
    private JSONObject ret = new JSONObject();
    private long size;
    private int textSize;

    public UzFsUtils(UZWebView uZWebView) {
        super(uZWebView);
    }

    public void jsmethod_getExtSDCardPathList(UZModuleContext uZModuleContext) {
        Iterator<String> it = getExtSDCardPathList().iterator();
        while (it.hasNext()) {
            Log.i("xDebug", "sdcard：" + it.next());
        }
    }

    public static List<String> getExtSDCardPathList() {
        ArrayList arrayList = new ArrayList();
        String externalStorageState = Environment.getExternalStorageState();
        File externalStorageDirectory = Environment.getExternalStorageDirectory();
        if (externalStorageState.equals("mounted") && externalStorageDirectory.exists() && externalStorageDirectory.isDirectory() && externalStorageDirectory.canWrite()) {
            arrayList.add(externalStorageDirectory.getAbsolutePath());
        }
        try {
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(Runtime.getRuntime().exec("mount").getInputStream()));
            while (true) {
                String readLine = bufferedReader.readLine();
                if (readLine == null) {
                    break;
                }
                Log.i("xDebug", "===>: " + readLine);
                if ((readLine.contains("fat") || readLine.contains("fuse") || readLine.contains("storage")) && !readLine.contains("secure") && !readLine.contains("asec") && !readLine.contains("firmware") && !readLine.contains("shell") && !readLine.contains("obb") && !readLine.contains("legacy")) {
                    if (!readLine.contains(UZOpenApi.DATA)) {
                        String[] split = readLine.split(" ");
                        if (1 < split.length) {
                            String str = split[1];
                            if (str.contains(InternalZipConstants.ZIP_FILE_SEPARATOR) && !str.contains(UZOpenApi.DATA)) {
                                if (!str.contains("Data")) {
                                    File file = new File(str);
                                    if (file.exists() && file.isDirectory()) {
                                        if (file.canWrite()) {
                                            if (!str.equals(externalStorageDirectory.getAbsolutePath())) {
                                                arrayList.add(str);
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return arrayList;
    }

    public void jsmethod_getDirs(UZModuleContext uZModuleContext) {
        File file = new File("/storage/1234-5678");
        if (file.exists() && file.isDirectory()) {
            File[] listFiles = file.listFiles();
            for (int i = 0; i < listFiles.length; i++) {
                Log.i("XDebug", "==><><> " + listFiles[i].getAbsolutePath());
            }
        }
    }

    public void jsmethod_createDir(UZModuleContext uZModuleContext) {
        try {
            this.ret.put(NotificationCompat.CATEGORY_STATUS, getFile(uZModuleContext.optString("path"), true));
            uZModuleContext.success(this.ret, true);
        } catch (Exception e) {
            e.printStackTrace();
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
        } catch (Throwable th) {
            this.ret.remove(NotificationCompat.CATEGORY_STATUS);
            this.err.remove(NotificationCompat.CATEGORY_MESSAGE);
            throw th;
        }
        this.ret.remove(NotificationCompat.CATEGORY_STATUS);
        this.err.remove(NotificationCompat.CATEGORY_MESSAGE);
    }

    public void jsmethod_createFile(UZModuleContext uZModuleContext) {
        createFile(uZModuleContext, false);
    }

    public void jsmethod_remove(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("path");
        if (TextUtils.isEmpty(optString)) {
            JSONObject jSONObject = new JSONObject();
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject.put(NotificationCompat.CATEGORY_STATUS, false);
                jSONObject2.put(NotificationCompat.CATEGORY_MESSAGE, "路径不能为空");
                uZModuleContext.error(jSONObject, jSONObject2, false);
                return;
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        try {
            if (optString.startsWith("file://")) {
                optString = optString.replace("file://", "");
            }
            remove(new File(new File(new File(uZModuleContext.makeRealPath(optString)).getParent()), optString.substring(optString.lastIndexOf(InternalZipConstants.ZIP_FILE_SEPARATOR))), uZModuleContext);
            this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            uZModuleContext.success(this.ret, true);
        } catch (Exception e2) {
            e2.printStackTrace();
            try {
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, e2.getMessage());
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e3) {
                e3.printStackTrace();
            }
        }
    }

    public void jsmethod_moveTo(final UZModuleContext uZModuleContext) {
        new Thread("fs-moveTo") {
            /* class com.uzmap.pkg.uzmodules.fs.UzFsUtils.AnonymousClass1 */

            public void run() {
                String optString = uZModuleContext.optString("oldPath");
                String optString2 = uZModuleContext.optString("newPath");
                String generatePath = UzFsUtils.this.generatePath(optString);
                String generatePath2 = UzFsUtils.this.generatePath(optString2);
                File file = new File(generatePath);
                if (file.isFile() && UzFsUtils.this.moveFile(generatePath, generatePath2)) {
                    UzFsUtils.this.callback(uZModuleContext, true, 0, "移动文件成功");
                } else if (!file.isDirectory() || !UzFsUtils.this.moveDirectory(generatePath, generatePath2)) {
                    UzFsUtils.this.callback(uZModuleContext, false, 1, "移动文件失败");
                } else {
                    UzFsUtils.this.callback(uZModuleContext, true, 0, "移动文件成功");
                }
            }
        }.start();
    }

    public boolean moveFile(String str, String str2) {
        File file = new File(str);
        if (!file.exists() || !file.isFile()) {
            return false;
        }
        File file2 = new File(str2);
        if (!file2.exists()) {
            file2.mkdirs();
        }
        return file.renameTo(new File(str2 + File.separator + file.getName()));
    }

    public boolean moveDirectory(String str, String str2) {
        File file = new File(str);
        if (!file.exists() || !file.isDirectory()) {
            return false;
        }
        File file2 = new File(str2);
        if (!file2.exists()) {
            file2.mkdirs();
        }
        File[] listFiles = file.listFiles();
        for (File file3 : listFiles) {
            if (file3.isFile()) {
                moveFile(file3.getAbsolutePath(), file2.getAbsolutePath());
            } else if (file3.isDirectory()) {
                moveDirectory(file3.getAbsolutePath(), file2.getAbsolutePath() + File.separator + file3.getName());
            }
        }
        return file.delete();
    }

    private void moveTo(String str, String str2, UZModuleContext uZModuleContext) throws Exception {
        File file = new File(str);
        boolean z = false;
        if (file.exists()) {
            File file2 = new File(str2);
            if (!file2.exists()) {
                getFile(str2, true);
            }
            if (file.isFile()) {
                File file3 = new File(file2.getPath() + "//" + file.getName());
                if (file3.exists()) {
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "文件已存在");
                    uZModuleContext.error(this.ret, this.err, true);
                    return;
                }
                file.renameTo(file3);
                return;
            }
            File[] listFiles = file.listFiles();
            if (listFiles != null) {
                for (int i = 0; i < listFiles.length; i++) {
                    if (listFiles[i].isDirectory()) {
                        String path = listFiles[i].getPath();
                        moveTo(path, str2 + "//" + listFiles[i].getName(), uZModuleContext);
                        listFiles[i].delete();
                    }
                    File file4 = new File(file2.getPath() + "//" + listFiles[i].getName());
                    if (file4.exists()) {
                        file4.delete();
                    }
                    listFiles[i].renameTo(file4);
                }
                file.delete();
                return;
            }
            return;
        }
        String isAssetPath = isAssetPath(str);
        if (isAssetPath != null) {
            z = copyAssetRes(isAssetPath, str2, true);
        }
        this.ret.put(NotificationCompat.CATEGORY_STATUS, z);
        if (!z) {
            this.err.put(NotificationCompat.CATEGORY_MESSAGE, "源文件不存在");
        }
        uZModuleContext.error(this.ret, this.err, true);
    }

    public void jsmethod_rename(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("oldPath");
        String optString2 = uZModuleContext.optString("newPath");
        try {
            String generatePath = generatePath(optString);
            String generatePath2 = generatePath(optString2);
            if (!new File(generatePath).isDirectory()) {
                boolean renameTo = renameTo(generatePath, generatePath2, uZModuleContext);
                Log.i("xDebug", "success: " + renameTo);
                this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
                uZModuleContext.success(this.ret, true);
            } else if (new File(generatePath).renameTo(new File(generatePath2))) {
                JSONObject jSONObject = new JSONObject();
                jSONObject.put(NotificationCompat.CATEGORY_STATUS, true);
                uZModuleContext.success(jSONObject, false);
            } else {
                JSONObject jSONObject2 = new JSONObject();
                jSONObject2.put(NotificationCompat.CATEGORY_STATUS, false);
                JSONObject jSONObject3 = new JSONObject();
                jSONObject3.put(NotificationCompat.CATEGORY_MESSAGE, "重命名失败");
                uZModuleContext.error(jSONObject2, jSONObject3, false);
            }
        } catch (Exception e) {
            e.printStackTrace();
            try {
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
        }
    }

    public void jsmethod_close(UZModuleContext uZModuleContext) {
        try {
            this.iomap.remove(uZModuleContext.optString("fd"));
            this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            uZModuleContext.success(this.ret, true);
        } catch (Exception e) {
            e.printStackTrace();
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
        }
    }

    private boolean renameTo(String str, String str2, UZModuleContext uZModuleContext) throws Exception {
        File file = new File(str);
        if (file.exists()) {
            return file.renameTo(new File(str2));
        }
        this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
        this.err.put(NotificationCompat.CATEGORY_MESSAGE, "源文件不存在");
        uZModuleContext.error(this.ret, this.err, true);
        return false;
    }

    public void jsmethod_copyTo(final UZModuleContext uZModuleContext) {
        new Thread("fs-copyTo") {
            /* class com.uzmap.pkg.uzmodules.fs.UzFsUtils.AnonymousClass2 */

            public void run() {
                try {
                    UzFsUtils.this.ret.put(NotificationCompat.CATEGORY_STATUS, UzFsUtils.this.transferTo(uZModuleContext.optString("oldPath"), uZModuleContext.optString("newPath"), uZModuleContext));
                    uZModuleContext.success(UzFsUtils.this.ret, true);
                } catch (Exception e) {
                    e.printStackTrace();
                    try {
                        UzFsUtils.this.err.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                        UzFsUtils.this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                        uZModuleContext.error(UzFsUtils.this.ret, UzFsUtils.this.err, true);
                    } catch (JSONException e2) {
                        e2.printStackTrace();
                    }
                }
            }
        }.start();
    }

    public void jsmethod_readDir(UZModuleContext uZModuleContext) {
        try {
            String generatePath = generatePath(uZModuleContext.optString("path"));
            File file = new File(generatePath);
            if (file.exists()) {
                this.ret.put(UZOpenApi.DATA, showDir(file));
                this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
                uZModuleContext.success(this.ret, true);
                return;
            }
            String isAssetPath = isAssetPath(generatePath);
            if (isAssetPath != null) {
                JSONArray jSONArray = new JSONArray();
                showAssetDir(isAssetPath, jSONArray);
                this.ret.put(UZOpenApi.DATA, jSONArray);
                this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
                uZModuleContext.success(this.ret, true);
                return;
            }
            this.err.put(NotificationCompat.CATEGORY_MESSAGE, "文件不存在");
            this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
            uZModuleContext.error(this.ret, this.err, true);
        } catch (Exception e) {
            e.printStackTrace();
            try {
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
        }
    }

    public void jsmethod_open(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("path");
        String optString2 = uZModuleContext.optString("flags");
        this.fileLen = getFileLength(optString);
        Log.i(TAG, "file length : " + this.fileLen);
        try {
            String makeRealPath = UZUtility.makeRealPath(optString, getWidgetInfo());
            Log.i(TAG, "pathname : " + makeRealPath);
            if (makeRealPath.contains("android_asset")) {
                try {
                    if ("read".equals(optString2)) {
                        open(optString, 1);
                    } else if ("write".equals(optString2)) {
                        this.err.put(NotificationCompat.CATEGORY_MESSAGE, "asset目录下的文件只能读取");
                        this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                        uZModuleContext.error(this.ret, this.err, true);
                    } else if ("read_write".equals(optString2)) {
                        this.err.put(NotificationCompat.CATEGORY_MESSAGE, "asset目录下的文件只能读取");
                        this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                        uZModuleContext.error(this.ret, this.err, true);
                    }
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
                    this.ret.put("fd", optString);
                    uZModuleContext.success(this.ret, true);
                } catch (Exception unused) {
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "文件不存在");
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    uZModuleContext.error(this.ret, this.err, true);
                }
            } else {
                if (makeRealPath.contains("file://")) {
                    makeRealPath = substringAfter(makeRealPath, "file://");
                }
                File file = new File(makeRealPath);
                if (!file.exists()) {
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "文件不存在");
                    uZModuleContext.error(this.ret, this.err, true);
                } else if (file.isDirectory()) {
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "文件是目录,无效操作");
                    uZModuleContext.error(this.ret, this.err, true);
                } else {
                    this.fd = makeRealPath;
                    if ("read".equals(optString2)) {
                        open(makeRealPath, 1);
                    } else if ("write".equals(optString2)) {
                        open(makeRealPath, 2);
                    } else if ("read_write".equals(optString2)) {
                        open(makeRealPath, 3);
                    }
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
                    this.ret.put("fd", makeRealPath);
                    uZModuleContext.success(this.ret, true);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            try {
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
        }
    }

    public boolean isBlank(CharSequence charSequence) {
        int length;
        if (!(charSequence == null || (length = charSequence.length()) == 0)) {
            for (int i = 0; i < length; i++) {
                if (!Character.isWhitespace(charSequence.charAt(i))) {
                    return false;
                }
            }
        }
        return true;
    }

    public boolean isEmpty(CharSequence charSequence) {
        return charSequence == null || charSequence.length() == 0;
    }

    public String substringAfter(String str, String str2) {
        int indexOf;
        if (isEmpty(str)) {
            return str;
        }
        if (str2 == null || (indexOf = str.indexOf(str2)) == -1) {
            return "";
        }
        return str.substring(indexOf + str2.length());
    }

    @UzJavascriptMethod
    public void jsmethod_read(UZModuleContext uZModuleContext) {
        String str;
        try {
            String optString = uZModuleContext.optString("fd");
            int optInt = uZModuleContext.optInt("offset");
            int optInt2 = uZModuleContext.optInt("length");
            String optString2 = uZModuleContext.optString("codingType", "utf-8");
            if (TextUtils.isEmpty(optString2)) {
                str = "utf-8";
            } else {
                str = optString2;
            }
            long fileLength = getFileLength(optString);
            this.fileLen = fileLength;
            if (fileLength <= 0) {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "文件为空");
                uZModuleContext.error(this.ret, this.err, true);
                return;
            }
            int i = optInt2 <= 0 ? (int) fileLength : optInt2;
            if (optInt < 0) {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "offset 不能小于零 ");
                uZModuleContext.error(this.ret, this.err, true);
            } else if (((long) (optInt + i)) > this.fileLen) {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "超过文件大小 ");
                uZModuleContext.error(this.ret, this.err, true);
            } else {
                readAsText(optString, optInt, i, str, uZModuleContext, true);
            }
        } catch (Exception e) {
            e.printStackTrace();
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
        }
    }

    @UzJavascriptMethod
    public void jsmethod_write(UZModuleContext uZModuleContext) {
        String str;
        String optString = uZModuleContext.optString("fd");
        String optString2 = uZModuleContext.optString(UZOpenApi.DATA);
        long optLong = uZModuleContext.optLong("offset", this.fileLen);
        String optString3 = uZModuleContext.optString("codingType", "utf-8");
        if (TextUtils.isEmpty(optString3)) {
            str = "utf-8";
        } else {
            str = optString3;
        }
        boolean optBoolean = uZModuleContext.optBoolean("overwrite", false);
        try {
            String generatePath = generatePath(optString);
            Integer num = this.iomap.get(optString);
            if (num == null) {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "没有打开文件或文件打开方式不对");
                uZModuleContext.error(this.ret, this.err, true);
                return;
            }
            int intValue = num.intValue();
            if (intValue == 2 || intValue == 3) {
                if (optBoolean) {
                    remove(new File(generatePath), uZModuleContext);
                    createFile(uZModuleContext, optString, false);
                    write(generatePath, optLong, str, optString2);
                } else {
                    write(generatePath, optLong, str, optString2);
                }
                this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
                uZModuleContext.success(this.ret, true);
                return;
            }
            this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
            this.err.put(NotificationCompat.CATEGORY_MESSAGE, "没有打开文件或文件打开方式不对");
            uZModuleContext.error(this.ret, this.err, true);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public long getFileLength(String str) {
        if (!TextUtils.isEmpty(str)) {
            File file = new File(str);
            if (file.exists()) {
                return file.length();
            }
            String makeRealPath = makeRealPath(str);
            Log.i(TAG, makeRealPath);
            try {
                InputStream guessInputStream = UZUtility.guessInputStream(makeRealPath);
                if (guessInputStream != null) {
                    return (long) guessInputStream.available();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return -1;
    }

    public void jsmethod_readUp(UZModuleContext uZModuleContext) {
        String str;
        String optString = uZModuleContext.optString("fd");
        int optInt = uZModuleContext.optInt("length");
        String optString2 = uZModuleContext.optString("codingType", "utf-8");
        if (TextUtils.isEmpty(optString2)) {
            str = "utf-8";
        } else {
            str = optString2;
        }
        try {
            if (isBlank(optString)) {
                String str2 = this.fd;
                if (isBlank(str2)) {
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "句柄不能为空");
                    uZModuleContext.error(this.ret, this.err, true);
                } else if (optInt == 0) {
                    readAsText(str2, this.readoffset, 0, str, uZModuleContext, false);
                } else {
                    int i = this.readoffset - optInt;
                    if (i > 0 || this.readoffset > 0) {
                        readAsText(str2, i, optInt, str, uZModuleContext, false);
                        return;
                    }
                    this.readoffset = 0;
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "已读到文件句首");
                    uZModuleContext.error(this.ret, this.err, true);
                }
            } else if (optInt == 0) {
                readAsText(optString, this.readoffset, 0, str, uZModuleContext, false);
            } else {
                int i2 = this.readoffset - optInt;
                if (i2 > 0 || this.readoffset > 0) {
                    readAsText(optString, i2, this.readoffset, str, uZModuleContext, false);
                    return;
                }
                this.readoffset = 0;
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "已读到文件句首");
                uZModuleContext.error(this.ret, this.err, true);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void jsmethod_readDown(UZModuleContext uZModuleContext) {
        String str;
        String optString = uZModuleContext.optString("fd");
        int optInt = uZModuleContext.optInt("length");
        String optString2 = uZModuleContext.optString("codingType", "utf-8");
        if (TextUtils.isEmpty(optString2)) {
            str = "utf-8";
        } else {
            str = optString2;
        }
        try {
            if (isBlank(optString)) {
                String str2 = this.fd;
                if (isBlank(str2)) {
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "句柄不能为空");
                    uZModuleContext.error(this.ret, this.err, true);
                } else if (optInt == 0) {
                    readAsText(str2, this.readoffset, 0, str, uZModuleContext, true);
                } else if (this.readoffset >= this.textSize) {
                    this.readoffset = this.textSize;
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "已读到文件末尾");
                    uZModuleContext.error(this.ret, this.err, true);
                } else {
                    readAsText(str2, this.readoffset, optInt, str, uZModuleContext, true);
                }
            } else if (optInt == 0) {
                readAsText(optString, this.readoffset, 0, str, uZModuleContext, true);
            } else if (this.readoffset >= this.textSize) {
                this.readoffset = this.textSize;
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "已读到文件末尾");
                uZModuleContext.error(this.ret, this.err, true);
            } else {
                readAsText(optString, this.readoffset, optInt, str, uZModuleContext, true);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void write(String str, long j, String str2, String str3) throws FileNotFoundException, IOException {
        byte[] bytes = str3.getBytes(str2);
        RandomAccessFile randomAccessFile = new RandomAccessFile(str, InternalZipConstants.WRITE_MODE);
        randomAccessFile.seek(j);
        randomAccessFile.write(bytes);
        randomAccessFile.close();
    }

    private void readAsText(String str, int i, int i2, String str2, UZModuleContext uZModuleContext, boolean z) throws Exception {
        int i3;
        String generatePath = generatePath(str);
        Integer num = this.iomap.get(str);
        if (num == null) {
            this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
            this.err.put(NotificationCompat.CATEGORY_MESSAGE, "没有打开文件或文件打开方式不对");
            uZModuleContext.error(this.ret, this.err, true);
            return;
        }
        int intValue = num.intValue();
        if (intValue == 1 || intValue == 3) {
            byte[] bArr = new byte[i2];
            if (generatePath.contains("android_asset")) {
                File file = new File(context().getExternalCacheDir(), generatePath.substring(generatePath.lastIndexOf(47) + 1, generatePath.length()).toLowerCase());
                String absolutePath = file.getAbsolutePath();
                if (!file.exists()) {
                    copy(context().getAssets().open(generatePath.substring(15, generatePath.length())), file);
                }
                generatePath = absolutePath;
            }
            RandomAccessFile randomAccessFile = new RandomAccessFile(generatePath, InternalZipConstants.WRITE_MODE);
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            if (i2 == 0) {
                while (true) {
                    int read = randomAccessFile.read(bArr);
                    if (read < 0) {
                        break;
                    }
                    byteArrayOutputStream.write(bArr, 0, read);
                }
            } else {
                randomAccessFile.seek(i > 0 ? (long) i : 0);
                if (i >= 0) {
                    i3 = i2;
                } else {
                    i3 = this.readoffset;
                    if (i3 < 0) {
                        i3 = 0;
                    }
                }
                byteArrayOutputStream.write(bArr, 0, randomAccessFile.read(bArr, 0, i3));
            }
            randomAccessFile.close();
            byte[] byteArray = byteArrayOutputStream.toByteArray();
            int length = byteArray.length;
            String str3 = new String(byteArray, str2);
            this.fd = str;
            if (i2 == 0) {
                this.readoffset = length;
                this.textSize = length;
            } else if (z) {
                this.readoffset = i + i2;
            } else {
                this.readoffset = i;
            }
            this.ret.put(UZOpenApi.DATA, str3);
            this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            uZModuleContext.success(this.ret, true);
            return;
        }
        this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
        this.err.put(NotificationCompat.CATEGORY_MESSAGE, "没有打开文件或文件打开方式不对");
        uZModuleContext.error(this.ret, this.err, true);
    }

    public ModuleResult readAsTextFixed(String str, int i, int i2, String str2, UZModuleContext uZModuleContext, boolean z) throws Exception {
        int i3;
        String generatePath = generatePath(str);
        Integer num = this.iomap.get(str);
        if (num == null) {
            return new ModuleResult(createErrorRet(-1, "文件打开失败"));
        }
        int intValue = num.intValue();
        if (intValue != 1 && intValue != 3) {
            return new ModuleResult(createErrorRet(-1, "文件打开失败"));
        }
        byte[] bArr = new byte[i2];
        if (generatePath.contains("android_asset")) {
            File file = new File(context().getExternalCacheDir(), generatePath.substring(generatePath.lastIndexOf(47) + 1, generatePath.length()).toLowerCase());
            String absolutePath = file.getAbsolutePath();
            if (!file.exists()) {
                copy(context().getAssets().open(generatePath.substring(15, generatePath.length())), file);
            }
            generatePath = absolutePath;
        }
        RandomAccessFile randomAccessFile = new RandomAccessFile(generatePath, InternalZipConstants.WRITE_MODE);
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        if (i2 == 0) {
            while (true) {
                int read = randomAccessFile.read(bArr);
                if (read < 0) {
                    break;
                }
                byteArrayOutputStream.write(bArr, 0, read);
            }
        } else {
            randomAccessFile.seek(i > 0 ? (long) i : 0);
            if (i >= 0) {
                i3 = i2;
            } else {
                i3 = this.readoffset;
                if (i3 < 0) {
                    i3 = 0;
                }
            }
            byteArrayOutputStream.write(bArr, 0, randomAccessFile.read(bArr, 0, i3));
        }
        randomAccessFile.close();
        byte[] byteArray = byteArrayOutputStream.toByteArray();
        int length = byteArray.length;
        String str3 = new String(byteArray, str2);
        this.fd = str;
        if (i2 == 0) {
            this.readoffset = length;
            this.textSize = length;
        } else if (z) {
            this.readoffset = i + i2;
        } else {
            this.readoffset = i;
        }
        return new ModuleResult(createRetWithData(true, 0, "", str3));
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x0034 A[SYNTHETIC, Splitter:B:24:0x0034] */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0041  */
    private void copy(InputStream inputStream, File file) throws IOException {
        Throwable th;
        FileOutputStream fileOutputStream = null;
        try {
            if (!file.exists()) {
                file.createNewFile();
            }
            FileOutputStream fileOutputStream2 = new FileOutputStream(file);
            try {
                byte[] bArr = new byte[1024];
                while (true) {
                    int read = inputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    fileOutputStream2.write(bArr, 0, read);
                }
                if (inputStream != null) {
                    try {
                        inputStream.close();
                    } catch (Throwable th2) {
                        fileOutputStream2.close();
                        throw th2;
                    }
                }
                fileOutputStream2.close();
            } catch (Throwable th3) {
                th = th3;
                fileOutputStream = fileOutputStream2;
                if (inputStream != null) {
                }
                if (fileOutputStream != null) {
                }
                throw th;
            }
        } catch (Throwable th4) {
            th = th4;
            if (inputStream != null) {
                try {
                    inputStream.close();
                } catch (Throwable th5) {
                    if (fileOutputStream != null) {
                        fileOutputStream.close();
                    }
                    throw th5;
                }
            }
            if (fileOutputStream != null) {
                fileOutputStream.close();
            }
            throw th;
        }
    }

    private void open(String str, int i) throws Exception {
        if (i == 1) {
            this.iomap.put(str, 1);
        } else if (i == 2) {
            this.iomap.put(str, 2);
        } else if (i == 3) {
            this.iomap.put(str, 3);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean transferTo(String str, String str2, UZModuleContext uZModuleContext) throws Exception {
        String generatePath = generatePath(str);
        String generatePath2 = generatePath(str2);
        File file = new File(generatePath);
        File file2 = new File(generatePath2);
        if (!file.exists()) {
            String isAssetPath = isAssetPath(generatePath);
            if (isAssetPath == null) {
                return false;
            }
            if (isAssetPath.endsWith(InternalZipConstants.ZIP_FILE_SEPARATOR)) {
                isAssetPath = isAssetPath.substring(0, isAssetPath.lastIndexOf(47));
            }
            return copyAssetRes(isAssetPath, generatePath2, true);
        } else if (file.isDirectory()) {
            copyDirectory(file, file2, uZModuleContext);
            return true;
        } else {
            copyFile(file, file2, uZModuleContext);
            return true;
        }
    }

    private void copyFile(File file, File file2, UZModuleContext uZModuleContext) throws Exception {
        if (!file2.exists()) {
            getFile(file2.getAbsolutePath(), true);
        }
        File file3 = new File(file2.getPath() + "//" + file.getName());
        FileChannel channel = new FileInputStream(file).getChannel();
        FileChannel channel2 = new FileOutputStream(file3).getChannel();
        channel.transferTo(0, channel.size(), channel2);
        channel.close();
        channel2.close();
    }

    public String substringAfterLast(String str, String str2) {
        int lastIndexOf;
        if (isEmpty(str)) {
            return str;
        }
        if (isEmpty(str2) || (lastIndexOf = str.lastIndexOf(str2)) == -1 || lastIndexOf == str.length() - str2.length()) {
            return "";
        }
        return str.substring(lastIndexOf + str2.length());
    }

    private void copyDirectory(File file, File file2, UZModuleContext uZModuleContext) throws Exception {
        File file3 = new File(file2, substringAfterLast(file.getAbsolutePath(), InternalZipConstants.ZIP_FILE_SEPARATOR));
        if (!file2.exists()) {
            getFile(file3.getAbsolutePath(), true);
        }
        File[] listFiles = file.listFiles();
        for (File file4 : listFiles) {
            if (file4.isDirectory()) {
                copyDirectory(file4, file3, uZModuleContext);
            } else {
                copyFile(file4, file3, uZModuleContext);
            }
        }
    }

    private JSONArray showDir(File file) throws Exception {
        JSONArray jSONArray = new JSONArray();
        File[] listFiles = file.listFiles();
        for (int i = 0; i < listFiles.length; i++) {
            listFiles[i].isDirectory();
            jSONArray.put(listFiles[i].getName());
        }
        return jSONArray;
    }

    private JSONArray showAssetDir(String str, JSONArray jSONArray) throws Exception {
        String[] strArr;
        AssetManager assets = context().getAssets();
        try {
            if (str.endsWith(InternalZipConstants.ZIP_FILE_SEPARATOR)) {
                str = str.substring(0, str.lastIndexOf(47));
            }
            strArr = assets.list(str);
        } catch (IOException e) {
            e.printStackTrace();
            strArr = null;
        }
        if (strArr != null && strArr.length > 0) {
            for (String str2 : strArr) {
                jSONArray.put(str2);
            }
        }
        return jSONArray;
    }

    private void remove(File file, UZModuleContext uZModuleContext) throws Exception {
        if (!file.exists()) {
            this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
            this.err.put(NotificationCompat.CATEGORY_MESSAGE, "文件不存在");
            uZModuleContext.error(this.ret, this.err, true);
        } else if (file.isFile()) {
            file.delete();
        } else {
            File[] listFiles = file.listFiles();
            for (int i = 0; i < listFiles.length; i++) {
                if (listFiles[i].isDirectory()) {
                    remove(listFiles[i], uZModuleContext);
                } else {
                    listFiles[i].delete();
                }
            }
            file.delete();
        }
    }

    public void remove_1(File file) {
        if (!file.exists()) {
            return;
        }
        if (file.isFile()) {
            file.delete();
            return;
        }
        File[] listFiles = file.listFiles();
        for (int i = 0; i < listFiles.length; i++) {
            if (listFiles[i].isDirectory()) {
                remove_1(listFiles[i]);
            } else {
                listFiles[i].delete();
            }
        }
        file.delete();
    }

    private void createFile(UZModuleContext uZModuleContext, boolean z) {
        String optString = uZModuleContext.optString("path");
        if (checkStorage()) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, getFile(optString, z));
                uZModuleContext.success(this.ret, true);
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "内存卡不可用");
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(this.ret, this.err, true);
        }
    }

    private void createFile(UZModuleContext uZModuleContext, String str, boolean z) {
        if (checkStorage()) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, getFile(str, z));
                uZModuleContext.success(this.ret, true);
            } catch (Exception e) {
                e.printStackTrace();
            }
        } else {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "内存卡不可用");
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(this.ret, this.err, true);
        }
    }

    private boolean getFile(String str, boolean z) throws Exception {
        File file = new File(generatePath(str));
        if (file.exists()) {
            return false;
        }
        File parentFile = file.getParentFile();
        if (!parentFile.exists()) {
            parentFile.mkdirs();
        }
        if (z) {
            return file.mkdir();
        }
        return file.createNewFile();
    }

    private boolean checkStorage() {
        return Environment.getExternalStorageState().equals("mounted");
    }

    public void jsmethod_getAttribute(UZModuleContext uZModuleContext) {
        String str;
        String generatePath = generatePath(uZModuleContext.optString("path"));
        try {
            if (!TextUtils.isEmpty(generatePath)) {
                File file = new File(generatePath);
                if (!file.exists()) {
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, "文件或文件夹不存在");
                    uZModuleContext.error(this.ret, this.err, false);
                    return;
                }
                this.size = 0;
                if (file.isDirectory()) {
                    getSize(file);
                    str = "folder";
                } else {
                    this.size = file.length();
                    str = "file";
                }
                long lastModified = file.lastModified();
                JSONObject jSONObject = new JSONObject();
                jSONObject.put("modificationDate", "" + (lastModified / 1000));
                jSONObject.put("size", this.size);
                jSONObject.put("type", str);
                this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
                this.ret.put("attribute", jSONObject);
                uZModuleContext.success(this.ret, false);
                return;
            }
            this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
            this.err.put(NotificationCompat.CATEGORY_MESSAGE, "路径不能为空");
            uZModuleContext.error(this.ret, this.err, false);
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

    private void getSize(File file) {
        if (file.isDirectory()) {
            File[] listFiles = file.listFiles();
            if (listFiles != null) {
                for (File file2 : listFiles) {
                    getSize(file2);
                }
                return;
            }
            return;
        }
        this.size += file.length();
    }

    public void jsmethod_exist(UZModuleContext uZModuleContext) {
        File file = new File(generatePath(uZModuleContext.optString("path")));
        try {
            if (!file.exists()) {
                this.ret.put("exist", false);
                this.ret.put("directory", false);
                uZModuleContext.success(this.ret, false);
            } else {
                boolean isDirectory = file.isDirectory();
                boolean z = true;
                this.ret.put("exist", true);
                JSONObject jSONObject = this.ret;
                if (!isDirectory) {
                    z = false;
                }
                jSONObject.put("directory", z);
                uZModuleContext.success(this.ret, false);
            }
            if (this.ret.has("exist")) {
                this.ret.remove("exist");
            }
            if (!this.ret.has("directory")) {
                return;
            }
        } catch (JSONException e) {
            e.printStackTrace();
            if (this.ret.has("exist")) {
                this.ret.remove("exist");
            }
            if (!this.ret.has("directory")) {
                return;
            }
        } catch (Throwable th) {
            if (this.ret.has("exist")) {
                this.ret.remove("exist");
            }
            if (this.ret.has("directory")) {
                this.ret.remove("directory");
            }
            throw th;
        }
        this.ret.remove("directory");
    }

    public String generatePath(String str) {
        if (!TextUtils.isEmpty(str) && str.startsWith("content://")) {
            return str;
        }
        String makeRealPath = UZUtility.makeRealPath(str, getWidgetInfo());
        if (TextUtils.isEmpty(makeRealPath)) {
            return null;
        }
        if (makeRealPath.contains("file://")) {
            return substringAfter(makeRealPath, "file://");
        }
        makeRealPath.contains("android_asset");
        return makeRealPath;
    }

    private boolean copyAssetRes(String str, String str2, boolean z) {
        String[] strArr;
        File file;
        InputStream inputStream;
        InputStream inputStream2;
        AssetManager assets = context().getAssets();
        if (z) {
            try {
                inputStream2 = assets.open(str);
            } catch (Exception unused) {
                inputStream2 = null;
            }
            if (inputStream2 != null) {
                int lastIndexOf = str.lastIndexOf(47);
                if (lastIndexOf >= 0) {
                    str = str.substring(lastIndexOf + 1);
                }
                try {
                    streamCopy(inputStream2, new File(str2 + str));
                    return true;
                } catch (IOException e) {
                    e.printStackTrace();
                    return false;
                }
            }
        }
        try {
            strArr = assets.list(str);
        } catch (IOException e2) {
            e2.printStackTrace();
            strArr = null;
        }
        File file2 = new File(str2);
        File parentFile = file2.getParentFile();
        if (!parentFile.exists()) {
            parentFile.mkdirs();
        }
        for (String str3 : strArr) {
            if (str3.contains(".")) {
                file = new File(file2, str3);
                if (file.exists()) {
                    file.delete();
                }
                if (str.length() != 0) {
                    try {
                        inputStream = assets.open(str + File.separator + str3);
                    } catch (IOException e3) {
                        e3.printStackTrace();
                    }
                } else {
                    try {
                        inputStream = assets.open(str3);
                    } catch (IOException e4) {
                        e4.printStackTrace();
                    }
                }
                try {
                    streamCopy(inputStream, file);
                } catch (Exception e5) {
                    e5.printStackTrace();
                }
            } else if (str.length() == 0) {
                copyAssetRes(str3, str2 + str3 + File.separator, false);
            } else {
                copyAssetRes(str + File.separator + str3, str2 + str3 + File.separator, false);
            }
        }
        return true;
        inputStream = null;
        streamCopy(inputStream, file);
    }

    private void streamCopy(InputStream inputStream, File file) throws IOException {
        File parentFile = file.getParentFile();
        if (!parentFile.exists()) {
            parentFile.mkdirs();
        }
        FileOutputStream fileOutputStream = new FileOutputStream(file);
        byte[] bArr = new byte[8192];
        while (true) {
            int read = inputStream.read(bArr);
            if (read > 0) {
                fileOutputStream.write(bArr, 0, read);
            } else {
                inputStream.close();
                fileOutputStream.close();
                return;
            }
        }
    }

    private String isAssetPath(String str) {
        if (str == null || !str.contains("android_asset/")) {
            return null;
        }
        return str.substring(str.lastIndexOf("android_asset/") + 14);
    }

    public void jsmethod_readByLength(UZModuleContext uZModuleContext) {
        int i;
        String optString = uZModuleContext.optString("path");
        JSONObject optJSONObject = uZModuleContext.optJSONObject("substring");
        int i2 = -1;
        if (optJSONObject != null) {
            i = optJSONObject.optInt("start");
            if (!optJSONObject.isNull("length")) {
                i2 = optJSONObject.optInt("length");
            }
        } else {
            i = 0;
        }
        try {
            InputStream guessInputStream = UZUtility.guessInputStream(makeRealPath(optString));
            if (guessInputStream == null) {
                callback(uZModuleContext, false, 1, "找不到此文件");
                return;
            }
            int available = guessInputStream.available();
            if (i2 <= 0) {
                i2 = available;
            }
            if (i2 + i > available) {
                callback(uZModuleContext, false, 1, "超出文件大小");
                return;
            }
            char[] cArr = new char[i2];
            new BufferedReader(new InputStreamReader(guessInputStream)).read(cArr, i, i2);
            StringBuilder sb = new StringBuilder();
            sb.append(cArr);
            JSONObject jSONObject = new JSONObject();
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject.put(NotificationCompat.CATEGORY_STATUS, true);
                jSONObject.put("content", sb.toString());
                jSONObject.put("codingType", "utf-8");
                jSONObject2.put("code", 0);
                jSONObject2.put(NotificationCompat.CATEGORY_MESSAGE, "操作成功");
            } catch (JSONException e) {
                e.printStackTrace();
            }
            uZModuleContext.error(jSONObject, jSONObject2, false);
        } catch (IOException e2) {
            callback(uZModuleContext, false, 1, "找不到此文件");
            e2.printStackTrace();
        }
    }

    public void jsmethod_writeByLength(UZModuleContext uZModuleContext) {
        int i;
        int i2;
        String optString = uZModuleContext.optString("path");
        String optString2 = uZModuleContext.optString("content");
        File file = new File(optString);
        if (!file.exists()) {
            file = new File(makeRealPath(optString));
        }
        JSONObject optJSONObject = uZModuleContext.optJSONObject("place");
        if (optJSONObject != null) {
            i = !optJSONObject.isNull("start") ? optJSONObject.optInt("start") : 0;
            i2 = !optJSONObject.isNull("strategy") ? optJSONObject.optInt("strategy", -1) : -1;
        } else {
            i2 = -1;
            i = 0;
        }
        StringBuilder fileContent = getFileContent(file);
        try {
            BufferedWriter bufferedWriter = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file)));
            if (i2 == -1) {
                bufferedWriter.write(optString2, i, optString2.length());
            } else if (i2 != 0) {
                if (i2 > 0) {
                    if (i + i2 >= fileContent.length()) {
                        i2 = (fileContent.length() - i) - 1;
                    }
                    fileContent.replace(i, i2 + i, "");
                    fileContent.insert(i, optString2);
                    bufferedWriter.write(fileContent.toString());
                }
            } else if (fileContent.length() == 0 || fileContent.length() <= i) {
                fileContent.append(optString2);
                bufferedWriter.write(fileContent.toString());
            } else {
                fileContent.insert(i, optString2);
                bufferedWriter.write(fileContent.toString());
            }
            bufferedWriter.flush();
            bufferedWriter.close();
            callback(uZModuleContext, true, 0, "操作成功");
        } catch (FileNotFoundException e) {
            callback(uZModuleContext, false, 1, e.getMessage());
        } catch (IOException e2) {
            callback(uZModuleContext, false, 1, e2.getMessage());
        }
    }

    public StringBuilder getFileContent(File file) {
        if (file == null || !file.exists()) {
            return null;
        }
        StringBuilder sb = new StringBuilder();
        try {
            BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new FileInputStream(file)));
            while (true) {
                String readLine = bufferedReader.readLine();
                if (readLine == null) {
                    break;
                }
                sb.append(readLine);
                sb.append("\n");
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e2) {
            e2.printStackTrace();
        }
        return sb;
    }

    public void jsmethod_rmdir(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("path");
        if (TextUtils.isEmpty(optString)) {
            callback(uZModuleContext, false, 1, "找不到此文件");
            return;
        }
        File file = new File(optString);
        if (file.exists()) {
            recursiveDelete(file);
            callback(uZModuleContext, true, 0, "删除目录成功");
            return;
        }
        File file2 = new File(makeRealPath(optString));
        if (file2.exists()) {
            recursiveDelete(file2);
            callback(uZModuleContext, true, 0, "删除目录成功");
            return;
        }
        callback(uZModuleContext, false, 1, "找不到此文件");
    }

    public void callback(UZModuleContext uZModuleContext, boolean z, int i, String str) {
        JSONObject jSONObject = new JSONObject();
        JSONObject jSONObject2 = new JSONObject();
        try {
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, z);
            jSONObject2.put("code", i);
            jSONObject2.put(NotificationCompat.CATEGORY_MESSAGE, str);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        uZModuleContext.error(jSONObject, jSONObject2, false);
    }

    public void callback(UZModuleContext uZModuleContext, JSONObject jSONObject, JSONObject jSONObject2) {
        uZModuleContext.error(jSONObject, jSONObject2, false);
    }

    public void recursiveDelete(File file) {
        if (file != null) {
            if (file.isDirectory()) {
                File[] listFiles = file.listFiles();
                for (File file2 : listFiles) {
                    if (file2.isFile()) {
                        file2.delete();
                    } else {
                        recursiveDelete(file2);
                        file2.delete();
                    }
                }
                file.delete();
                return;
            }
            file.delete();
        }
    }

    public void jsmethod_getMD5(UZModuleContext uZModuleContext) {
        if (!uZModuleContext.isNull("path")) {
            try {
                String fileMD5 = getFileMD5(UZUtility.guessInputStream(makeRealPath(uZModuleContext.optString("path"))));
                if (!TextUtils.isEmpty(fileMD5)) {
                    callback(uZModuleContext, true, fileMD5);
                } else {
                    callback(uZModuleContext, false, (String) null);
                }
            } catch (IOException e) {
                e.printStackTrace();
                callback(uZModuleContext, false, (String) null);
            }
        } else {
            callback(uZModuleContext, false, (String) null);
        }
    }

    public void callback(UZModuleContext uZModuleContext, boolean z, String str) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, z);
            jSONObject.put("md5Str", str);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        uZModuleContext.success(jSONObject, false);
    }

    public static String getFileMD5(InputStream inputStream) {
        if (inputStream == null) {
            return null;
        }
        byte[] bArr = new byte[1024];
        try {
            MessageDigest instance = MessageDigest.getInstance("MD5");
            while (true) {
                int read = inputStream.read(bArr, 0, 1024);
                if (read != -1) {
                    instance.update(bArr, 0, read);
                } else {
                    inputStream.close();
                    return new BigInteger(1, instance.digest()).toString(16);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }

    public ModuleResult jsmethod_createDirSync_sync(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("path");
        if (TextUtils.isEmpty(optString)) {
            return new ModuleResult(createErrorRet(1, "找不到文件错误"));
        }
        File file = new File(uZModuleContext.makeRealPath(optString));
        if (file.exists()) {
            return new ModuleResult(createErrorRet(7, "文件已存在错误"));
        }
        if (file.exists() || !file.mkdirs()) {
            return new ModuleResult(createErrorRet(1, "找不到文件错误"));
        }
        return new ModuleResult(createSuccessRet());
    }

    public JSONObject createSuccessRet() {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, true);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jSONObject;
    }

    public JSONObject createErrorRet(int i, String str) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("code", i);
            jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, str);
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, false);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jSONObject;
    }

    public JSONObject createCommonRet(boolean z, int i, String str, JSONArray jSONArray) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("code", i);
            if (!TextUtils.isEmpty(str)) {
                jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, str);
            }
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, z);
            jSONObject.put(UZOpenApi.DATA, jSONArray);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jSONObject;
    }

    public JSONObject createRetWithData(boolean z, int i, String str, String str2) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("code", i);
            if (!TextUtils.isEmpty(str)) {
                jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, str);
            }
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, z);
            jSONObject.put(UZOpenApi.DATA, str2);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jSONObject;
    }

    public ModuleResult jsmethod_rmdirSync_sync(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("path");
        if (TextUtils.isEmpty(optString)) {
            return new ModuleResult(createErrorRet(1, "找不到此文件"));
        }
        File file = new File(optString);
        if (file.exists()) {
            recursiveDelete(file);
            return new ModuleResult(createSuccessRet());
        }
        File file2 = new File(makeRealPath(optString));
        if (!file2.exists()) {
            return new ModuleResult(createErrorRet(1, "找不到此文件"));
        }
        recursiveDelete(file2);
        return new ModuleResult(createSuccessRet());
    }

    public ModuleResult jsmethod_createFileSync_sync(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("path");
        if (TextUtils.isEmpty(optString)) {
            return new ModuleResult(createErrorRet(1, "找不到此文件"));
        }
        try {
            if (!checkStorage() || !getFile(optString, false)) {
                return new ModuleResult(createErrorRet(1, "找不到此文件"));
            }
            return new ModuleResult(createSuccessRet());
        } catch (Exception unused) {
            return new ModuleResult(createErrorRet(1, "找不到此文件"));
        }
    }

    public ModuleResult jsmethod_removeSync_sync(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("path");
        if (TextUtils.isEmpty(optString)) {
            return new ModuleResult(createErrorRet(1, "找不到此文件"));
        }
        File file = new File(generatePath(optString));
        if (!file.exists()) {
            return new ModuleResult(createErrorRet(1, "找不到此文件"));
        }
        remove_1(file);
        return new ModuleResult(createSuccessRet());
    }

    public String getFileNameByPath(String str) {
        int lastIndexOf;
        if (TextUtils.isEmpty(str) || (lastIndexOf = str.lastIndexOf(InternalZipConstants.ZIP_FILE_SEPARATOR)) == -1) {
            return null;
        }
        return str.substring(lastIndexOf);
    }

    public ModuleResult jsmethod_copyToSync_sync(UZModuleContext uZModuleContext) {
        String replace = uZModuleContext.optString("oldPath").replace("%", "$");
        String replace2 = uZModuleContext.optString("newPath").replace("%", "$");
        String replace3 = uZModuleContext.makeRealPath(replace).replace("$", "%");
        String replace4 = uZModuleContext.makeRealPath(replace2).replace("$", "%");
        File file = new File(replace4);
        if (!file.exists()) {
            file.mkdirs();
        }
        try {
            InputStream guessInputStream = UZUtility.guessInputStream(replace3);
            FileOutputStream fileOutputStream = new FileOutputStream(new File(replace4, getFileNameByPath(replace3)));
            byte[] bArr = new byte[1024];
            while (true) {
                int read = guessInputStream.read(bArr);
                if (read >= 0) {
                    fileOutputStream.write(bArr, 0, read);
                } else {
                    fileOutputStream.close();
                    guessInputStream.close();
                    return new ModuleResult(createSuccessRet());
                }
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return new ModuleResult(createErrorRet(1, "找不到此文件"));
        } catch (IOException e2) {
            e2.printStackTrace();
            return new ModuleResult(createErrorRet(2, "IO 异常"));
        }
    }

    public ModuleResult jsmethod_moveToSync_sync(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("oldPath");
        String optString2 = uZModuleContext.optString("newPath");
        String generatePath = generatePath(optString);
        String generatePath2 = generatePath(optString2);
        File file = new File(generatePath);
        if (!file.exists()) {
            new ModuleResult(createErrorRet(1, "找不到文件错误"));
        }
        if (file.isFile() && moveFile(generatePath, generatePath2)) {
            return new ModuleResult(createSuccessRet());
        }
        if (!file.isDirectory() || !moveDirectory(generatePath, generatePath2)) {
            return new ModuleResult(createErrorRet(5, "无效操作错误"));
        }
        return new ModuleResult(createSuccessRet());
    }

    public ModuleResult jsmethod_renameSync_sync(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("oldPath");
        String optString2 = uZModuleContext.optString("newPath");
        try {
            String generatePath = generatePath(optString);
            String generatePath2 = generatePath(optString2);
            if (new File(generatePath).isDirectory()) {
                moveTo(generatePath, generatePath2, uZModuleContext);
            } else {
                renameTo(generatePath, generatePath2, uZModuleContext);
            }
            return new ModuleResult(createSuccessRet());
        } catch (Exception unused) {
            return new ModuleResult(createErrorRet(5, "操作失败"));
        }
    }

    public ModuleResult jsmethod_readDirSync_sync(UZModuleContext uZModuleContext) {
        try {
            String generatePath = generatePath(uZModuleContext.optString("path"));
            File file = new File(generatePath);
            if (file.exists()) {
                return new ModuleResult(createCommonRet(true, 0, (String) null, showDir(file)));
            }
            String isAssetPath = isAssetPath(generatePath);
            if (isAssetPath == null) {
                return new ModuleResult(createErrorRet(5, "操作失败"));
            }
            JSONArray jSONArray = new JSONArray();
            showAssetDir(isAssetPath, jSONArray);
            return new ModuleResult(createCommonRet(true, 0, (String) null, jSONArray));
        } catch (Exception unused) {
            return new ModuleResult(createErrorRet(5, "操作失败"));
        }
    }

    public JSONObject createCommonRet(boolean z, int i, String str, String str2) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("code", i);
            if (!TextUtils.isEmpty(str)) {
                jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, str);
            }
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, z);
            jSONObject.put("fd", str2);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jSONObject;
    }

    public ModuleResult jsmethod_openSync_sync(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("path");
        String optString2 = uZModuleContext.optString("flags", "read");
        this.fileLen = getFileLength(optString);
        try {
            String makeRealPath = UZUtility.makeRealPath(optString, getWidgetInfo());
            if (makeRealPath.contains("android_asset")) {
                try {
                    if (!"read".equals(optString2)) {
                        return new ModuleResult(createErrorRet(5, "操作失败"));
                    }
                    open(optString, 1);
                    return new ModuleResult(createCommonRet(true, 0, "", optString));
                } catch (Exception unused) {
                    return new ModuleResult(createErrorRet(5, "操作失败"));
                }
            } else {
                if (makeRealPath.contains("file://")) {
                    makeRealPath = substringAfter(makeRealPath, "file://");
                }
                File file = new File(makeRealPath);
                if (!file.exists()) {
                    return new ModuleResult(createErrorRet(1, "文件不存在"));
                }
                if (file.isDirectory()) {
                    return new ModuleResult(createErrorRet(5, "操作失败"));
                }
                this.fd = makeRealPath;
                if ("read".equals(optString2)) {
                    open(makeRealPath, 1);
                } else if ("write".equals(optString2)) {
                    open(makeRealPath, 2);
                } else if ("read_write".equals(optString2)) {
                    open(makeRealPath, 3);
                }
                return new ModuleResult(createCommonRet(true, 0, "", makeRealPath));
            }
        } catch (Exception unused2) {
            return new ModuleResult(createErrorRet(5, "操作失败"));
        }
    }

    public ModuleResult jsmethod_readSync_sync(UZModuleContext uZModuleContext) {
        String str;
        try {
            String optString = uZModuleContext.optString("fd");
            int optInt = uZModuleContext.optInt("offset");
            int optInt2 = uZModuleContext.optInt("length");
            String optString2 = uZModuleContext.optString("codingType", "utf-8");
            if (TextUtils.isEmpty(optString2)) {
                str = "utf-8";
            } else {
                str = optString2;
            }
            long fileLength = getFileLength(optString);
            this.fileLen = fileLength;
            if (fileLength <= 0) {
                return new ModuleResult(createErrorRet(-1, "文件为空"));
            }
            if (optInt2 <= 0) {
                optInt2 = (int) fileLength;
            }
            if (optInt < 0) {
                return new ModuleResult(createErrorRet(-1, "offset 不能小于零"));
            }
            if (((long) (optInt + optInt2)) > this.fileLen) {
                return new ModuleResult(createErrorRet(-1, "超过文件大小 "));
            }
            return readAsTextFixed(optString, optInt, optInt2, str, uZModuleContext, true);
        } catch (Exception unused) {
            return new ModuleResult(createErrorRet(5, "操作失败"));
        }
    }

    public ModuleResult jsmethod_readUpSync_sync(UZModuleContext uZModuleContext) {
        String str;
        String optString = uZModuleContext.optString("fd");
        int optInt = uZModuleContext.optInt("length");
        String optString2 = uZModuleContext.optString("codingType", "utf-8");
        if (TextUtils.isEmpty(optString2)) {
            str = "utf-8";
        } else {
            str = optString2;
        }
        try {
            if (isBlank(optString)) {
                String str2 = this.fd;
                if (isBlank(str2)) {
                    return new ModuleResult(createErrorRet(-1, "句柄不能为空 "));
                }
                if (optInt == 0) {
                    readAsTextFixed(str2, this.readoffset, 0, str, uZModuleContext, false);
                } else {
                    int i = this.readoffset - optInt;
                    if (i > 0 || this.readoffset > 0) {
                        readAsTextFixed(str2, i, optInt, str, uZModuleContext, false);
                    } else {
                        this.readoffset = 0;
                        return new ModuleResult(createErrorRet(-1, "已读到文件句首 "));
                    }
                }
            } else if (optInt == 0) {
                readAsTextFixed(optString, this.readoffset, 0, str, uZModuleContext, false);
            } else {
                int i2 = this.readoffset - optInt;
                if (i2 > 0 || this.readoffset > 0) {
                    readAsTextFixed(optString, i2, this.readoffset, str, uZModuleContext, false);
                } else {
                    this.readoffset = 0;
                    return new ModuleResult(createErrorRet(-1, "已读到文件句首 "));
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return new ModuleResult(createErrorRet(-1, "操作失败"));
    }

    public ModuleResult jsmethod_readDownSync_sync(UZModuleContext uZModuleContext) {
        String str;
        String optString = uZModuleContext.optString("fd");
        int optInt = uZModuleContext.optInt("length");
        String optString2 = uZModuleContext.optString("codingType", "utf-8");
        if (TextUtils.isEmpty(optString2)) {
            str = "utf-8";
        } else {
            str = optString2;
        }
        try {
            if (isBlank(optString)) {
                String str2 = this.fd;
                if (isBlank(str2)) {
                    return new ModuleResult(createErrorRet(-1, "句柄不能为空 "));
                }
                if (optInt == 0) {
                    readAsTextFixed(str2, this.readoffset, 0, str, uZModuleContext, true);
                } else if (this.readoffset >= this.textSize) {
                    this.readoffset = this.textSize;
                    return new ModuleResult(createErrorRet(-1, "已读到文件句首 "));
                } else {
                    readAsTextFixed(str2, this.readoffset, optInt, str, uZModuleContext, true);
                }
            } else if (optInt == 0) {
                readAsTextFixed(optString, this.readoffset, 0, str, uZModuleContext, true);
            } else if (this.readoffset >= this.textSize) {
                this.readoffset = this.textSize;
                return new ModuleResult(createErrorRet(-1, "已读到文件句首 "));
            } else {
                readAsTextFixed(optString, this.readoffset, optInt, str, uZModuleContext, true);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return new ModuleResult(createErrorRet(-1, "操作失败"));
    }

    public ModuleResult jsmethod_writeSync_sync(UZModuleContext uZModuleContext) {
        String str;
        String optString = uZModuleContext.optString("fd");
        String optString2 = uZModuleContext.optString(UZOpenApi.DATA);
        int optInt = uZModuleContext.optInt("offset");
        String optString3 = uZModuleContext.optString("codingType", "utf-8");
        if (TextUtils.isEmpty(optString3)) {
            str = "utf-8";
        } else {
            str = optString3;
        }
        boolean optBoolean = uZModuleContext.optBoolean("overwrite", false);
        try {
            String generatePath = generatePath(optString);
            Integer num = this.iomap.get(optString);
            if (num == null) {
                return new ModuleResult(createErrorRet(-1, "没有打开文件或文件打开方式不对 "));
            }
            int intValue = num.intValue();
            if (intValue != 2 && intValue != 3) {
                return new ModuleResult(createErrorRet(-1, "没有打开文件或文件打开方式不对 "));
            }
            if (optBoolean) {
                remove(new File(generatePath), uZModuleContext);
                createFile(uZModuleContext, optString, false);
                write(generatePath, (long) optInt, str, optString2);
            } else {
                write(generatePath, (long) optInt, str, optString2);
            }
            return new ModuleResult(createSuccessRet());
        } catch (Exception e) {
            e.printStackTrace();
            return new ModuleResult(createErrorRet(-1, "操作失败"));
        }
    }

    public ModuleResult jsmethod_closeSync_sync(UZModuleContext uZModuleContext) {
        this.iomap.remove(uZModuleContext.optString("fd"));
        return new ModuleResult(createSuccessRet());
    }

    public ModuleResult jsmethod_existSync_sync(UZModuleContext uZModuleContext) {
        File file = new File(generatePath(uZModuleContext.optString("path")));
        try {
            boolean z = false;
            if (!file.exists()) {
                JSONObject jSONObject = new JSONObject();
                jSONObject.put("exist", false);
                jSONObject.put("directory", false);
                return new ModuleResult(jSONObject);
            }
            JSONObject jSONObject2 = new JSONObject();
            boolean isDirectory = file.isDirectory();
            jSONObject2.put("exist", true);
            if (isDirectory) {
                z = true;
            }
            jSONObject2.put("directory", z);
            return new ModuleResult(jSONObject2);
        } catch (JSONException e) {
            e.printStackTrace();
            return new ModuleResult(createErrorRet(-1, "操作失败"));
        }
    }

    public ModuleResult jsmethod_getAttributeSync_sync(UZModuleContext uZModuleContext) {
        String str;
        String makeRealPath = uZModuleContext.makeRealPath(uZModuleContext.optString("path"));
        try {
            if (TextUtils.isEmpty(makeRealPath)) {
                return new ModuleResult(createErrorRet(-1, "路径不能为空"));
            }
            File file = new File(makeRealPath);
            if (!file.exists()) {
                return new ModuleResult(createErrorRet(-1, "文件或文件夹不存在"));
            }
            this.size = 0;
            if (file.isDirectory()) {
                getSize(file);
                str = "folder";
            } else {
                this.size = file.length();
                str = "file";
            }
            long lastModified = file.lastModified();
            JSONObject jSONObject = new JSONObject();
            JSONObject jSONObject2 = new JSONObject();
            jSONObject2.put("modificationDate", "" + (lastModified / 1000));
            jSONObject2.put("size", this.size);
            jSONObject2.put("type", str);
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, true);
            jSONObject.put("attribute", jSONObject2);
            return new ModuleResult(jSONObject);
        } catch (JSONException e) {
            e.printStackTrace();
            return new ModuleResult(createErrorRet(-1, "操作失败"));
        }
    }

    public ModuleResult jsmethod_readByLengthSync_sync(UZModuleContext uZModuleContext) {
        int i;
        int i2;
        String optString = uZModuleContext.optString("path");
        JSONObject optJSONObject = uZModuleContext.optJSONObject("substring");
        if (optJSONObject != null) {
            i2 = optJSONObject.optInt("start");
            i = !optJSONObject.isNull("length") ? optJSONObject.optInt("length") : -1;
        } else {
            i = -1;
            i2 = 0;
        }
        try {
            InputStream guessInputStream = UZUtility.guessInputStream(makeRealPath(optString));
            if (guessInputStream == null) {
                return new ModuleResult(createErrorRet(-1, "找不到此文件"));
            }
            int available = guessInputStream.available();
            if (i <= 0) {
                i = available;
            }
            if (i + i2 > available) {
                return new ModuleResult(createErrorRet(-1, "超出文件大小"));
            }
            char[] cArr = new char[i];
            new BufferedReader(new InputStreamReader(guessInputStream)).read(cArr, i2, i);
            StringBuilder sb = new StringBuilder();
            sb.append(cArr);
            JSONObject jSONObject = new JSONObject();
            try {
                jSONObject.put(NotificationCompat.CATEGORY_STATUS, true);
                jSONObject.put("content", sb.toString());
                jSONObject.put("codingType", "utf-8");
                jSONObject.put("code", 0);
                jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, "操作成功");
            } catch (JSONException e) {
                e.printStackTrace();
            }
            return new ModuleResult(jSONObject);
        } catch (IOException e2) {
            e2.printStackTrace();
            return new ModuleResult(createErrorRet(-1, "找不到此文件"));
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:16:0x0059 A[Catch:{ FileNotFoundException -> 0x00a9, IOException -> 0x009a }] */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0083 A[Catch:{ FileNotFoundException -> 0x00a9, IOException -> 0x009a }] */
    public ModuleResult jsmethod_writeByLengthSync_sync(UZModuleContext uZModuleContext) {
        int i;
        String optString = uZModuleContext.optString("path");
        String optString2 = uZModuleContext.optString("content");
        File file = new File(optString);
        if (!file.exists()) {
            file = new File(makeRealPath(optString));
        }
        JSONObject optJSONObject = uZModuleContext.optJSONObject("place");
        int i2 = 0;
        if (optJSONObject != null) {
            if (!optJSONObject.isNull("start")) {
                i2 = optJSONObject.optInt("start");
            }
            if (!optJSONObject.isNull("strategy")) {
                i = optJSONObject.optInt("strategy", -1);
                StringBuilder fileContent = getFileContent(file);
                BufferedWriter bufferedWriter = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file)));
                if (i != -1) {
                    bufferedWriter.write(optString2, i2, optString2.length());
                } else if (i != 0) {
                    if (i > 0) {
                        bufferedWriter.write(optString2, i2, i);
                    }
                } else if (fileContent.length() == 0 || fileContent.length() <= i2) {
                    fileContent.append(optString2);
                    bufferedWriter.write(fileContent.toString());
                } else {
                    fileContent.insert(i2, optString2);
                    bufferedWriter.write(fileContent.toString());
                }
                bufferedWriter.flush();
                bufferedWriter.close();
                return new ModuleResult(createSuccessRet());
            }
        }
        i = -1;
        StringBuilder fileContent2 = getFileContent(file);
        try {
            BufferedWriter bufferedWriter2 = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file)));
            if (i != -1) {
            }
            bufferedWriter2.flush();
            bufferedWriter2.close();
            return new ModuleResult(createSuccessRet());
        } catch (FileNotFoundException e) {
            return new ModuleResult(createErrorRet(-1, e.getMessage()));
        } catch (IOException e2) {
            return new ModuleResult(createErrorRet(-1, e2.getMessage()));
        }
    }

    public ModuleResult jsmethod_getMD5Sync_sync(UZModuleContext uZModuleContext) {
        if (uZModuleContext.isNull("path")) {
            return new ModuleResult(createErrorRet(-1, "操作失败"));
        }
        try {
            String fileMD5 = getFileMD5(UZUtility.guessInputStream(makeRealPath(uZModuleContext.optString("path"))));
            if (TextUtils.isEmpty(fileMD5)) {
                return new ModuleResult(createErrorRet(-1, "操作失败"));
            }
            JSONObject jSONObject = new JSONObject();
            try {
                jSONObject.put(NotificationCompat.CATEGORY_STATUS, true);
                jSONObject.put("md5Str", fileMD5);
            } catch (JSONException e) {
                e.printStackTrace();
            }
            return new ModuleResult(jSONObject);
        } catch (IOException e2) {
            e2.printStackTrace();
            return new ModuleResult(createErrorRet(-1, "操作失败"));
        }
    }

    public void jsmethod_cutFile(UZModuleContext uZModuleContext) {
        String makeRealPath = uZModuleContext.makeRealPath(uZModuleContext.optString("path"));
        String makeRealPath2 = uZModuleContext.makeRealPath(uZModuleContext.optString("cutFiles"));
        File file = new File(makeRealPath2);
        if (!file.exists()) {
            file.mkdirs();
        }
        int optInt = uZModuleContext.optInt("cutSize", 1);
        try {
            FileInputStream fileInputStream = new FileInputStream(new File(makeRealPath));
            byte[] bArr = new byte[(optInt * 1024 * 1024)];
            JSONArray jSONArray = new JSONArray();
            int i = 0;
            while (true) {
                int read = fileInputStream.read(bArr);
                if (read != -1) {
                    File file2 = new File(makeRealPath2, "part" + String.valueOf(i));
                    FileOutputStream fileOutputStream = new FileOutputStream(file2);
                    fileOutputStream.write(bArr, 0, read);
                    fileOutputStream.close();
                    i++;
                    jSONArray.put(file2.getAbsolutePath());
                } else {
                    JSONObject jSONObject = new JSONObject();
                    jSONObject.put(NotificationCompat.CATEGORY_STATUS, true);
                    jSONObject.put("cutFiles", jSONArray);
                    uZModuleContext.success(jSONObject, false);
                    return;
                }
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            callback_failed(uZModuleContext);
        } catch (IOException e2) {
            e2.printStackTrace();
            callback_failed(uZModuleContext);
        } catch (Exception e3) {
            e3.printStackTrace();
            callback_failed(uZModuleContext);
        }
    }

    public void callback_failed(UZModuleContext uZModuleContext) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, false);
            uZModuleContext.success(jSONObject, false);
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

    public JSONObject cb_failed() {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, false);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return jSONObject;
    }

    public void callback(UZModuleContext uZModuleContext, boolean z) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put(NotificationCompat.CATEGORY_STATUS, z);
            uZModuleContext.success(jSONObject, false);
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

    public ModuleResult jsmethod_cutFileSync_sync(UZModuleContext uZModuleContext) {
        String makeRealPath = uZModuleContext.makeRealPath(uZModuleContext.optString("path"));
        String makeRealPath2 = uZModuleContext.makeRealPath(uZModuleContext.optString("cutFiles"));
        File file = new File(makeRealPath2);
        if (!file.exists()) {
            file.mkdirs();
        }
        int optInt = uZModuleContext.optInt("cutSize", 1);
        try {
            FileInputStream fileInputStream = new FileInputStream(new File(makeRealPath));
            byte[] bArr = new byte[(optInt * 1024 * 1024)];
            JSONArray jSONArray = new JSONArray();
            int i = 0;
            while (true) {
                int read = fileInputStream.read(bArr);
                if (read != -1) {
                    File file2 = new File(makeRealPath2, "part" + String.valueOf(i));
                    FileOutputStream fileOutputStream = new FileOutputStream(file2);
                    fileOutputStream.write(bArr, 0, read);
                    fileOutputStream.close();
                    i++;
                    jSONArray.put(file2.getAbsolutePath());
                } else {
                    JSONObject jSONObject = new JSONObject();
                    jSONObject.put(NotificationCompat.CATEGORY_STATUS, true);
                    jSONObject.put("cutFiles", jSONArray);
                    return new ModuleResult(jSONObject);
                }
            }
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return new ModuleResult(cb_failed());
        } catch (IOException e2) {
            e2.printStackTrace();
            return new ModuleResult(cb_failed());
        } catch (Exception e3) {
            e3.printStackTrace();
            return new ModuleResult(cb_failed());
        }
    }
}
