package com.uzmap.pkg.uzmodules.uzFNScanner.Zxing.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.ComposeShader;
import android.graphics.LinearGradient;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.RadialGradient;
import android.graphics.Rect;
import android.graphics.RectF;
import android.graphics.Shader;
import android.graphics.SweepGradient;
import android.support.v4.view.MotionEventCompat;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.View;
import com.google.zxing.ResultPoint;
import com.uzmap.pkg.uzcore.UZResourcesIDFinder;
import com.uzmap.pkg.uzkit.UZUtility;
import com.uzmap.pkg.uzmodules.uzFNScanner.UzFNScanner;
import com.uzmap.pkg.uzmodules.uzFNScanner.Zxing.camera.CameraManager;
import com.uzmap.pkg.uzmodules.uzFNScanner.utlis.JsParamsUtil;
import java.util.Collection;
import java.util.HashSet;

public final class ViewfinderView extends View {
    private static final long ANIMATION_DELAY = 10;
    private static final int CORNER_RECT_HEIGHT = 40;
    private static final int CORNER_RECT_WIDTH = 8;
    private static final int OPAQUE = 255;
    private static final int SCANNER_LINE_HEIGHT = 10;
    private static final int SCANNER_LINE_MOVE_DISTANCE = 5;
    public static int scannerEnd;
    public static int scannerStart;
    private int cornerColor = MotionEventCompat.ACTION_POINTER_INDEX_MASK;
    private int frameColor = -1862270977;
    private int laserColor = MotionEventCompat.ACTION_POINTER_INDEX_MASK;
    private Collection<ResultPoint> lastPossibleResultPoints;
    private Context mContext;
    private String mLineColor;
    private String mOrientationStr;
    private int maskColor = 1610612736;
    private final Paint paint;
    private Collection<ResultPoint> possibleResultPoints;
    private Bitmap resultBitmap;
    private int resultColor = -1342177280;
    private int resultPointColor = -1056964864;
    private final String text = "对准条形码／二维码，即可自动扫描";

    public ViewfinderView(Context context, AttributeSet attributeSet) {
        super(context, attributeSet);
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, new int[]{context.getResources().getIdentifier("orientation", "attr", context.getPackageName())});
        this.mOrientationStr = obtainStyledAttributes.getString(UZResourcesIDFinder.getResStyleableID("ViewfinderView_orientation"));
        obtainStyledAttributes.recycle();
        scannerStart = 0;
        scannerEnd = 0;
        Paint paint2 = new Paint();
        this.paint = paint2;
        paint2.setAntiAlias(true);
        this.possibleResultPoints = new HashSet(5);
        this.mContext = context;
    }

    public void onDraw(Canvas canvas) {
        Rect rect;
        if (TextUtils.equals("port", this.mOrientationStr)) {
            rect = CameraManager.get().getFramingRect();
        } else if (TextUtils.equals("land", this.mOrientationStr)) {
            rect = CameraManager.get().getLandFramingRect();
        } else {
            rect = CameraManager.get().getFramingRect();
        }
        if (rect != null) {
            if (scannerStart == 0 || scannerEnd == 0) {
                scannerStart = rect.top;
                scannerEnd = rect.bottom;
            }
            drawExterior(canvas, rect, canvas.getWidth(), canvas.getHeight());
            if (this.resultBitmap != null) {
                this.paint.setAlpha(255);
                canvas.drawBitmap(this.resultBitmap, (float) rect.left, (float) rect.top, this.paint);
                return;
            }
            drawLine(canvas, rect);
            postInvalidateDelayed(ANIMATION_DELAY, rect.left, rect.top, rect.right, rect.bottom);
        }
    }

    private void drawExterior(Canvas canvas, Rect rect, int i, int i2) {
        this.paint.setColor(this.resultBitmap != null ? this.resultColor : this.maskColor);
        float f = (float) i;
        canvas.drawRect(0.0f, 0.0f, f, (float) rect.top, this.paint);
        canvas.drawRect(0.0f, (float) rect.top, (float) rect.left, (float) (rect.bottom + 1), this.paint);
        canvas.drawRect((float) (rect.right + 1), (float) rect.top, f, (float) (rect.bottom + 1), this.paint);
        canvas.drawRect(0.0f, (float) (rect.bottom + 1), f, (float) i2, this.paint);
    }

    private void drawLine(Canvas canvas, Rect rect) {
        drawFrame(canvas, rect);
        drawCorner(canvas, rect);
        drawTextInfo(canvas, rect);
        drawLaserScanner(canvas, rect);
        Collection<ResultPoint> collection = this.possibleResultPoints;
        Collection<ResultPoint> collection2 = this.lastPossibleResultPoints;
        if (collection.isEmpty()) {
            this.lastPossibleResultPoints = null;
        } else {
            this.possibleResultPoints = new HashSet(5);
            this.lastPossibleResultPoints = collection;
            this.paint.setAlpha(255);
            this.paint.setColor(this.resultPointColor);
            for (ResultPoint resultPoint : collection) {
                canvas.drawCircle(((float) rect.left) + resultPoint.getX(), ((float) rect.top) + resultPoint.getY(), 6.0f, this.paint);
            }
        }
        if (collection2 != null) {
            this.paint.setAlpha(127);
            this.paint.setColor(this.resultPointColor);
            for (ResultPoint resultPoint2 : collection2) {
                canvas.drawCircle(((float) rect.left) + resultPoint2.getX(), ((float) rect.top) + resultPoint2.getY(), 3.0f, this.paint);
            }
        }
    }

    private void drawTextInfo(Canvas canvas, Rect rect) {
        this.paint.setColor(UZUtility.parseCssColor(JsParamsUtil.getInstance().getHintTextColor()));
        this.paint.setTextSize((float) sp2px(this.mContext, (float) JsParamsUtil.getInstance().getHintTextSize()));
        this.paint.setTextAlign(Paint.Align.CENTER);
        String optString = UzFNScanner.mModuleContext.optString("hintText", "对准条形码／二维码，即可自动扫描");
        int i = rect.left + rect.right;
        if (optString != null && optString.length() > 0) {
            float f = (float) i;
            if (this.paint.measureText(optString) > f) {
                int breakText = this.paint.breakText(optString, 0, optString.length(), true, f, null);
                optString = optString.substring(0, breakText - 3) + "...";
            }
        }
        canvas.drawText(optString, (float) (rect.left + (rect.width() / 2)), (float) (rect.bottom + 40 + 50), this.paint);
    }

    public static int sp2px(Context context, float f) {
        return (int) ((f * context.getResources().getDisplayMetrics().scaledDensity) + 0.5f);
    }

    private void drawFrame(Canvas canvas, Rect rect) {
        this.paint.setColor(Color.parseColor("#90FFFFFF"));
        canvas.drawRect((float) rect.left, (float) rect.top, (float) (rect.right + 1), (float) (rect.top + 2), this.paint);
        canvas.drawRect((float) rect.left, (float) (rect.top + 2), (float) (rect.left + 2), (float) (rect.bottom - 1), this.paint);
        canvas.drawRect((float) (rect.right - 1), (float) rect.top, (float) (rect.right + 1), (float) (rect.bottom - 1), this.paint);
        canvas.drawRect((float) rect.left, (float) (rect.bottom - 1), (float) (rect.right + 1), (float) (rect.bottom + 1), this.paint);
    }

    private void drawCorner(Canvas canvas, Rect rect) {
        this.paint.setColor(-1);
        canvas.drawRect((float) rect.left, (float) rect.top, (float) (rect.left + 8), (float) (rect.top + 40), this.paint);
        canvas.drawRect((float) rect.left, (float) rect.top, (float) (rect.left + 40), (float) (rect.top + 8), this.paint);
        canvas.drawRect((float) (rect.right - 8), (float) rect.top, (float) rect.right, (float) (rect.top + 40), this.paint);
        canvas.drawRect((float) (rect.right - 40), (float) rect.top, (float) rect.right, (float) (rect.top + 8), this.paint);
        canvas.drawRect((float) rect.left, (float) (rect.bottom - 8), (float) (rect.left + 40), (float) rect.bottom, this.paint);
        canvas.drawRect((float) rect.left, (float) (rect.bottom - 40), (float) (rect.left + 8), (float) rect.bottom, this.paint);
        canvas.drawRect((float) (rect.right - 8), (float) (rect.bottom - 40), (float) rect.right, (float) rect.bottom, this.paint);
        canvas.drawRect((float) (rect.right - 40), (float) (rect.bottom - 8), (float) rect.right, (float) rect.bottom, this.paint);
    }

    private void drawLaserScanner(Canvas canvas, Rect rect) {
        RadialGradient radialGradient;
        this.paint.setColor(-1);
        LinearGradient linearGradient = new LinearGradient((float) rect.left, (float) scannerStart, (float) rect.left, (float) (scannerStart + 10), shadeColor(this.laserColor), this.laserColor, Shader.TileMode.MIRROR);
        if (TextUtils.isEmpty(this.mLineColor)) {
            radialGradient = new RadialGradient((float) (rect.left + (rect.width() / 2)), (float) (scannerStart + 5), 360.0f, -1, shadeColor(-1), Shader.TileMode.MIRROR);
        } else {
            radialGradient = new RadialGradient((float) (rect.left + (rect.width() / 2)), (float) (scannerStart + 5), 360.0f, UZUtility.parseCssColor(this.mLineColor), shadeColor(UZUtility.parseCssColor(this.mLineColor)), Shader.TileMode.MIRROR);
        }
        new SweepGradient((float) (rect.left + (rect.width() / 2)), (float) (scannerStart + 10), shadeColor(this.laserColor), this.laserColor);
        new ComposeShader(radialGradient, linearGradient, PorterDuff.Mode.ADD);
        this.paint.setShader(radialGradient);
        if (scannerStart <= scannerEnd) {
            canvas.drawOval(new RectF((float) (rect.left + 20), (float) scannerStart, (float) (rect.right - 20), (float) (scannerStart + 10)), this.paint);
            scannerStart += 5;
        } else {
            scannerStart = rect.top;
        }
        this.paint.setShader(null);
    }

    public void setLineColor(String str) {
        this.mLineColor = str;
    }

    public int shadeColor(int i) {
        String hexString = Integer.toHexString(i);
        return Integer.valueOf("20" + hexString.substring(2), 16).intValue();
    }

    public void drawViewfinder() {
        this.resultBitmap = null;
        invalidate();
    }

    public void drawResultBitmap(Bitmap bitmap) {
        this.resultBitmap = bitmap;
        invalidate();
    }

    public void addPossibleResultPoint(ResultPoint resultPoint) {
        this.possibleResultPoints.add(resultPoint);
    }
}
