package com.uzmap.pkg.uzmodules.uzdb;

import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Build;
import android.text.TextUtils;
import java.io.File;
import java.text.DecimalFormat;
import java.util.Hashtable;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class DBManager {
    static final int DB_VERSION = 1;
    private static DBManager instance;
    private Map<String, DBWrap> mDBbMap = new Hashtable();

    private DBManager() {
    }

    public DBWrap getDatabase(String str) {
        return this.mDBbMap.get(str);
    }

    public void putDatabase(String str, DBWrap dBWrap) {
        this.mDBbMap.put(str, dBWrap);
    }

    public static DBManager instance() {
        if (instance == null) {
            instance = new DBManager();
        }
        return instance;
    }

    public boolean openDatabase(Context context, String str, String str2, boolean z) {
        SQLiteDatabase sQLiteDatabase = null;
        if (!TextUtils.isEmpty(str2)) {
            File file = new File(str2);
            File parentFile = file.getParentFile();
            if (!parentFile.exists()) {
                parentFile.mkdirs();
            }
            sQLiteDatabase = SQLiteDatabase.openOrCreateDatabase(file, (SQLiteDatabase.CursorFactory) null);
        } else if (str != null && !TextUtils.isEmpty(str)) {
            String absolutePath = context.getDatabasePath(str).getAbsolutePath();
            File file2 = new File(absolutePath);
            if (!file2.exists() || file2.length() <= 0) {
                sQLiteDatabase = new DBHelper(context, absolutePath, 1).getWritableDatabase();
            } else {
                try {
                    sQLiteDatabase = SQLiteDatabase.openDatabase(absolutePath, null, 0);
                } catch (Exception unused) {
                }
            }
        }
        if (sQLiteDatabase != null) {
            DBWrap dBWrap = new DBWrap(sQLiteDatabase);
            dBWrap.setReadonly(z);
            putDatabase(str, dBWrap);
        }
        return sQLiteDatabase != null;
    }

    public boolean closeDatabase(String str) {
        if (TextUtils.isEmpty(str)) {
            return false;
        }
        DBWrap dBWrap = null;
        try {
            dBWrap = this.mDBbMap.remove(str);
        } catch (Exception unused) {
        }
        if (dBWrap == null) {
            return false;
        }
        try {
            if (dBWrap.inTransaction()) {
                dBWrap.setTransactionSuccessful();
                dBWrap.endTransaction();
            }
            dBWrap.close();
            return true;
        } catch (Exception unused2) {
            return true;
        }
    }

    public JSONArray rawQuery(String str, String str2) throws Exception {
        String str3;
        DBWrap database = getDatabase(str);
        JSONArray jSONArray = new JSONArray();
        Cursor rawQuery = database.rawQuery(str2, null);
        if (rawQuery != null) {
            while (rawQuery.moveToNext()) {
                int columnCount = rawQuery.getColumnCount();
                JSONObject jSONObject = new JSONObject();
                for (int i = 0; i < columnCount; i++) {
                    String columnName = rawQuery.getColumnName(i);
                    if (Build.VERSION.SDK_INT < 11) {
                        str3 = rawQuery.getString(i);
                    } else {
                        int type = rawQuery.getType(i);
                        if (type != 0) {
                            str3 = type != 1 ? type != 2 ? type != 3 ? type != 4 ? null : new String(rawQuery.getBlob(i)) : rawQuery.getString(i) : String.valueOf(formatDouble(rawQuery.getDouble(i))) : String.valueOf(rawQuery.getLong(i));
                        } else {
                            str3 = rawQuery.getString(i);
                        }
                    }
                    if (TextUtils.isEmpty(str3)) {
                        str3 = "";
                    }
                    try {
                        jSONObject.put(columnName, str3);
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                }
                jSONArray.put(jSONObject);
            }
            rawQuery.close();
        }
        return jSONArray;
    }

    private String formatDouble(double d) {
        DecimalFormat decimalFormat = new DecimalFormat();
        decimalFormat.setMinimumFractionDigits(0);
        decimalFormat.setMaximumFractionDigits(6);
        return decimalFormat.format(d).replaceAll(",", "");
    }
}
