package com.uzmap.pkg.uzmodules.uzdb;

import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Build;
import android.support.v4.app.NotificationCompat;
import android.text.TextUtils;
import android.util.Log;
import com.uzmap.pkg.uzcore.UZWebView;
import com.uzmap.pkg.uzcore.uzmodule.ModuleResult;
import com.uzmap.pkg.uzcore.uzmodule.UZModule;
import com.uzmap.pkg.uzcore.uzmodule.UZModuleContext;
import com.uzmap.pkg.uzkit.UZOpenApi;
import com.uzmap.pkg.uzkit.UZUtility;
import com.uzmap.pkg.uzmodules.uzdb.daoImpl.DBDaoImpl;
import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Map;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class UzDatebase extends UZModule {
    private static final String TAG = "db";
    JSONObject err = new JSONObject();
    private Map<String, SQLiteDatabase> map = new HashMap();
    JSONObject ret = new JSONObject();

    public UzDatebase(UZWebView uZWebView) {
        super(uZWebView);
    }

    public void jsmethod_openDatabase(UZModuleContext uZModuleContext) {
        Log.v(TAG, "open");
        String optString = uZModuleContext.optString("name");
        String optString2 = uZModuleContext.optString("path");
        if (!TextUtils.isEmpty(optString)) {
            this.map.put(optString, new DBDaoImpl(this.mContext).openDatabase(optString, generatePath(optString2)));
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            } catch (JSONException e) {
                e.printStackTrace();
            }
            uZModuleContext.success(this.ret, true);
        }
    }

    public ModuleResult jsmethod_openDatabaseSync_sync(UZModuleContext uZModuleContext) {
        Log.v(TAG, "open");
        String optString = uZModuleContext.optString("name");
        String optString2 = uZModuleContext.optString("path");
        if (TextUtils.isEmpty(optString)) {
            return new ModuleResult();
        }
        this.map.put(optString, new DBDaoImpl(this.mContext).openDatabase(optString, generatePath(optString2)));
        try {
            this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
        } catch (JSONException e) {
            e.printStackTrace();
        }
        return new ModuleResult(this.ret);
    }

    public String generatePath(String str) {
        String makeRealPath = UZUtility.makeRealPath(str, getWidgetInfo());
        if (TextUtils.isEmpty(makeRealPath)) {
            return null;
        }
        if (makeRealPath.contains("file://")) {
            return substringAfter(makeRealPath, "file://");
        }
        makeRealPath.contains("android_asset");
        return makeRealPath;
    }

    public boolean isEmpty(CharSequence charSequence) {
        return charSequence == null || charSequence.length() == 0;
    }

    public String substringAfter(String str, String str2) {
        int indexOf;
        if (isEmpty(str)) {
            return str;
        }
        if (str2 == null || (indexOf = str.indexOf(str2)) == -1) {
            return "";
        }
        return str.substring(indexOf + str2.length());
    }

    public void jsmethod_closeDatabase(UZModuleContext uZModuleContext) {
        Log.v(TAG, "closeDatabase");
        String optString = uZModuleContext.optString("name");
        SQLiteDatabase sQLiteDatabase = this.map.get(optString);
        if (sQLiteDatabase == null) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "数据库没有打开");
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e) {
                e.printStackTrace();
            }
        } else {
            if (sQLiteDatabase.inTransaction()) {
                sQLiteDatabase.endTransaction();
            }
            sQLiteDatabase.close();
            this.map.remove(optString);
            this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            uZModuleContext.success(this.ret, true);
        }
    }

    public ModuleResult jsmethod_closeDatabaseSync_sync(UZModuleContext uZModuleContext) {
        Log.v(TAG, "closeDatabase");
        String optString = uZModuleContext.optString("name");
        SQLiteDatabase sQLiteDatabase = this.map.get(optString);
        if (sQLiteDatabase == null) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.ret.put(NotificationCompat.CATEGORY_MESSAGE, "数据库没有打开");
                return new ModuleResult(this.ret);
            } catch (JSONException e) {
                e.printStackTrace();
            }
        } else {
            if (sQLiteDatabase.inTransaction()) {
                sQLiteDatabase.endTransaction();
            }
            sQLiteDatabase.close();
            this.map.remove(optString);
            this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            return new ModuleResult(this.ret);
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.uzmap.pkg.uzcore.uzmodule.UZModule
    public void onClean() {
        Map<String, SQLiteDatabase> map2 = this.map;
        if (map2 != null) {
            for (Map.Entry<String, SQLiteDatabase> entry : map2.entrySet()) {
                SQLiteDatabase value = entry.getValue();
                if (value != null) {
                    if (value.inTransaction()) {
                        value.endTransaction();
                    }
                    value.close();
                    this.map.clear();
                }
            }
        }
    }

    public void jsmethod_transaction(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("name");
        String optString2 = uZModuleContext.optString("operation");
        SQLiteDatabase sQLiteDatabase = this.map.get(optString);
        if (sQLiteDatabase == null) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "数据库没有打开");
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e) {
                e.printStackTrace();
            }
        } else {
            if ("begin".equals(optString2)) {
                sQLiteDatabase.beginTransaction();
            } else if ("commit".equals(optString2)) {
                sQLiteDatabase.setTransactionSuccessful();
            } else if ("rollback".equals(optString2)) {
                sQLiteDatabase.endTransaction();
            }
            this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            uZModuleContext.success(this.ret, true);
        }
    }

    public ModuleResult jsmethod_transactionSync_sync(UZModuleContext uZModuleContext) {
        String optString = uZModuleContext.optString("name");
        String optString2 = uZModuleContext.optString("operation");
        SQLiteDatabase sQLiteDatabase = this.map.get(optString);
        if (sQLiteDatabase == null) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.ret.put(NotificationCompat.CATEGORY_MESSAGE, "数据库没有打开");
                return new ModuleResult(this.ret);
            } catch (JSONException e) {
                e.printStackTrace();
            }
        } else {
            if ("begin".equals(optString2)) {
                sQLiteDatabase.beginTransaction();
            } else if ("commit".equals(optString2)) {
                sQLiteDatabase.setTransactionSuccessful();
            } else if ("rollback".equals(optString2)) {
                sQLiteDatabase.endTransaction();
            }
            this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            return new ModuleResult(this.ret);
        }
    }

    public void jsmethod_executeSql(UZModuleContext uZModuleContext) {
        Log.v(TAG, "executeSql");
        String optString = uZModuleContext.optString("name");
        String optString2 = uZModuleContext.optString("sql");
        SQLiteDatabase sQLiteDatabase = this.map.get(optString);
        if (sQLiteDatabase == null) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "数据库没有打开");
                uZModuleContext.error(this.ret, this.err, true);
            } catch (Exception e) {
                try {
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.err.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                } catch (JSONException e2) {
                    e2.printStackTrace();
                }
                uZModuleContext.error(this.ret, this.err, true);
            }
        } else {
            sQLiteDatabase.execSQL(optString2);
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            } catch (JSONException e3) {
                e3.printStackTrace();
            }
            uZModuleContext.success(this.ret, true);
        }
    }

    public ModuleResult jsmethod_executeSqlSync_sync(UZModuleContext uZModuleContext) {
        Log.v(TAG, "executeSql");
        String optString = uZModuleContext.optString("name");
        String optString2 = uZModuleContext.optString("sql");
        SQLiteDatabase sQLiteDatabase = this.map.get(optString);
        if (sQLiteDatabase == null) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.ret.put(NotificationCompat.CATEGORY_MESSAGE, "数据库没有打开");
                return new ModuleResult(this.ret);
            } catch (Exception e) {
                try {
                    this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                    this.ret.put(NotificationCompat.CATEGORY_MESSAGE, e.getMessage());
                } catch (JSONException e2) {
                    e2.printStackTrace();
                }
                return new ModuleResult(this.ret);
            }
        } else {
            sQLiteDatabase.execSQL(optString2);
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, true);
            } catch (JSONException e3) {
                e3.printStackTrace();
            }
            return new ModuleResult(this.ret);
        }
    }

    public void jsmethod_selectSql(UZModuleContext uZModuleContext) {
        String str;
        String optString = uZModuleContext.optString("name");
        String optString2 = uZModuleContext.optString("sql");
        SQLiteDatabase sQLiteDatabase = this.map.get(optString);
        if (sQLiteDatabase == null) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, "数据库没有打开");
                uZModuleContext.error(this.ret, this.err, true);
                return;
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        JSONArray jSONArray = new JSONArray();
        try {
            Cursor rawQuery = sQLiteDatabase.rawQuery(optString2, null);
            if (rawQuery != null) {
                while (rawQuery.moveToNext()) {
                    int columnCount = rawQuery.getColumnCount();
                    JSONObject jSONObject = new JSONObject();
                    for (int i = 0; i < columnCount; i++) {
                        String columnName = rawQuery.getColumnName(i);
                        if (Build.VERSION.SDK_INT < 11) {
                            str = rawQuery.getString(i);
                        } else {
                            int type = rawQuery.getType(i);
                            if (type != 0) {
                                str = type != 1 ? type != 2 ? type != 3 ? type != 4 ? null : new String(rawQuery.getBlob(i)) : rawQuery.getString(i) : String.valueOf(formatDouble(rawQuery.getDouble(i))) : String.valueOf(rawQuery.getInt(i));
                            } else {
                                str = rawQuery.getString(i);
                            }
                        }
                        if (TextUtils.isEmpty(str)) {
                            str = "";
                        }
                        try {
                            jSONObject.put(columnName, str);
                        } catch (JSONException e2) {
                            e2.printStackTrace();
                        }
                    }
                    jSONArray.put(jSONObject);
                }
                rawQuery.close();
            }
            JSONObject jSONObject2 = new JSONObject();
            jSONObject2.put(UZOpenApi.DATA, jSONArray);
            jSONObject2.put(NotificationCompat.CATEGORY_STATUS, true);
            uZModuleContext.success(jSONObject2, true);
        } catch (Exception e3) {
            try {
                this.err.put(NotificationCompat.CATEGORY_MESSAGE, e3.getMessage());
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                uZModuleContext.error(this.ret, this.err, true);
            } catch (JSONException e4) {
                e4.printStackTrace();
                e3.printStackTrace();
            }
        }
    }

    public ModuleResult jsmethod_selectSqlSync_sync(UZModuleContext uZModuleContext) {
        String str;
        String optString = uZModuleContext.optString("name");
        String optString2 = uZModuleContext.optString("sql");
        SQLiteDatabase sQLiteDatabase = this.map.get(optString);
        if (sQLiteDatabase == null) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                this.ret.put(NotificationCompat.CATEGORY_MESSAGE, "数据库没有打开");
                return new ModuleResult(this.ret);
            } catch (JSONException e) {
                e.printStackTrace();
            }
        }
        JSONArray jSONArray = new JSONArray();
        try {
            Cursor rawQuery = sQLiteDatabase.rawQuery(optString2, null);
            if (rawQuery != null) {
                while (rawQuery.moveToNext()) {
                    int columnCount = rawQuery.getColumnCount();
                    JSONObject jSONObject = new JSONObject();
                    for (int i = 0; i < columnCount; i++) {
                        String columnName = rawQuery.getColumnName(i);
                        if (Build.VERSION.SDK_INT < 11) {
                            str = rawQuery.getString(i);
                        } else {
                            int type = rawQuery.getType(i);
                            if (type != 0) {
                                str = type != 1 ? type != 2 ? type != 3 ? type != 4 ? null : new String(rawQuery.getBlob(i)) : rawQuery.getString(i) : String.valueOf(formatDouble(rawQuery.getDouble(i))) : String.valueOf(rawQuery.getInt(i));
                            } else {
                                str = rawQuery.getString(i);
                            }
                        }
                        if (TextUtils.isEmpty(str)) {
                            str = "";
                        }
                        try {
                            jSONObject.put(columnName, str);
                        } catch (JSONException e2) {
                            e2.printStackTrace();
                        }
                    }
                    jSONArray.put(jSONObject);
                }
                rawQuery.close();
            }
            JSONObject jSONObject2 = new JSONObject();
            jSONObject2.put(UZOpenApi.DATA, jSONArray);
            jSONObject2.put(NotificationCompat.CATEGORY_STATUS, true);
            return new ModuleResult(jSONObject2);
        } catch (Exception e3) {
            try {
                this.ret.put(NotificationCompat.CATEGORY_MESSAGE, e3.getMessage());
                this.ret.put(NotificationCompat.CATEGORY_STATUS, false);
                return new ModuleResult(this.ret);
            } catch (JSONException e4) {
                e4.printStackTrace();
                e3.printStackTrace();
                return new ModuleResult();
            }
        }
    }

    private String formatDouble(double d) {
        DecimalFormat decimalFormat = new DecimalFormat();
        decimalFormat.setMinimumFractionDigits(0);
        decimalFormat.setMaximumFractionDigits(6);
        return decimalFormat.format(d).replaceAll(",", "");
    }
}
