package com.uzmap.pkg.uzmodules.uzmam;

import android.support.v4.app.NotificationCompat;
import com.deepe.sdk.ViewEntity;
import com.uzmap.pkg.openapi.IncPackage;
import com.uzmap.pkg.openapi.mam.DataCollector;
import com.uzmap.pkg.openapi.mam.ResetListener;
import com.uzmap.pkg.openapi.mam.Results;
import com.uzmap.pkg.openapi.mam.ServerRewriter;
import com.uzmap.pkg.openapi.mam.SmartUpdateCallback;
import com.uzmap.pkg.openapi.mam.SmartUpdateListener;
import com.uzmap.pkg.openapi.mam.UpdateCallback;
import com.uzmap.pkg.openapi.mam.VersionManager;
import com.uzmap.pkg.uzcore.UZWebView;
import com.uzmap.pkg.uzcore.uzmodule.UZModule;
import com.uzmap.pkg.uzcore.uzmodule.UZModuleContext;
import java.util.ArrayList;
import java.util.List;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class UzMAM extends UZModule {
    private static boolean sSmartRuning;
    private static boolean sUpdateRuning;
    private ServerConfig mServerConfig;

    /* access modifiers changed from: protected */
    @Override // com.uzmap.pkg.uzcore.uzmodule.UZModule
    public void onClean() {
    }

    public UzMAM(UZWebView uZWebView) {
        super(uZWebView);
    }

    public final void jsmethod_config(UZModuleContext uZModuleContext) {
        this.mServerConfig = ServerConfig.parse(uZModuleContext);
    }

    public final void jsmethod_checkUpdate(UZModuleContext uZModuleContext) {
        if (!updateRuning()) {
            checkUpdate(uZModuleContext, this.mServerConfig);
        }
    }

    public final void jsmethod_addEvent(UZModuleContext uZModuleContext) {
        DataCollector.addEvent(uZModuleContext.optString("name"));
    }

    public final void jsmethod_checkSmartUpdate(UZModuleContext uZModuleContext) {
        if (!smartRuning()) {
            checkSmartUpdate(uZModuleContext, this.mServerConfig);
        }
    }

    public final void jsmethod_startSmartUpdate(final UZModuleContext uZModuleContext) {
        if (!smartRuning()) {
            setSmartRuning(true);
            List<IncPackage> incPackage = toIncPackage(uZModuleContext.optJSONArray("packages"));
            final JSONObject jSONObject = new JSONObject();
            VersionManager.startSmartUpdate(new SmartUpdateListener() {
                /* class com.uzmap.pkg.uzmodules.uzmam.UzMAM.AnonymousClass1 */

                @Override // com.uzmap.pkg.openapi.mam.SmartUpdateListener
                public void onStart(List<IncPackage> list) {
                }

                @Override // com.uzmap.pkg.openapi.mam.SmartUpdateListener
                public void onStatusChange(int i, int i2, int i3, double d, String str) {
                    try {
                        jSONObject.put("state", i);
                        jSONObject.put("total", i2);
                        jSONObject.put("current", i3);
                        jSONObject.put(NotificationCompat.CATEGORY_PROGRESS, (int) d);
                        jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, str);
                    } catch (JSONException unused) {
                    }
                    uZModuleContext.success(jSONObject, false);
                }

                @Override // com.uzmap.pkg.openapi.mam.SmartUpdateListener
                public void onFinish(boolean z, String str) {
                    UzMAM.setSmartRuning(false);
                }
            }, incPackage, this.mServerConfig);
        }
    }

    public final void jsmethod_resetSmartUpdate(final UZModuleContext uZModuleContext) {
        if (!smartRuning()) {
            setSmartRuning(true);
            final JSONObject jSONObject = new JSONObject();
            VersionManager.resetSmartUpdate(new ResetListener() {
                /* class com.uzmap.pkg.uzmodules.uzmam.UzMAM.AnonymousClass2 */
                private long mTotalSize;

                @Override // com.uzmap.pkg.openapi.mam.ResetListener
                public void onStart(long j) {
                    this.mTotalSize = j;
                }

                @Override // com.uzmap.pkg.openapi.mam.ResetListener
                public void onProgress(double d) {
                    try {
                        jSONObject.put("finish", false);
                        jSONObject.put("reset", this.mTotalSize > 0);
                        jSONObject.put(NotificationCompat.CATEGORY_PROGRESS, d);
                        jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, "success");
                    } catch (JSONException unused) {
                    }
                    uZModuleContext.success(jSONObject, false);
                }

                @Override // com.uzmap.pkg.openapi.mam.ResetListener
                public void onEnd(boolean z, String str) {
                    boolean z2 = false;
                    UzMAM.setSmartRuning(false);
                    try {
                        jSONObject.put("finish", true);
                        JSONObject jSONObject = jSONObject;
                        if (this.mTotalSize > 0) {
                            z2 = true;
                        }
                        jSONObject.put("reset", z2);
                        jSONObject.put(NotificationCompat.CATEGORY_PROGRESS, 100);
                        jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, str);
                    } catch (JSONException unused) {
                    }
                    uZModuleContext.success(jSONObject, true);
                }

                @Override // com.uzmap.pkg.openapi.mam.ResetListener
                public void onError(String str) {
                    UzMAM.setSmartRuning(false);
                }
            });
        }
    }

    private void checkUpdate(final UZModuleContext uZModuleContext, ServerRewriter serverRewriter) {
        setUpdateRuning(true);
        VersionManager.checkUpdate(new UpdateCallback() {
            /* class com.uzmap.pkg.uzmodules.uzmam.UzMAM.AnonymousClass3 */

            @Override // com.uzmap.pkg.openapi.mam.UpdateCallback
            public void onResult(Results results) {
                UzMAM.setUpdateRuning(false);
                if (results.success()) {
                    uZModuleContext.success(results.data, true, true);
                    return;
                }
                JSONObject jSONObject = new JSONObject();
                try {
                    jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, results.data);
                    jSONObject.put("statusCode", results.statusCode);
                    jSONObject.put("code", results.statusCode == 401 ? "auth" : "fail");
                } catch (JSONException e) {
                    e.printStackTrace();
                }
                uZModuleContext.error(null, jSONObject, true);
            }
        }, serverRewriter);
    }

    private void checkSmartUpdate(final UZModuleContext uZModuleContext, ServerRewriter serverRewriter) {
        setSmartRuning(true);
        VersionManager.checkSmartUpdate(new SmartUpdateCallback() {
            /* class com.uzmap.pkg.uzmodules.uzmam.UzMAM.AnonymousClass4 */

            @Override // com.uzmap.pkg.openapi.mam.SmartUpdateCallback
            public void onResult(List<IncPackage> list, String str) {
                UzMAM.setSmartRuning(false);
                JSONObject jSONObject = new JSONObject();
                JSONArray jSONArray = new JSONArray();
                if (list != null) {
                    try {
                        for (IncPackage incPackage : list) {
                            JSONObject jSONObject2 = new JSONObject();
                            jSONObject2.put("incNo", incPackage.version);
                            jSONObject2.put("silent", incPackage.silent);
                            jSONObject2.put("extra", incPackage.extra);
                            jSONObject2.put(ViewEntity.KEY_URL, incPackage.url);
                            jSONObject2.put("index", incPackage.index);
                            jSONArray.put(jSONObject2);
                        }
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                }
                jSONObject.put("packages", jSONArray);
                uZModuleContext.success(jSONObject, true);
            }

            @Override // com.uzmap.pkg.openapi.mam.SmartUpdateCallback
            public void onError(int i, String str) {
                UzMAM.setSmartRuning(false);
                try {
                    JSONObject jSONObject = new JSONObject();
                    jSONObject.put(NotificationCompat.CATEGORY_MESSAGE, str);
                    jSONObject.put("statusCode", i);
                    uZModuleContext.error(null, jSONObject, true);
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        }, serverRewriter);
    }

    private List<IncPackage> toIncPackage(JSONArray jSONArray) {
        if (jSONArray == null || jSONArray.length() == 0) {
            return null;
        }
        int length = jSONArray.length();
        ArrayList arrayList = new ArrayList(length);
        for (int i = 0; i < length; i++) {
            JSONObject optJSONObject = jSONArray.optJSONObject(i);
            if (optJSONObject != null) {
                int optInt = optJSONObject.optInt("incNo");
                String optString = optJSONObject.optString(ViewEntity.KEY_URL);
                boolean optBoolean = optJSONObject.optBoolean("silent");
                String optString2 = optJSONObject.optString("extra");
                int optInt2 = optJSONObject.optInt("index");
                IncPackage incPackage = new IncPackage();
                incPackage.version = optInt;
                incPackage.url = optString;
                incPackage.silent = optBoolean;
                incPackage.index = optInt2;
                incPackage.extra = optString2;
                arrayList.add(incPackage);
            }
        }
        return arrayList;
    }

    static void setUpdateRuning(boolean z) {
        sUpdateRuning = z;
    }

    static boolean updateRuning() {
        return sUpdateRuning;
    }

    static void setSmartRuning(boolean z) {
        sSmartRuning = z;
    }

    static boolean smartRuning() {
        return sSmartRuning;
    }
}
