package com.zakww.loratm.api;

import android.content.Context;
import android.content.Intent;
import android.os.Build;
import android.os.PowerManager;
import android.util.Log;
import com.ly.loratm.db.DbService;
import com.ly.loratm.db.SQLiteHelper;
import com.uzmap.pkg.uzcore.UZWebView;
import com.uzmap.pkg.uzcore.uzmodule.UZModule;
import com.uzmap.pkg.uzcore.uzmodule.UZModuleContext;
import com.uzmap.pkg.uzkit.UZOpenApi;
import com.zakww.loratm.bean.ClientBean;
import com.zakww.loratm.bean.FlowBean;
import com.zakww.loratm.bean.MessageBean;
import com.zakww.loratm.bean.PackageBean;
import com.zakww.loratm.bean.SubPackageBean;
import com.zakww.loratm.util.AppUtil;
import com.zakww.loratm.util.Crc16Util;
import com.zakww.loratm.util.ErrorUtil;
import com.zakww.loratm.util.JsonUtil;
import com.zakww.loratm.util.LogUtil;
import com.zakww.loratm.util.SeqUUIDUtil;
import com.zakww.loratm.util.SerialInter;
import com.zakww.loratm.util.SerialManage;
import com.zakww.loratm.util.SerialService;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import net.lingala.zip4j.util.InternalZipConstants;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

public class SerialPortModule extends UZModule implements SerialInter {
    private static final String TAG = "SerialPortModule";
    private boolean batchSendState = false;
    private boolean connectServerState = false;
    private DbService dbService;
    private Intent intent;
    private boolean isSerialOpen = false;
    private int msgSerialNum = 0;
    private long overTime = 10000;
    private long preReceiveTime = 0;
    private long preRestartTime = 0;
    private String receiveData = "";
    private String serialAirSpeed;
    private String serialChannel;
    private SerialManage serialManage;
    private int serialNum = 0;
    private String serialPower;
    private String serialSelfCode;

    @Override // com.zakww.loratm.util.SerialInter
    public void connectMsg(String str, boolean z) {
    }

    public SerialPortModule(UZWebView uZWebView) {
        super(uZWebView);
        SerialManage instance = SerialManage.getInstance();
        this.serialManage = instance;
        instance.init(this);
        this.isSerialOpen = getOpenSerialPort();
        DbService instance2 = DbService.getInstance(new SQLiteHelper(context()));
        this.dbService = instance2;
        FlowBean lastFlow = instance2.getLastFlow();
        if (lastFlow != null) {
            this.serialNum = lastFlow.getSerialNum() + 1;
        }
        ClientBean client = this.dbService.getClient();
        if (client != null) {
            this.serialSelfCode = client.getSerialSelfCode();
            this.serialManage.setAirSpeed(client.getAirSpeed());
            MessageBean selfLastMessage = this.dbService.getSelfLastMessage(this.serialSelfCode);
            if (selfLastMessage != null) {
                this.msgSerialNum = selfLastMessage.getSerialNum().intValue() + 1;
            }
        }
        this.preReceiveTime = System.currentTimeMillis();
        this.preRestartTime = System.currentTimeMillis();
        LogUtil.v(TAG, "模块实例化成功");
    }

    private synchronized boolean getOpenSerialPort() {
        if (!this.isSerialOpen) {
            this.isSerialOpen = this.serialManage.open();
            if (this.serialManage.close()) {
                this.isSerialOpen = this.serialManage.open();
            }
        }
        if (this.intent == null) {
            this.intent = new Intent(context(), SerialService.class);
            context().startService(this.intent);
        }
        return this.isSerialOpen;
    }

    public void jsmethod_getSerialCode(UZModuleContext uZModuleContext) {
        boolean z;
        JSONObject jSONObject = new JSONObject();
        try {
            ClientBean client = this.dbService.getClient();
            if (client != null) {
                jSONObject.put("serialCode", client.getSerialSelfCode());
                z = true;
            } else {
                jSONObject.put("serialCode", "");
                z = false;
            }
            jSONObject.put("state", z);
        } catch (Exception e) {
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject2.put("error", e.getMessage());
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    public void jsmethod_init(UZModuleContext uZModuleContext) {
        boolean z;
        JSONObject jSONObject = new JSONObject();
        try {
            this.serialSelfCode = "";
            PackageBean packageBean = new PackageBean();
            packageBean.toHardware();
            this.serialManage.send(packageBean.getSendSerialData());
            long currentTimeMillis = System.currentTimeMillis();
            while (true) {
                if (System.currentTimeMillis() <= this.overTime + currentTimeMillis) {
                    if (this.serialSelfCode != null && !"".equals(this.serialSelfCode)) {
                        z = true;
                        break;
                    }
                    Thread.sleep(50);
                } else {
                    z = false;
                    break;
                }
            }
            new Thread(new initRunnable()).start();
            this.serialNum = 0;
            this.msgSerialNum = 0;
            jSONObject.put("serialCode", this.serialSelfCode);
            jSONObject.put("state", z);
        } catch (Exception e) {
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject2.put("error", e.getMessage());
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    class initRunnable implements Runnable {
        public initRunnable() {
        }

        public void run() {
            try {
                ClientBean clientBean = new ClientBean();
                SerialPortModule.this.dbService.reset();
                SerialPortModule.this.serialAirSpeed = "";
                SerialPortModule.this.serialChannel = "";
                SerialPortModule.this.serialPower = "";
                PackageBean packageBean = new PackageBean();
                packageBean.toGetSetting();
                SerialPortModule.this.serialManage.send(packageBean.getSendSerialData());
                long currentTimeMillis = System.currentTimeMillis();
                while (true) {
                    if (System.currentTimeMillis() <= SerialPortModule.this.overTime + currentTimeMillis) {
                        if (SerialPortModule.this.serialAirSpeed != null && !"".equals(SerialPortModule.this.serialAirSpeed)) {
                            clientBean.setAirSpeed(SerialPortModule.this.serialAirSpeed);
                            clientBean.setChannel(SerialPortModule.this.serialChannel);
                            clientBean.setPower(SerialPortModule.this.serialPower);
                            SerialPortModule.this.serialManage.setAirSpeed(SerialPortModule.this.serialAirSpeed);
                            break;
                        }
                        Thread.sleep(50);
                    } else {
                        break;
                    }
                }
                clientBean.setSerialSelfCode(SerialPortModule.this.serialSelfCode);
                clientBean.setId(SeqUUIDUtil.toSequenceUUID());
                SerialPortModule.this.dbService.saveClient(clientBean);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
    }

    public void jsmethod_open(UZModuleContext uZModuleContext) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("state", getOpenSerialPort());
        } catch (Exception e) {
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject2.put("error", e.getMessage());
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    public void jsmethod_close(UZModuleContext uZModuleContext) {
        JSONObject jSONObject = new JSONObject();
        try {
            boolean z = false;
            if (this.isSerialOpen) {
                boolean close = this.serialManage.close();
                this.isSerialOpen = false;
                z = close;
            }
            jSONObject.put("state", z);
        } catch (Exception e) {
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject2.put("error", e.getMessage());
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    public void jsmethod_getState(UZModuleContext uZModuleContext) {
        JSONObject jSONObject = new JSONObject();
        try {
            jSONObject.put("state", !this.isSerialOpen ? "close" : "open");
        } catch (Exception e) {
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject2.put("error", e.getMessage());
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    public void jsmethod_getSetting(UZModuleContext uZModuleContext) {
        boolean z;
        JSONObject jSONObject = new JSONObject();
        try {
            ClientBean client = this.dbService.getClient();
            if (client != null) {
                jSONObject.put("serialCode", client.getSerialSelfCode());
                jSONObject.put("airSpeed", client.getAirSpeed());
                jSONObject.put("channel", client.getChannel());
                jSONObject.put("power", client.getPower());
                z = true;
            } else {
                z = false;
            }
            jSONObject.put("state", z);
        } catch (Exception e) {
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject2.put("error", e.getMessage());
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    public void jsmethod_updateSetting(UZModuleContext uZModuleContext) {
        UZModuleContext uZModuleContext2;
        JSONObject jSONObject = new JSONObject();
        try {
            this.serialAirSpeed = "";
            this.serialChannel = "";
            this.serialPower = "";
            ClientBean client = this.dbService.getClient();
            String optString = uZModuleContext.optString("airSpeed");
            String optString2 = uZModuleContext.optString("channel");
            String optString3 = uZModuleContext.optString("power");
            PackageBean packageBean = new PackageBean();
            String str = Build.VERSION.RELEASE;
            double doubleValue = Double.valueOf(str).doubleValue();
            LogUtil.v(TAG, "判断android版本：androidVersion==" + str + ",转成double==" + doubleValue);
            if (doubleValue > 10.0d) {
                packageBean.preUpdateSetting();
                this.serialManage.send(packageBean.getSendSerialData());
                Thread.sleep(50);
                packageBean = new PackageBean();
            }
            packageBean.toUpdateSetting(optString, optString2, optString3);
            Log.v(TAG, packageBean.getSendSerialData());
            this.serialManage.send(packageBean.getSendSerialData());
            long currentTimeMillis = System.currentTimeMillis();
            while (true) {
                if (System.currentTimeMillis() <= this.overTime + currentTimeMillis) {
                    if (this.serialAirSpeed != null && !"".equals(this.serialAirSpeed)) {
                        client.setAirSpeed(this.serialAirSpeed);
                        client.setChannel(this.serialChannel);
                        client.setPower(this.serialPower);
                        this.serialManage.setAirSpeed(this.serialAirSpeed);
                        break;
                    }
                    Thread.sleep(50);
                } else {
                    break;
                }
            }
            if (client != null) {
                client.setAirSpeed(optString);
                client.setPower(optString3);
                client.setChannel(optString2);
                this.dbService.updateClient(client);
            }
            jSONObject.put("airSpeed", optString);
            jSONObject.put("channel", optString2);
            jSONObject.put("power", optString3);
            jSONObject.put("state", true);
            uZModuleContext2 = uZModuleContext;
        } catch (Exception e) {
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject2.put("error", e.getMessage());
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext2 = uZModuleContext;
            uZModuleContext2.error(jSONObject2);
        }
        uZModuleContext2.success(jSONObject);
    }

    public void jsmethod_getConnectState(UZModuleContext uZModuleContext) {
        JSONObject jSONObject = new JSONObject();
        try {
            String optString = uZModuleContext.optString("serialServerCode");
            this.receiveData = "";
            this.connectServerState = false;
            PackageBean packageBean = new PackageBean();
            packageBean.toPolling(optString, PackageBean.ActionType.ConnectReq.getCode());
            Log.v(TAG, packageBean.getSendSerialData());
            this.serialManage.send(packageBean.getSendSerialData());
            long currentTimeMillis = System.currentTimeMillis();
            while (true) {
                if (System.currentTimeMillis() > this.overTime + currentTimeMillis) {
                    break;
                } else if (this.connectServerState) {
                    break;
                } else {
                    Thread.sleep(500);
                    jSONObject.put("connecting", true);
                    uZModuleContext.success(jSONObject, false);
                }
            }
            jSONObject.put("state", true);
            jSONObject.put("connectServerState", this.connectServerState);
        } catch (Exception e) {
            JSONObject jSONObject2 = new JSONObject();
            try {
                jSONObject2.put("error", e.getMessage());
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    public void jsmethod_send(UZModuleContext uZModuleContext) {
        JSONObject jSONObject = new JSONObject();
        JSONObject jSONObject2 = new JSONObject();
        try {
            uZModuleContext.optString("serialServerCode");
            String optString = uZModuleContext.optString("api");
            String optString2 = uZModuleContext.optString("params");
            HashMap hashMap = new HashMap();
            hashMap.put("a", optString);
            hashMap.put("p", optString2);
            List<String> subContents = subContents(new JSONObject(hashMap).toString());
            FlowBean flowBean = new FlowBean();
            flowBean.setId(SeqUUIDUtil.toSequenceUUID());
            flowBean.setSerialNum(getSerialNum());
            flowBean.setPackageCount(subContents.size());
            flowBean.setSendCount(0);
            flowBean.setSendState("n");
            flowBean.setApi(optString);
            flowBean.setParam(optString2);
            flowBean.setReceiveState("n");
            flowBean.setCreateTime(AppUtil.getCurrDateStr());
            flowBean.setLastUpdateTime(flowBean.getCreateTime());
            this.dbService.saveFlow(flowBean);
            int i = 1;
            for (String str : subContents) {
                SubPackageBean subPackageBean = new SubPackageBean();
                subPackageBean.setId(SeqUUIDUtil.toSequenceUUID());
                subPackageBean.setFlowId(flowBean.getId());
                subPackageBean.setContent(str);
                subPackageBean.setSendState("n");
                subPackageBean.setSeq(i);
                this.dbService.saveSubPackage(subPackageBean);
                i++;
            }
            jSONObject.put("flowId", flowBean.getId());
        } catch (Exception e) {
            try {
                jSONObject2.put("error", "请求发生异常，请联系系统管理员");
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    private synchronized int getSerialNum() {
        int i;
        i = this.serialNum;
        this.serialNum++;
        return i;
    }

    public void jsmethod_updateFlowReceived(UZModuleContext uZModuleContext) {
        boolean z;
        JSONObject jSONObject = new JSONObject();
        JSONObject jSONObject2 = new JSONObject();
        try {
            FlowBean flow = this.dbService.getFlow(uZModuleContext.optString("flowId"));
            if (flow != null) {
                flow.setLastUpdateTime(AppUtil.getCurrDateStr());
                flow.setReceiveState("y");
                z = this.dbService.updateFlow(flow);
            } else {
                z = false;
            }
            jSONObject.put("state", z);
        } catch (Exception e) {
            try {
                jSONObject2.put("error", "请求发生异常，请联系系统管理员");
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    public void jsmethod_getRes(UZModuleContext uZModuleContext) {
        String str;
        boolean z;
        String str2;
        JSONObject jSONObject = new JSONObject();
        JSONObject jSONObject2 = new JSONObject();
        try {
            FlowBean flow = this.dbService.getFlow(uZModuleContext.optString("flowId"));
            if (flow != null) {
                z = true;
                str = flow.getResult();
                str2 = flow.getReceiveState();
            } else {
                str2 = "";
                str = str2;
                z = false;
            }
            jSONObject.put("state", z);
            jSONObject.put("receiveState", str2);
            jSONObject.put("res", str);
        } catch (Exception e) {
            try {
                jSONObject2.put("error", "请求发生异常，请联系系统管理员");
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    private List<String> subContents(String str) {
        ArrayList arrayList = new ArrayList();
        StringBuffer stringBuffer = new StringBuffer();
        int i = 0;
        while (i < str.length()) {
            int i2 = i + 1;
            stringBuffer.append(str.substring(i, i2));
            if (stringBuffer.length() > 440) {
                arrayList.add(stringBuffer.toString());
                stringBuffer = new StringBuffer();
            }
            i = i2;
        }
        arrayList.add(stringBuffer.toString());
        return arrayList;
    }

    @Override // com.zakww.loratm.util.SerialInter
    public void readData(String str, byte[] bArr, int i) {
        try {
            this.receiveData = Crc16Util.bytesToHexString(bArr);
            LogUtil.v(TAG, "读取到的串口数据：" + this.receiveData);
            this.preReceiveTime = System.currentTimeMillis();
            PackageBean packageBean = new PackageBean();
            packageBean.fromSerialData(this.receiveData);
            if (packageBean.isErrorState()) {
                return;
            }
            if (!"09".equals(packageBean.getCommand())) {
                if (!"44".equals(packageBean.getCommand())) {
                    if (!"43".equals(packageBean.getCommand())) {
                        if ("41".equals(packageBean.getCommand())) {
                            this.serialSelfCode = packageBean.getSelfCode();
                            return;
                        }
                        return;
                    }
                }
                this.serialAirSpeed = packageBean.getAirSpeed();
                this.serialChannel = packageBean.getChannel();
                this.serialPower = packageBean.getPower();
            } else if (packageBean.getActionType() != null && !"".equals(packageBean.getActionType())) {
                if (PackageBean.ActionType.Polling.getCode().equals(packageBean.getActionType())) {
                    handlePolling(packageBean);
                } else if (PackageBean.ActionType.ReqRes.getCode().equals(packageBean.getActionType())) {
                    flowReqRes(packageBean);
                } else if (PackageBean.ActionType.ConnectRes.getCode().equals(packageBean.getActionType())) {
                    this.connectServerState = true;
                } else if (PackageBean.ActionType.BatchSend.getCode().equals(packageBean.getActionType())) {
                    receiveBatchSend(packageBean);
                } else if (PackageBean.ActionType.BatchSendRes.getCode().equals(packageBean.getActionType())) {
                    batchSendRes(packageBean);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void flowReqRes(PackageBean packageBean) throws JSONException {
        FlowBean flowBySerialNum;
        if (packageBean.getSerialNum() != null && !"".equals(packageBean.getSerialNum()) && (flowBySerialNum = this.dbService.getFlowBySerialNum(Integer.parseInt(packageBean.getSerialNum(), 16))) != null) {
            String hexStr2Str = Crc16Util.hexStr2Str(packageBean.getContent());
            flowBySerialNum.setLastUpdateTime(AppUtil.getCurrDateStr());
            flowBySerialNum.setReceiveState("y");
            flowBySerialNum.setResult(hexStr2Str);
            this.dbService.updateFlow(flowBySerialNum);
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("flowId", flowBySerialNum.getId());
            sendEventToHtml5("onLoraSendSuccess", jSONObject);
        }
    }

    private synchronized void receiveBatchSend(PackageBean packageBean) throws JSONException {
        Map<String, Object> jsonToMap = JsonUtil.jsonToMap(Crc16Util.hexStr2Str(packageBean.getContent()));
        String obj = jsonToMap.get("s").toString();
        if (!this.serialSelfCode.equals(obj)) {
            Log.v(TAG, "fromCode：" + obj + ",serialNum:" + Integer.parseInt(packageBean.getSerialNum(), 16));
            MessageBean messageByFromCodeAndSerialNum = this.dbService.getMessageByFromCodeAndSerialNum(obj, Integer.parseInt(packageBean.getSerialNum(), 16));
            if (messageByFromCodeAndSerialNum == null) {
                MessageBean messageBean = new MessageBean();
                messageBean.setId(SeqUUIDUtil.toSequenceUUID());
                messageBean.setSerialNum(Integer.valueOf(Integer.parseInt(packageBean.getSerialNum(), 16)));
                messageBean.setContent(jsonToMap.get("t").toString());
                messageBean.setFromClient(jsonToMap.get("c").toString());
                messageBean.setFromCode(jsonToMap.get("s").toString());
                messageBean.setCreateTime(AppUtil.getCurrDateStr());
                messageBean.setType(this.serialSelfCode.equals(obj) ? "s" : InternalZipConstants.READ_MODE);
                this.dbService.saveMessage(messageBean);
                Context context = context();
                context();
                PowerManager powerManager = (PowerManager) context.getSystemService("power");
                if (powerManager != null && !powerManager.isScreenOn()) {
                    powerManager.newWakeLock(268435462, "My Tag").acquire(3000);
                }
                JSONObject jSONObject = new JSONObject();
                jSONObject.put("id", messageBean.getId());
                jSONObject.put("content", messageBean.getContent());
                jSONObject.put("fromClient", messageBean.getFromClient());
                jSONObject.put("fromCode", messageBean.getFromCode());
                jSONObject.put("createTime", messageBean.getCreateTime());
                jSONObject.put("type", messageBean.getType());
                sendEventToHtml5("onLoraBatchSendMessage", jSONObject);
            } else {
                Log.v(TAG, "message.fromCode：" + messageByFromCodeAndSerialNum.getFromCode() + ",messageSerialNum:" + Integer.parseInt(packageBean.getSerialNum(), 16));
            }
        }
    }

    private void batchSendRes(PackageBean packageBean) throws JSONException {
        MessageBean messageByFromCodeAndSerialNum;
        if (packageBean.getSerialNum() != null && !"".equals(packageBean.getSerialNum()) && (messageByFromCodeAndSerialNum = this.dbService.getMessageByFromCodeAndSerialNum(this.serialSelfCode, Integer.parseInt(packageBean.getSerialNum(), 16))) != null) {
            this.dbService.updateMessageSendState(messageByFromCodeAndSerialNum.getId(), MessageBean.SendState.Yes.getCode());
            JSONObject jSONObject = new JSONObject();
            jSONObject.put("messageId", messageByFromCodeAndSerialNum.getId());
            sendEventToHtml5("onLoraBatchSendSuccess", jSONObject);
        }
    }

    private void sendEvent(String str, JSONObject jSONObject) {
        JSONObject jSONObject2 = new JSONObject();
        try {
            jSONObject2.put("type", str);
            jSONObject2.put(UZOpenApi.DATA, jSONObject);
            sendEventToHtml5("onLoraMessage", jSONObject2);
        } catch (JSONException e) {
            throw new RuntimeException(e);
        }
    }

    private void handlePolling(PackageBean packageBean) {
        PackageBean packageBean2 = new PackageBean();
        List<MessageBean> unSendMessages = this.dbService.getUnSendMessages();
        List<FlowBean> unReceiveFlows = this.dbService.getUnReceiveFlows();
        int size = (unSendMessages == null || unSendMessages.size() <= 0) ? 0 : unSendMessages.size() + 0;
        if (unReceiveFlows != null && unReceiveFlows.size() > 0) {
            size += unReceiveFlows.size();
        }
        packageBean2.resPollingCall(packageBean.getFromCode(), PackageBean.ActionType.ResPolling.getCode(), size);
        this.serialManage.send(packageBean2.getSendSerialData());
        if (unSendMessages != null && unSendMessages.size() > 0) {
            for (MessageBean messageBean : unSendMessages) {
                HashMap hashMap = new HashMap();
                hashMap.put("c", messageBean.getFromClient());
                hashMap.put("t", messageBean.getContent());
                hashMap.put("s", messageBean.getFromCode());
                PackageBean packageBean3 = new PackageBean();
                packageBean3.toDataTransmission(packageBean.getFromCode(), Crc16Util.int2HexString(messageBean.getSerialNum().intValue(), 2), 1, 1, new JSONObject(hashMap).toString(), PackageBean.ActionType.BatchSend.getCode());
                this.serialManage.send(packageBean3.getSendSerialData());
            }
        }
        if (unReceiveFlows != null && unReceiveFlows.size() > 0) {
            for (FlowBean flowBean : unReceiveFlows) {
                List<SubPackageBean> subPackagesByFlowId = this.dbService.getSubPackagesByFlowId(flowBean.getId());
                for (int i = 0; i < subPackagesByFlowId.size(); i++) {
                    PackageBean packageBean4 = new PackageBean();
                    packageBean4.toDataTransmission(packageBean.getFromCode(), Crc16Util.int2HexString(flowBean.getSerialNum(), 2), subPackagesByFlowId.size(), subPackagesByFlowId.get(i).getSeq(), subPackagesByFlowId.get(i).getContent(), PackageBean.ActionType.Req.getCode());
                    this.serialManage.send(packageBean4.getSendSerialData());
                }
            }
        }
    }

    @Override // com.zakww.loratm.util.SerialInter
    public void checkPort(String str) {
        if (this.preReceiveTime > 0) {
            long currentTimeMillis = System.currentTimeMillis();
            if (currentTimeMillis - this.preReceiveTime > 300000 && currentTimeMillis - this.preRestartTime > 300000) {
                LogUtil.v(TAG, "超时没有接收到数据，即将进入重启。。。");
                JSONObject jSONObject = new JSONObject();
                try {
                    Intent intent2 = new Intent("android.intent.action.comm_module_ctrl");
                    intent2.putExtra("state", "stop");
                    context().sendBroadcast(intent2);
                    Thread.sleep(3000);
                    Intent intent3 = new Intent("android.intent.action.comm_module_ctrl");
                    intent3.putExtra("state", "start");
                    context().sendBroadcast(intent3);
                    Thread.sleep(3000);
                    boolean open = this.serialManage.open();
                    this.isSerialOpen = open;
                    if (!open) {
                        jSONObject.put("type", 0);
                        jSONObject.put(UZOpenApi.DATA, "超时没有接收到数据，请重启设备重试。");
                        sendEventToHtml5("onLoraMessage", jSONObject);
                        return;
                    }
                    LogUtil.v(TAG, "超时没有接收到数据，重启成功。。。");
                    this.preRestartTime = System.currentTimeMillis();
                } catch (Exception e) {
                    throw new RuntimeException(e);
                }
            }
        }
    }

    public void jsmethod_batchSend(UZModuleContext uZModuleContext) {
        JSONObject jSONObject = new JSONObject();
        JSONObject jSONObject2 = new JSONObject();
        this.batchSendState = false;
        try {
            String optString = uZModuleContext.optString("clientName");
            String optString2 = uZModuleContext.optString("content");
            MessageBean messageBean = new MessageBean();
            messageBean.setId(SeqUUIDUtil.toSequenceUUID());
            messageBean.setContent(optString2);
            messageBean.setFromClient(optString);
            messageBean.setCreateTime(AppUtil.getCurrDateStr());
            messageBean.setFromCode(this.serialSelfCode);
            messageBean.setType(MessageBean.Type.Send.getCode());
            messageBean.setSendState(MessageBean.SendState.No.getCode());
            messageBean.setSerialNum(Integer.valueOf(this.msgSerialNum));
            this.msgSerialNum++;
            this.dbService.saveMessage(messageBean);
            jSONObject.put("messageId", messageBean.getId());
        } catch (Exception e) {
            try {
                jSONObject2.put("error", "请求发生异常，请联系系统管理员");
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }

    public void jsmethod_batchGetMessage(UZModuleContext uZModuleContext) {
        JSONObject jSONObject = new JSONObject();
        JSONObject jSONObject2 = new JSONObject();
        try {
            List<MessageBean> messageList = this.dbService.getMessageList(uZModuleContext.optString("preId"));
            JSONArray jSONArray = new JSONArray();
            if (messageList != null || messageList.size() > 0) {
                for (MessageBean messageBean : messageList) {
                    JSONObject jSONObject3 = new JSONObject();
                    jSONObject3.put("id", messageBean.getId());
                    jSONObject3.put("fromCode", messageBean.getFromCode());
                    jSONObject3.put("fromClient", messageBean.getFromClient());
                    jSONObject3.put("content", messageBean.getContent());
                    jSONObject3.put("createTime", messageBean.getCreateTime());
                    jSONObject3.put("type", messageBean.getType());
                    jSONObject3.put("sendState", messageBean.getSendState());
                    jSONObject3.put("serialNum", messageBean.getSerialNum());
                    jSONArray.put(jSONObject3);
                }
            }
            jSONObject.put("list", jSONArray);
        } catch (Exception e) {
            try {
                jSONObject2.put("error", "请求发生异常，请联系系统管理员");
                jSONObject2.put("errorTrace", ErrorUtil.getExceptionStack(e));
            } catch (JSONException e2) {
                e2.printStackTrace();
            }
            uZModuleContext.error(jSONObject2);
        }
        uZModuleContext.success(jSONObject);
    }
}
