package com.zakww.loratm.util;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

public final class SeqUUIDUtil {
    private static char DEFAULT_PREFIX_CHAR = 'o';

    public static String toSequenceUUID(long j) {
        return toSequenceUUID(DEFAULT_PREFIX_CHAR, j);
    }

    public static String toSequenceUUID(long j, long j2) {
        return toSequenceUUID(DEFAULT_PREFIX_CHAR, System.currentTimeMillis(), j, j2);
    }

    public static String toSequenceUUID(long j, long j2, long j3) {
        return toSequenceUUID(DEFAULT_PREFIX_CHAR, j, j2, j3);
    }

    public static String toSequenceUUID(char c, long j) {
        UUID randomUUID = UUID.randomUUID();
        return toSequenceUUID(c, j, randomUUID.getMostSignificantBits(), randomUUID.getLeastSignificantBits());
    }

    public static String toSequenceUUID(char c, long j, long j2, long j3) {
        if (c <= 127) {
            StringBuilder sb = new StringBuilder(32);
            sb.append(c);
            sb.append(BaseConvert.compressNumber(j, 5));
            String compressNumber = BaseConvert.compressNumber(j2, 6);
            sb.append(compressNumber);
            if (compressNumber.length() < 11) {
                sb.append("_");
            }
            sb.append(BaseConvert.compressNumber(j3, 6));
            int length = 32 - sb.length();
            if (length > 0) {
                sb.append((CharSequence) "________________________________", 0, length);
            }
            return sb.toString();
        }
        throw new IllegalArgumentException("prefix必须是一个字节(byte)的字符");
    }

    public static String toSequenceUUID() {
        return toSequenceUUID(System.currentTimeMillis());
    }

    public static List<String> toSequenceUUIDs(int i) {
        long currentTimeMillis = System.currentTimeMillis();
        ArrayList arrayList = new ArrayList(i);
        for (int i2 = 0; i2 < i; i2++) {
            arrayList.add(toSequenceUUID(currentTimeMillis));
            currentTimeMillis += 50;
        }
        return arrayList;
    }

    public static long extractTimestamp(String str) {
        return BaseConvert.decompressNumber(str.substring(1, 10), 5);
    }

    public static long extractMostSignificantBits(String str) {
        int indexOf = str.indexOf(95, 10);
        if (indexOf < 10) {
            indexOf = 21;
        }
        return BaseConvert.decompressNumber(str.substring(10, indexOf), 6);
    }

    public static long extractLeastSignificantBits(String str) {
        int indexOf = str.indexOf(95, 10) + 1;
        if (indexOf < 10) {
            indexOf = 21;
        }
        int indexOf2 = str.indexOf(95, indexOf);
        if (indexOf2 < 21) {
            indexOf2 = 32;
        }
        return BaseConvert.decompressNumber(str.substring(indexOf, indexOf2), 6);
    }

    public static class BaseConvert {
        static final char[] digits = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '-', '.'};

        private static long getCharIndexNum(char c) {
            int i;
            if (c >= '0' && c <= '9') {
                i = c - '0';
            } else if (c >= 'a' && c <= 'z') {
                i = c - 'W';
            } else if (c >= 'A' && c <= 'Z') {
                i = c - 29;
            } else if (c == '+') {
                return 62;
            } else {
                return c == '/' ? 63 : 0;
            }
            return (long) i;
        }

        public static String compressNumber(long j, int i) {
            char[] cArr = new char[64];
            long j2 = (long) ((1 << i) - 1);
            int i2 = 64;
            do {
                i2--;
                cArr[i2] = digits[(int) (j & j2)];
                j >>>= i;
            } while (j != 0);
            return new String(cArr, i2, 64 - i2);
        }

        public static long decompressNumber(String str, int i) {
            long j = 0;
            for (int length = str.length() - 1; length >= 0; length--) {
                if (length == str.length() - 1) {
                    j += getCharIndexNum(str.charAt(length));
                } else {
                    for (int i2 = 0; i2 < digits.length; i2++) {
                        if (str.charAt(length) == digits[i2]) {
                            j += ((long) i2) << (((str.length() - 1) - length) * i);
                        }
                    }
                }
            }
            return j;
        }
    }

    public static void main(String[] strArr) {
        for (int i = 0; i < 20; i++) {
            try {
                Thread.sleep(100);
            } catch (InterruptedException unused) {
            }
            System.out.println(toSequenceUUID());
        }
    }
}
