package com.zakww.loratm.util;

import android.os.Build;
import com.zakww.loratm.bean.ClientBean;
import java.util.Queue;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.TimeUnit;

public class SerialManage {
    private static final String TAG = "serialManage";
    private static SerialManage instance;
    private static SerialHandle serialHandle;
    private int airSpeed = 240;
    private String airSpeedCode = "02";
    private boolean isConnect = false;
    private boolean isSendTaskRunning = false;
    private long nextCanSendTime = 0;
    private Queue<String> queueMsg = new ConcurrentLinkedQueue();
    private ScheduledExecutorService scheduledExecutor = Executors.newScheduledThreadPool(8);
    private ScheduledFuture sendStrTask;

    private SerialManage() {
    }

    public static SerialManage getInstance() {
        if (instance == null) {
            synchronized (SerialManage.class) {
                if (instance == null) {
                    instance = new SerialManage();
                }
            }
        }
        return instance;
    }

    public void setAirSpeed(String str) {
        this.airSpeedCode = str;
        this.airSpeed = getAirSpeedByCode(str);
    }

    public ScheduledExecutorService getScheduledExecutor() {
        return this.scheduledExecutor;
    }

    public void init(SerialInter serialInter) {
        if (serialHandle == null) {
            serialHandle = new SerialHandle();
        }
        serialHandle.addSerialInter(serialInter);
    }

    public boolean isSerialOpen() {
        SerialHandle serialHandle2 = serialHandle;
        if (serialHandle2 == null) {
            return false;
        }
        return serialHandle2.isOpen();
    }

    public boolean open() {
        String str = Build.VERSION.RELEASE;
        double doubleValue = Double.valueOf(str).doubleValue();
        LogUtil.v(TAG, "判断android版本：androidVersion==" + str + ",转成double==" + doubleValue);
        if (doubleValue > 10.0d) {
            this.isConnect = serialHandle.open("/dev/ttyS4", 115200, true);
        } else {
            this.isConnect = serialHandle.open("/dev/ttyS1", 115200, true);
        }
        LogUtil.v(TAG, "打开串口结果：" + this.isConnect);
        return this.isConnect;
    }

    public synchronized void send(String str) {
        if (!this.isConnect) {
            LogUtil.v(TAG, AppUtil.getCurrDateStr() + "发送线程判断串口isConnect为false");
        } else if (serialHandle == null) {
            LogUtil.v(TAG, AppUtil.getCurrDateStr() + "发送线程判断串口serialHandle为null");
        } else if (str != null && !"".equals(str)) {
            try {
                long currentTimeMillis = System.currentTimeMillis();
                if (currentTimeMillis < this.nextCanSendTime) {
                    Thread.sleep(this.nextCanSendTime - currentTimeMillis);
                }
                serialHandle.send(str);
                double length = (double) (str.length() / 2);
                Double.isNaN(length);
                double d = (double) this.airSpeed;
                Double.isNaN(d);
                Double.isNaN(length);
                long round = (long) (((int) Math.round((((length * 1.0d) / d) * 1.0d * 1000.0d) + (length * 0.087d * 2.0d) + 30.0d)) + 100);
                if (round < 300) {
                    round = 300;
                }
                this.nextCanSendTime = System.currentTimeMillis() + round;
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            }
        }
    }

    private int getAirSpeedByCode(String str) {
        if (ClientBean.AirSpeed.Two.getCode().equals(str)) {
            return ClientBean.AirSpeed.Two.getText();
        }
        if (ClientBean.AirSpeed.Three.getCode().equals(str)) {
            return ClientBean.AirSpeed.Three.getText();
        }
        if (ClientBean.AirSpeed.Four.getCode().equals(str)) {
            return ClientBean.AirSpeed.Four.getText();
        }
        if (ClientBean.AirSpeed.Five.getCode().equals(str)) {
            return ClientBean.AirSpeed.Five.getText();
        }
        if (ClientBean.AirSpeed.Six.getCode().equals(str)) {
            return ClientBean.AirSpeed.Six.getText();
        }
        if (ClientBean.AirSpeed.Seven.getCode().equals(str)) {
            return ClientBean.AirSpeed.Seven.getText();
        }
        return 240;
    }

    public boolean close() {
        return serialHandle.close();
    }

    private void startSendTask() {
        cancelSendTask();
        this.sendStrTask = this.scheduledExecutor.scheduleAtFixedRate(new Runnable() {
            /* class com.zakww.loratm.util.SerialManage.AnonymousClass1 */

            public void run() {
                SerialManage.this.isSendTaskRunning = true;
                if (!SerialManage.this.isConnect) {
                    LogUtil.v(SerialManage.TAG, AppUtil.getCurrDateStr() + "发送线程判断串口isConnect为false");
                } else if (SerialManage.serialHandle == null) {
                    LogUtil.v(SerialManage.TAG, AppUtil.getCurrDateStr() + "发送线程判断串口serialHandle为null");
                } else {
                    String str = (String) SerialManage.this.queueMsg.poll();
                    if (str != null && !"".equals(str)) {
                        SerialManage.serialHandle.send(str);
                    }
                }
            }
        }, 0, 100, TimeUnit.MILLISECONDS);
    }

    private void cancelSendTask() {
        ScheduledFuture scheduledFuture = this.sendStrTask;
        if (scheduledFuture != null) {
            scheduledFuture.cancel(true);
            try {
                Thread.sleep(100);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            this.sendStrTask = null;
        }
    }

    public void readFromPort() {
        SerialHandle serialHandle2 = serialHandle;
        if (serialHandle2 != null) {
            serialHandle2.readFromPortWithLoop();
        }
    }

    public void checkSendTask() {
        if (this.sendStrTask != null) {
            this.isSendTaskRunning = false;
            try {
                Thread.sleep(200);
                if (!this.isSendTaskRunning) {
                    startSendTask();
                }
                LogUtil.v(TAG, AppUtil.getCurrDateStr() + "发送线程仍在执行中");
            } catch (InterruptedException e) {
                throw new RuntimeException(e);
            }
        } else {
            startSendTask();
        }
    }
}
