package net.lingala.zip4j.unzip;

import java.io.File;
import java.util.ArrayList;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.io.ZipInputStream;
import net.lingala.zip4j.model.CentralDirectory;
import net.lingala.zip4j.model.FileHeader;
import net.lingala.zip4j.model.UnzipParameters;
import net.lingala.zip4j.model.ZipModel;
import net.lingala.zip4j.progress.ProgressMonitor;
import net.lingala.zip4j.util.InternalZipConstants;
import net.lingala.zip4j.util.Zip4jUtil;

public class Unzip {
    private ZipModel zipModel;

    public Unzip(ZipModel zipModel2) throws ZipException {
        if (zipModel2 != null) {
            this.zipModel = zipModel2;
            return;
        }
        throw new ZipException("ZipModel is null");
    }

    public void extractAll(final UnzipParameters unzipParameters, final String str, final ProgressMonitor progressMonitor, boolean z) throws ZipException {
        CentralDirectory centralDirectory = this.zipModel.getCentralDirectory();
        if (centralDirectory == null || centralDirectory.getFileHeaders() == null) {
            throw new ZipException("invalid central directory in zipModel");
        }
        final ArrayList fileHeaders = centralDirectory.getFileHeaders();
        progressMonitor.setCurrentOperation(1);
        progressMonitor.setTotalWork(calculateTotalWork(fileHeaders));
        progressMonitor.setState(1);
        if (z) {
            new Thread(InternalZipConstants.THREAD_NAME) {
                /* class net.lingala.zip4j.unzip.Unzip.AnonymousClass1 */

                public void run() {
                    try {
                        Unzip.this.initExtractAll(fileHeaders, unzipParameters, progressMonitor, str);
                        progressMonitor.endProgressMonitorSuccess();
                    } catch (ZipException unused) {
                    }
                }
            }.start();
        } else {
            initExtractAll(fileHeaders, unzipParameters, progressMonitor, str);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void initExtractAll(ArrayList arrayList, UnzipParameters unzipParameters, ProgressMonitor progressMonitor, String str) throws ZipException {
        for (int i = 0; i < arrayList.size(); i++) {
            initExtractFile((FileHeader) arrayList.get(i), str, unzipParameters, null, progressMonitor);
            if (progressMonitor.isCancelAllTasks()) {
                progressMonitor.setResult(3);
                progressMonitor.setState(0);
                return;
            }
        }
    }

    public void extractFile(final FileHeader fileHeader, final String str, final UnzipParameters unzipParameters, final String str2, final ProgressMonitor progressMonitor, boolean z) throws ZipException {
        if (fileHeader != null) {
            progressMonitor.setCurrentOperation(1);
            progressMonitor.setTotalWork(fileHeader.getCompressedSize());
            progressMonitor.setState(1);
            progressMonitor.setPercentDone(0);
            progressMonitor.setFileName(fileHeader.getFileName());
            if (z) {
                new Thread(InternalZipConstants.THREAD_NAME) {
                    /* class net.lingala.zip4j.unzip.Unzip.AnonymousClass2 */

                    public void run() {
                        try {
                            Unzip.this.initExtractFile(fileHeader, str, unzipParameters, str2, progressMonitor);
                            progressMonitor.endProgressMonitorSuccess();
                        } catch (ZipException unused) {
                        }
                    }
                }.start();
                return;
            }
            initExtractFile(fileHeader, str, unzipParameters, str2, progressMonitor);
            progressMonitor.endProgressMonitorSuccess();
            return;
        }
        throw new ZipException("fileHeader is null");
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0051, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x0052, code lost:
        r7.endProgressMonitorError(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x005a, code lost:
        throw new net.lingala.zip4j.exception.ZipException(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:23:0x0073, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0074, code lost:
        r7.endProgressMonitorError(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x007c, code lost:
        throw new net.lingala.zip4j.exception.ZipException(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:26:0x007d, code lost:
        r3 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x007e, code lost:
        r7.endProgressMonitorError(r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0081, code lost:
        throw r3;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x007d A[ExcHandler: ZipException (r3v2 'e' net.lingala.zip4j.exception.ZipException A[CUSTOM_DECLARE]), Splitter:B:1:0x0002] */
    private void initExtractFile(FileHeader fileHeader, String str, UnzipParameters unzipParameters, String str2, ProgressMonitor progressMonitor) throws ZipException {
        if (fileHeader != null) {
            try {
                progressMonitor.setFileName(fileHeader.getFileName());
                if (!str.endsWith(InternalZipConstants.FILE_SEPARATOR)) {
                    str = str + InternalZipConstants.FILE_SEPARATOR;
                }
                if (fileHeader.isDirectory()) {
                    String fileName = fileHeader.getFileName();
                    if (Zip4jUtil.isStringNotNullAndNotEmpty(fileName)) {
                        File file = new File(str + fileName);
                        if (!file.exists()) {
                            file.mkdirs();
                            return;
                        }
                        return;
                    }
                    return;
                }
                checkOutputDirectoryStructure(fileHeader, str, str2);
                new UnzipEngine(this.zipModel, fileHeader).unzipFile(progressMonitor, str, str2, unzipParameters);
            } catch (Exception e) {
                progressMonitor.endProgressMonitorError(e);
                throw new ZipException(e);
            } catch (ZipException e2) {
            }
        } else {
            throw new ZipException("fileHeader is null");
        }
    }

    public ZipInputStream getInputStream(FileHeader fileHeader) throws ZipException {
        return new UnzipEngine(this.zipModel, fileHeader).getInputStream();
    }

    private void checkOutputDirectoryStructure(FileHeader fileHeader, String str, String str2) throws ZipException {
        if (fileHeader == null || !Zip4jUtil.isStringNotNullAndNotEmpty(str)) {
            throw new ZipException("Cannot check output directory structure...one of the parameters was null");
        }
        String fileName = fileHeader.getFileName();
        if (!Zip4jUtil.isStringNotNullAndNotEmpty(str2)) {
            str2 = fileName;
        }
        if (Zip4jUtil.isStringNotNullAndNotEmpty(str2)) {
            try {
                File file = new File(new File(str + str2).getParent());
                if (!file.exists()) {
                    file.mkdirs();
                }
            } catch (Exception e) {
                throw new ZipException(e);
            }
        }
    }

    private long calculateTotalWork(ArrayList arrayList) throws ZipException {
        long j;
        if (arrayList != null) {
            long j2 = 0;
            for (int i = 0; i < arrayList.size(); i++) {
                FileHeader fileHeader = (FileHeader) arrayList.get(i);
                if (fileHeader.getZip64ExtendedInfo() == null || fileHeader.getZip64ExtendedInfo().getUnCompressedSize() <= 0) {
                    j = fileHeader.getCompressedSize();
                } else {
                    j = fileHeader.getZip64ExtendedInfo().getCompressedSize();
                }
                j2 += j;
            }
            return j2;
        }
        throw new ZipException("fileHeaders is null, cannot calculate total work");
    }
}
