package org.simple.eventbus;

import android.util.Log;
import java.lang.reflect.Method;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.Map;
import java.util.concurrent.CopyOnWriteArrayList;

public class SubsciberMethodHunter {
    Map<EventType, CopyOnWriteArrayList<Subscription>> mSubcriberMap;

    public SubsciberMethodHunter(Map<EventType, CopyOnWriteArrayList<Subscription>> map) {
        this.mSubcriberMap = map;
    }

    public void findSubcribeMethods(Object obj) {
        Class<?>[] parameterTypes;
        if (this.mSubcriberMap != null) {
            Class<?> cls = obj.getClass();
            while (cls != null && !isSystemCalss(cls.getName())) {
                Method[] declaredMethods = cls.getDeclaredMethods();
                for (Method method : declaredMethods) {
                    Subscriber subscriber = (Subscriber) method.getAnnotation(Subscriber.class);
                    if (!(subscriber == null || (parameterTypes = method.getParameterTypes()) == null || parameterTypes.length != 1)) {
                        Class<?> convertType = convertType(parameterTypes[0]);
                        subscibe(new EventType(convertType, subscriber.tag()), new TargetMethod(method, convertType, subscriber.mode()), obj);
                    }
                }
                cls = cls.getSuperclass();
            }
            return;
        }
        throw new NullPointerException("the mSubcriberMap is null. ");
    }

    private void subscibe(EventType eventType, TargetMethod targetMethod, Object obj) {
        CopyOnWriteArrayList<Subscription> copyOnWriteArrayList = this.mSubcriberMap.get(eventType);
        if (copyOnWriteArrayList == null) {
            copyOnWriteArrayList = new CopyOnWriteArrayList<>();
        }
        Subscription subscription = new Subscription(obj, targetMethod);
        if (!copyOnWriteArrayList.contains(subscription)) {
            copyOnWriteArrayList.add(subscription);
            this.mSubcriberMap.put(eventType, copyOnWriteArrayList);
        }
    }

    public void removeMethodsFromMap(Object obj) {
        Iterator<CopyOnWriteArrayList<Subscription>> it = this.mSubcriberMap.values().iterator();
        while (it.hasNext()) {
            CopyOnWriteArrayList<Subscription> next = it.next();
            if (next != null) {
                LinkedList linkedList = new LinkedList();
                Iterator<Subscription> it2 = next.iterator();
                while (it2.hasNext()) {
                    Subscription next2 = it2.next();
                    if (next2.subscriber.equals(obj)) {
                        Log.d("", "### 移除订阅 " + obj.getClass().getName());
                        linkedList.add(next2);
                    }
                }
                next.removeAll(linkedList);
            }
            if (next == null || next.size() == 0) {
                it.remove();
            }
        }
    }

    private Class<?> convertType(Class<?> cls) {
        if (cls.equals(Boolean.TYPE)) {
            return Boolean.class;
        }
        if (cls.equals(Integer.TYPE)) {
            return Integer.class;
        }
        if (cls.equals(Float.TYPE)) {
            return Float.class;
        }
        return cls.equals(Double.TYPE) ? Double.class : cls;
    }

    private boolean isSystemCalss(String str) {
        return str.startsWith("java.") || str.startsWith("javax.") || str.startsWith("android.");
    }
}
