package com.eclipsesource.v8.debug;

import com.eclipsesource.v8.JavaVoidCallback;
import com.eclipsesource.v8.Releasable;
import com.eclipsesource.v8.V8;
import com.eclipsesource.v8.V8Array;
import com.eclipsesource.v8.V8Function;
import com.eclipsesource.v8.V8Object;
import com.eclipsesource.v8.V8Value;
import java.util.ArrayList;
import java.util.List;

public class DebugHandler implements Releasable {
    private static final String CHANGE_BREAK_POINT_CONDITION = "changeBreakPointCondition";
    private static final String CLEAR_BREAK_POINT = "clearBreakPoint";
    private static final String DEBUG_BREAK_HANDLER = "__j2v8_debug_handler";
    public static String DEBUG_OBJECT_NAME = "__j2v8_Debug";
    private static final String DISABLE_ALL_BREAK_POINTS = "disableAllBreakPoints";
    private static final String DISABLE_SCRIPT_BREAK_POINT = "disableScriptBreakPoint";
    private static final String ENABLE_SCRIPT_BREAK_POINT = "enableScriptBreakPoint";
    private static final String FIND_SCRIPT_BREAK_POINT = "findScriptBreakPoint";
    private static final String NUMBER = "number";
    private static final String SCRIPT_BREAK_POINTS = "scriptBreakPoints";
    private static final String SET_BREAK_POINT = "setBreakPoint";
    private static final String SET_LISTENER = "setListener";
    private static final String SET_SCRIPT_BREAK_POINT_BY_NAME = "setScriptBreakPointByName";
    private static final String V8_DEBUG_OBJECT = "Debug";
    private List<BreakHandler> breakHandlers = new ArrayList();
    private V8Object debugObject;
    private V8 runtime;

    /* access modifiers changed from: private */
    public class BreakpointHandler implements JavaVoidCallback {
        private static /* synthetic */ int[] $SWITCH_TABLE$com$eclipsesource$v8$debug$DebugHandler$DebugEvent;

        /* JADX WARNING: Can't wrap try/catch for region: R(21:3|4|5|6|7|8|9|10|11|12|13|14|15|16|17|18|19|20|21|22|24) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:10:0x0028 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:12:0x0031 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:14:0x003a */
        /* JADX WARNING: Missing exception handler attribute for start block: B:16:0x0043 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:18:0x004c */
        /* JADX WARNING: Missing exception handler attribute for start block: B:20:0x0056 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:6:0x0015 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:8:0x001f */
        static /* synthetic */ int[] $SWITCH_TABLE$com$eclipsesource$v8$debug$DebugHandler$DebugEvent() {
            int[] iArr = $SWITCH_TABLE$com$eclipsesource$v8$debug$DebugHandler$DebugEvent;
            if (iArr != null) {
                return iArr;
            }
            int[] iArr2 = new int[DebugEvent.values().length];
            iArr2[DebugEvent.AfterCompile.ordinal()] = 6;
            iArr2[DebugEvent.AsyncTaskEvent.ordinal()] = 9;
            iArr2[DebugEvent.BeforeCompile.ordinal()] = 5;
            iArr2[DebugEvent.Break.ordinal()] = 2;
            iArr2[DebugEvent.CompileError.ordinal()] = 7;
            iArr2[DebugEvent.Exception.ordinal()] = 3;
            iArr2[DebugEvent.NewFunction.ordinal()] = 4;
            iArr2[DebugEvent.PromiseError.ordinal()] = 8;
            iArr2[DebugEvent.Undefined.ordinal()] = 1;
            $SWITCH_TABLE$com$eclipsesource$v8$debug$DebugHandler$DebugEvent = iArr2;
            return iArr2;
        }

        private BreakpointHandler() {
        }

        /* synthetic */ BreakpointHandler(DebugHandler debugHandler, BreakpointHandler breakpointHandler) {
            this();
        }

        private EventData createDebugEvent(DebugEvent debugEvent, V8Object v8Object) {
            int i = $SWITCH_TABLE$com$eclipsesource$v8$debug$DebugHandler$DebugEvent()[debugEvent.ordinal()];
            return i != 2 ? i != 3 ? i != 5 ? i != 6 ? new EventData(v8Object) : new CompileEvent(v8Object) : new CompileEvent(v8Object) : new ExceptionEvent(v8Object) : new BreakEvent(v8Object);
        }

        private void invokeHandler(V8Array v8Array, int i, BreakHandler breakHandler) {
            ExecutionState executionState;
            Throwable th;
            V8Object v8Object;
            ExecutionState executionState2;
            V8Object v8Object2;
            V8Object v8Object3 = null;
            EventData eventData = null;
            try {
                V8Object object = v8Array.getObject(1);
                try {
                    v8Object2 = v8Array.getObject(2);
                } catch (Throwable th2) {
                    th = th2;
                    v8Object = null;
                    executionState = null;
                    v8Object2 = null;
                    executionState2 = null;
                    v8Object3 = object;
                    safeRelease(v8Object3);
                    safeRelease(v8Object2);
                    safeRelease(v8Object);
                    safeRelease(executionState2);
                    safeRelease(executionState);
                    throw th;
                }
                try {
                    v8Object = v8Array.getObject(3);
                } catch (Throwable th3) {
                    th = th3;
                    v8Object = null;
                    executionState = null;
                    executionState2 = executionState;
                    v8Object3 = object;
                    safeRelease(v8Object3);
                    safeRelease(v8Object2);
                    safeRelease(v8Object);
                    safeRelease(executionState2);
                    safeRelease(executionState);
                    throw th;
                }
                try {
                    executionState2 = new ExecutionState(object);
                    try {
                        DebugEvent debugEvent = DebugEvent.values()[i];
                        eventData = createDebugEvent(debugEvent, v8Object2);
                        breakHandler.onBreak(debugEvent, executionState2, eventData, v8Object);
                        safeRelease(object);
                        safeRelease(v8Object2);
                        safeRelease(v8Object);
                        safeRelease(executionState2);
                        safeRelease(eventData);
                    } catch (Throwable th4) {
                        th = th4;
                        executionState = eventData;
                        v8Object3 = object;
                        safeRelease(v8Object3);
                        safeRelease(v8Object2);
                        safeRelease(v8Object);
                        safeRelease(executionState2);
                        safeRelease(executionState);
                        throw th;
                    }
                } catch (Throwable th5) {
                    th = th5;
                    executionState = null;
                    executionState2 = executionState;
                    v8Object3 = object;
                    safeRelease(v8Object3);
                    safeRelease(v8Object2);
                    safeRelease(v8Object);
                    safeRelease(executionState2);
                    safeRelease(executionState);
                    throw th;
                }
            } catch (Throwable th6) {
                th = th6;
                v8Object = null;
                executionState = null;
                v8Object2 = null;
                executionState2 = null;
                safeRelease(v8Object3);
                safeRelease(v8Object2);
                safeRelease(v8Object);
                safeRelease(executionState2);
                safeRelease(executionState);
                throw th;
            }
        }

        private void safeRelease(Releasable releasable) {
            if (releasable != null) {
                releasable.release();
            }
        }

        @Override // com.eclipsesource.v8.JavaVoidCallback
        public void invoke(V8Object v8Object, V8Array v8Array) {
            if (!(v8Array == null || v8Array.isUndefined())) {
                int integer = v8Array.getInteger(0);
                for (BreakHandler breakHandler : DebugHandler.this.breakHandlers) {
                    invokeHandler(v8Array, integer, breakHandler);
                }
            }
        }
    }

    public enum DebugEvent {
        Undefined(0),
        Break(1),
        Exception(2),
        NewFunction(3),
        BeforeCompile(4),
        AfterCompile(5),
        CompileError(6),
        PromiseError(7),
        AsyncTaskEvent(8);
        
        int index;

        private DebugEvent(int i) {
            this.index = i;
        }
    }

    public DebugHandler(V8 v8) {
        this.runtime = v8;
        setupDebugObject(v8);
        setupBreakpointHandler();
    }

    private void setupBreakpointHandler() {
        V8Array v8Array;
        Throwable th;
        V8Function v8Function;
        this.debugObject.registerJavaMethod(new BreakpointHandler(this, null), DEBUG_BREAK_HANDLER);
        try {
            v8Function = (V8Function) this.debugObject.getObject(DEBUG_BREAK_HANDLER);
            try {
                v8Array = new V8Array(this.runtime);
            } catch (Throwable th2) {
                v8Array = null;
                th = th2;
                v8Function.close();
                v8Array.close();
                throw th;
            }
            try {
                v8Array.push((V8Value) v8Function);
                this.debugObject.executeFunction(SET_LISTENER, v8Array);
                if (v8Function != null && !v8Function.isReleased()) {
                    v8Function.close();
                }
                if (!v8Array.isReleased()) {
                    v8Array.close();
                }
            } catch (Throwable th3) {
                th = th3;
                v8Function.close();
                v8Array.close();
                throw th;
            }
        } catch (Throwable th4) {
            v8Array = null;
            th = th4;
            v8Function = null;
            if (v8Function != null && !v8Function.isReleased()) {
                v8Function.close();
            }
            if (v8Array != null && !v8Array.isReleased()) {
                v8Array.close();
            }
            throw th;
        }
    }

    private void setupDebugObject(V8 v8) {
        V8Object object = v8.getObject(DEBUG_OBJECT_NAME);
        try {
            this.debugObject = object.getObject(V8_DEBUG_OBJECT);
        } finally {
            object.close();
        }
    }

    public void addBreakHandler(BreakHandler breakHandler) {
        this.runtime.getLocker().checkThread();
        this.breakHandlers.add(breakHandler);
    }

    public void changeBreakPointCondition(int i, String str) {
        V8Array v8Array = new V8Array(this.runtime);
        v8Array.push(i);
        v8Array.push(str);
        try {
            this.debugObject.executeVoidFunction(CHANGE_BREAK_POINT_CONDITION, v8Array);
        } finally {
            v8Array.close();
        }
    }

    public void clearBreakPoint(int i) {
        V8Array v8Array = new V8Array(this.runtime);
        v8Array.push(i);
        try {
            this.debugObject.executeVoidFunction(CLEAR_BREAK_POINT, v8Array);
        } finally {
            v8Array.close();
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable, com.eclipsesource.v8.Releasable
    public void close() {
        this.debugObject.close();
    }

    public void disableAllBreakPoints() {
        this.debugObject.executeVoidFunction(DISABLE_ALL_BREAK_POINTS, null);
    }

    public void disableScriptBreakPoint(int i) {
        V8Array v8Array = new V8Array(this.runtime);
        v8Array.push(i);
        try {
            this.debugObject.executeVoidFunction(DISABLE_SCRIPT_BREAK_POINT, v8Array);
        } finally {
            v8Array.close();
        }
    }

    public void enableScriptBreakPoint(int i) {
        V8Array v8Array = new V8Array(this.runtime);
        v8Array.push(i);
        try {
            this.debugObject.executeVoidFunction(ENABLE_SCRIPT_BREAK_POINT, v8Array);
        } finally {
            v8Array.close();
        }
    }

    public ScriptBreakPoint getScriptBreakPoint(int i) {
        V8Array v8Array = new V8Array(this.runtime);
        v8Array.push(i);
        v8Array.push(false);
        V8Object v8Object = null;
        try {
            v8Object = this.debugObject.executeObjectFunction(FIND_SCRIPT_BREAK_POINT, v8Array);
            return new ScriptBreakPoint(v8Object);
        } finally {
            v8Array.close();
            if (v8Object != null) {
                v8Object.close();
            }
        }
    }

    public int getScriptBreakPointCount() {
        V8Array executeArrayFunction = this.debugObject.executeArrayFunction(SCRIPT_BREAK_POINTS, null);
        try {
            return executeArrayFunction.length();
        } finally {
            executeArrayFunction.close();
        }
    }

    /* JADX INFO: finally extract failed */
    public int[] getScriptBreakPointIDs() {
        V8Array executeArrayFunction = this.debugObject.executeArrayFunction(SCRIPT_BREAK_POINTS, null);
        try {
            int[] iArr = new int[executeArrayFunction.length()];
            for (int i = 0; i < executeArrayFunction.length(); i++) {
                V8Object object = executeArrayFunction.getObject(i);
                try {
                    iArr[i] = object.executeIntegerFunction(NUMBER, null);
                    object.close();
                } catch (Throwable th) {
                    object.close();
                    throw th;
                }
            }
            return iArr;
        } finally {
            executeArrayFunction.close();
        }
    }

    @Override // com.eclipsesource.v8.Releasable
    @Deprecated
    public void release() {
        close();
    }

    public void removeBreakHandler(BreakHandler breakHandler) {
        this.runtime.getLocker().checkThread();
        this.breakHandlers.remove(breakHandler);
    }

    public int setBreakpoint(V8Function v8Function) {
        V8Array v8Array = new V8Array(this.runtime);
        v8Array.push((V8Value) v8Function);
        try {
            return this.debugObject.executeIntegerFunction(SET_BREAK_POINT, v8Array);
        } finally {
            v8Array.close();
        }
    }

    public int setScriptBreakpoint(String str, int i) {
        V8Array v8Array = new V8Array(this.runtime);
        v8Array.push(str);
        v8Array.push(i);
        try {
            return this.debugObject.executeIntegerFunction(SET_SCRIPT_BREAK_POINT_BY_NAME, v8Array);
        } finally {
            v8Array.close();
        }
    }
}
