package com.eclipsesource.v8.utils;

import com.eclipsesource.v8.ReferenceHandler;
import com.eclipsesource.v8.V8;
import com.eclipsesource.v8.V8Value;
import java.util.ArrayList;
import java.util.Iterator;

public class MemoryManager {
    private MemoryManagerReferenceHandler memoryManagerReferenceHandler;
    private ArrayList<V8Value> references = new ArrayList<>();
    private boolean released = false;
    private boolean releasing = false;
    private V8 v8;

    private class MemoryManagerReferenceHandler implements ReferenceHandler {
        private MemoryManagerReferenceHandler() {
        }

        /* synthetic */ MemoryManagerReferenceHandler(MemoryManager memoryManager, MemoryManagerReferenceHandler memoryManagerReferenceHandler) {
            this();
        }

        @Override // com.eclipsesource.v8.ReferenceHandler
        public void v8HandleCreated(V8Value v8Value) {
            MemoryManager.this.references.add(v8Value);
        }

        @Override // com.eclipsesource.v8.ReferenceHandler
        public void v8HandleDisposed(V8Value v8Value) {
            if (!MemoryManager.this.releasing) {
                Iterator it = MemoryManager.this.references.iterator();
                while (it.hasNext()) {
                    if (it.next() == v8Value) {
                        it.remove();
                        return;
                    }
                }
            }
        }
    }

    public MemoryManager(V8 v82) {
        this.v8 = v82;
        MemoryManagerReferenceHandler memoryManagerReferenceHandler2 = new MemoryManagerReferenceHandler(this, null);
        this.memoryManagerReferenceHandler = memoryManagerReferenceHandler2;
        v82.addReferenceHandler(memoryManagerReferenceHandler2);
    }

    private void checkReleased() {
        if (this.released) {
            throw new IllegalStateException("Memory manager released");
        }
    }

    public int getObjectReferenceCount() {
        checkReleased();
        return this.references.size();
    }

    public boolean isReleased() {
        return this.released;
    }

    public void persist(V8Value v8Value) {
        this.v8.getLocker().checkThread();
        checkReleased();
        this.references.remove(v8Value);
    }

    /* JADX INFO: finally extract failed */
    public void release() {
        this.v8.getLocker().checkThread();
        if (!this.released) {
            this.releasing = true;
            try {
                Iterator<V8Value> it = this.references.iterator();
                while (it.hasNext()) {
                    it.next().close();
                }
                this.v8.removeReferenceHandler(this.memoryManagerReferenceHandler);
                this.references.clear();
                this.releasing = false;
                this.released = true;
            } catch (Throwable th) {
                this.releasing = false;
                throw th;
            }
        }
    }
}
