package net.lingala.zip4j.zip;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;
import java.util.ArrayList;
import java.util.HashMap;
import net.lingala.zip4j.exception.ZipException;
import net.lingala.zip4j.io.SplitOutputStream;
import net.lingala.zip4j.io.ZipOutputStream;
import net.lingala.zip4j.model.EndCentralDirRecord;
import net.lingala.zip4j.model.FileHeader;
import net.lingala.zip4j.model.ZipModel;
import net.lingala.zip4j.model.ZipParameters;
import net.lingala.zip4j.progress.ProgressMonitor;
import net.lingala.zip4j.util.ArchiveMaintainer;
import net.lingala.zip4j.util.CRCUtil;
import net.lingala.zip4j.util.InternalZipConstants;
import net.lingala.zip4j.util.Zip4jUtil;

public class ZipEngine {
    private ZipModel zipModel;

    public ZipEngine(ZipModel zipModel2) throws ZipException {
        if (zipModel2 != null) {
            this.zipModel = zipModel2;
            return;
        }
        throw new ZipException("zip model is null in ZipEngine constructor");
    }

    public void addFiles(final ArrayList arrayList, final ZipParameters zipParameters, final ProgressMonitor progressMonitor, boolean z) throws ZipException {
        if (arrayList == null || zipParameters == null) {
            throw new ZipException("one of the input parameters is null when adding files");
        } else if (arrayList.size() > 0) {
            progressMonitor.setCurrentOperation(0);
            progressMonitor.setState(1);
            progressMonitor.setResult(1);
            if (z) {
                progressMonitor.setTotalWork(calculateTotalWork(arrayList, zipParameters));
                progressMonitor.setFileName(((File) arrayList.get(0)).getAbsolutePath());
                new Thread(InternalZipConstants.THREAD_NAME) {
                    /* class net.lingala.zip4j.zip.ZipEngine.AnonymousClass1 */

                    public void run() {
                        try {
                            ZipEngine.this.initAddFiles(arrayList, zipParameters, progressMonitor);
                        } catch (ZipException unused) {
                        }
                    }
                }.start();
                return;
            }
            initAddFiles(arrayList, zipParameters, progressMonitor);
        } else {
            throw new ZipException("no files to add");
        }
    }

    /* JADX DEBUG: Multi-variable search result rejected for r3v0, resolved type: net.lingala.zip4j.io.ZipOutputStream */
    /* JADX DEBUG: Multi-variable search result rejected for r3v3, resolved type: net.lingala.zip4j.io.ZipOutputStream */
    /* JADX DEBUG: Multi-variable search result rejected for r3v5, resolved type: net.lingala.zip4j.io.ZipOutputStream */
    /* JADX DEBUG: Multi-variable search result rejected for r3v7, resolved type: net.lingala.zip4j.io.ZipOutputStream */
    /* JADX DEBUG: Multi-variable search result rejected for r3v8, resolved type: net.lingala.zip4j.io.ZipOutputStream */
    /* JADX WARN: Multi-variable type inference failed */
    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    /* JADX WARNING: Can't wrap try/catch for region: R(14:4|(1:6)|7|8|9|(3:11|12|(1:14)(2:15|16))|17|(3:20|(6:112|22|(2:24|25)|26|27|116)(5:29|(4:31|(2:35|(6:109|37|(2:39|40)|41|42|118))|44|(1:46))|47|(2:49|114)(2:50|(3:51|52|(2:54|(7:110|56|57|58|59|60|120)(1:62))(3:115|63|113)))|64)|18)|111|68|(2:70|71)|72|73|122) */
    /* JADX WARNING: Can't wrap try/catch for region: R(6:109|37|(2:39|40)|41|42|118) */
    /* JADX WARNING: Can't wrap try/catch for region: R(6:112|22|(2:24|25)|26|27|116) */
    /* JADX WARNING: Can't wrap try/catch for region: R(7:110|56|57|58|59|60|120) */
    /* JADX WARNING: Code restructure failed: missing block: B:117:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:119:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:121:?, code lost:
        return;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:123:?, code lost:
        return;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:26:0x0087 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:41:0x00df */
    /* JADX WARNING: Missing exception handler attribute for start block: B:59:0x0130 */
    /* JADX WARNING: Missing exception handler attribute for start block: B:72:0x0158 */
    /* JADX WARNING: Removed duplicated region for block: B:101:0x0186 A[SYNTHETIC, Splitter:B:101:0x0186] */
    /* JADX WARNING: Removed duplicated region for block: B:97:0x017f A[SYNTHETIC, Splitter:B:97:0x017f] */
    private void initAddFiles(ArrayList arrayList, ZipParameters zipParameters, ProgressMonitor progressMonitor) throws ZipException {
        Throwable th;
        ZipOutputStream zipOutputStream;
        FileInputStream fileInputStream;
        FileInputStream fileInputStream2;
        ZipException e;
        Exception e2;
        if (arrayList == null || zipParameters == null) {
            throw new ZipException("one of the input parameters is null when adding files");
        } else if (arrayList.size() > 0) {
            if (this.zipModel.getEndCentralDirRecord() == null) {
                this.zipModel.setEndCentralDirRecord(createEndOfCentralDirectoryRecord());
            }
            FileInputStream fileInputStream3 = null;
            try {
                checkParameters(zipParameters);
                removeFilesIfExists(arrayList, zipParameters, progressMonitor);
                boolean checkFileExists = Zip4jUtil.checkFileExists(this.zipModel.getZipFile());
                SplitOutputStream splitOutputStream = new SplitOutputStream(new File(this.zipModel.getZipFile()), this.zipModel.getSplitLength());
                ZipOutputStream zipOutputStream2 = new ZipOutputStream(splitOutputStream, this.zipModel);
                if (checkFileExists) {
                    try {
                        if (this.zipModel.getEndCentralDirRecord() != null) {
                            splitOutputStream.seek(this.zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir());
                        } else {
                            throw new ZipException("invalid end of central directory record");
                        }
                    } catch (ZipException e3) {
                        e = e3;
                        progressMonitor.endProgressMonitorError(e);
                        throw e;
                    } catch (Exception e4) {
                        e2 = e4;
                        fileInputStream = null;
                        fileInputStream3 = zipOutputStream2;
                        progressMonitor.endProgressMonitorError(e2);
                        throw new ZipException(e2);
                    } catch (Throwable th2) {
                        th = th2;
                        zipOutputStream = zipOutputStream2;
                        if (fileInputStream3 != null) {
                            try {
                                fileInputStream3.close();
                            } catch (IOException unused) {
                            }
                        }
                        if (zipOutputStream != 0) {
                            try {
                                zipOutputStream.close();
                            } catch (IOException unused2) {
                            }
                        }
                        throw th;
                    }
                }
                byte[] bArr = new byte[4096];
                for (int i = 0; i < arrayList.size(); i++) {
                    if (progressMonitor.isCancelAllTasks()) {
                        progressMonitor.setResult(3);
                        progressMonitor.setState(0);
                        if (fileInputStream3 != null) {
                            fileInputStream3.close();
                        }
                        zipOutputStream2.close();
                        return;
                    }
                    ZipParameters zipParameters2 = (ZipParameters) zipParameters.clone();
                    progressMonitor.setFileName(((File) arrayList.get(i)).getAbsolutePath());
                    if (!((File) arrayList.get(i)).isDirectory()) {
                        if (zipParameters2.isEncryptFiles() && zipParameters2.getEncryptionMethod() == 0) {
                            progressMonitor.setCurrentOperation(3);
                            zipParameters2.setSourceFileCRC((int) CRCUtil.computeFileCRC(((File) arrayList.get(i)).getAbsolutePath(), progressMonitor));
                            progressMonitor.setCurrentOperation(0);
                            if (progressMonitor.isCancelAllTasks()) {
                                progressMonitor.setResult(3);
                                progressMonitor.setState(0);
                                if (fileInputStream3 != null) {
                                    fileInputStream3.close();
                                }
                                zipOutputStream2.close();
                                return;
                            }
                        }
                        if (Zip4jUtil.getFileLengh((File) arrayList.get(i)) == 0) {
                            zipParameters2.setCompressionMethod(0);
                        }
                    }
                    zipOutputStream2.putNextEntry((File) arrayList.get(i), zipParameters2);
                    if (((File) arrayList.get(i)).isDirectory()) {
                        zipOutputStream2.closeEntry();
                    } else {
                        fileInputStream = new FileInputStream((File) arrayList.get(i));
                        while (true) {
                            try {
                                int read = fileInputStream.read(bArr);
                                if (read == -1) {
                                    zipOutputStream2.closeEntry();
                                    fileInputStream.close();
                                    fileInputStream3 = fileInputStream;
                                    break;
                                } else if (progressMonitor.isCancelAllTasks()) {
                                    progressMonitor.setResult(3);
                                    progressMonitor.setState(0);
                                    fileInputStream.close();
                                    zipOutputStream2.close();
                                    return;
                                } else {
                                    zipOutputStream2.write(bArr, 0, read);
                                    progressMonitor.updateWorkCompleted((long) read);
                                }
                            } catch (ZipException e5) {
                                e = e5;
                                progressMonitor.endProgressMonitorError(e);
                                throw e;
                            } catch (Exception e6) {
                                e2 = e6;
                                fileInputStream3 = zipOutputStream2;
                                progressMonitor.endProgressMonitorError(e2);
                                throw new ZipException(e2);
                            } catch (Throwable th3) {
                                th = th3;
                                fileInputStream2 = zipOutputStream2;
                                fileInputStream3 = fileInputStream;
                                zipOutputStream = fileInputStream2;
                                if (fileInputStream3 != null) {
                                }
                                if (zipOutputStream != 0) {
                                }
                                throw th;
                            }
                        }
                    }
                }
                zipOutputStream2.finish();
                progressMonitor.endProgressMonitorSuccess();
                if (fileInputStream3 != null) {
                    fileInputStream3.close();
                }
                zipOutputStream2.close();
            } catch (ZipException e7) {
                e = e7;
                progressMonitor.endProgressMonitorError(e);
                throw e;
            } catch (Exception e8) {
                e2 = e8;
                fileInputStream = null;
                progressMonitor.endProgressMonitorError(e2);
                throw new ZipException(e2);
            } catch (Throwable th4) {
                th = th4;
                fileInputStream2 = fileInputStream3;
                fileInputStream3 = fileInputStream;
                zipOutputStream = fileInputStream2;
                if (fileInputStream3 != null) {
                }
                if (zipOutputStream != 0) {
                }
                throw th;
            }
        } else {
            throw new ZipException("no files to add");
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:36:0x009a A[SYNTHETIC, Splitter:B:36:0x009a] */
    public void addStreamToZip(InputStream inputStream, ZipParameters zipParameters) throws ZipException {
        Throwable th;
        Exception e;
        ZipOutputStream zipOutputStream;
        if (inputStream == null || zipParameters == null) {
            throw new ZipException("one of the input parameters is null, cannot add stream to zip");
        }
        ZipOutputStream zipOutputStream2 = null;
        try {
            checkParameters(zipParameters);
            boolean checkFileExists = Zip4jUtil.checkFileExists(this.zipModel.getZipFile());
            SplitOutputStream splitOutputStream = new SplitOutputStream(new File(this.zipModel.getZipFile()), this.zipModel.getSplitLength());
            zipOutputStream = new ZipOutputStream(splitOutputStream, this.zipModel);
            if (checkFileExists) {
                if (this.zipModel.getEndCentralDirRecord() != null) {
                    splitOutputStream.seek(this.zipModel.getEndCentralDirRecord().getOffsetOfStartOfCentralDir());
                } else {
                    throw new ZipException("invalid end of central directory record");
                }
            }
            byte[] bArr = new byte[4096];
            zipOutputStream.putNextEntry(null, zipParameters);
            if (!zipParameters.getFileNameInZip().endsWith(InternalZipConstants.ZIP_FILE_SEPARATOR) && !zipParameters.getFileNameInZip().endsWith("\\")) {
                while (true) {
                    int read = inputStream.read(bArr);
                    if (read == -1) {
                        break;
                    }
                    zipOutputStream.write(bArr, 0, read);
                }
            }
            zipOutputStream.closeEntry();
            zipOutputStream.finish();
            try {
                zipOutputStream.close();
            } catch (IOException unused) {
            }
        } catch (ZipException e2) {
            throw e2;
        } catch (Exception e3) {
            e = e3;
            throw new ZipException(e);
        } catch (ZipException e4) {
            throw e4;
        } catch (Exception e5) {
            e = e5;
            zipOutputStream2 = zipOutputStream;
            throw new ZipException(e);
        } catch (Throwable th2) {
            th = th2;
            if (zipOutputStream2 != null) {
            }
            throw th;
        }
    }

    public void addFolderToZip(File file, ZipParameters zipParameters, ProgressMonitor progressMonitor, boolean z) throws ZipException {
        String str;
        if (file == null || zipParameters == null) {
            throw new ZipException("one of the input parameters is null, cannot add folder to zip");
        } else if (!Zip4jUtil.checkFileExists(file.getAbsolutePath())) {
            throw new ZipException("input folder does not exist");
        } else if (!file.isDirectory()) {
            throw new ZipException("input file is not a folder, user addFileToZip method to add files");
        } else if (Zip4jUtil.checkFileReadAccess(file.getAbsolutePath())) {
            if (zipParameters.isIncludeRootFolder()) {
                str = "";
                if (file.getAbsolutePath() != null) {
                    if (file.getAbsoluteFile().getParentFile() != null) {
                        str = file.getAbsoluteFile().getParentFile().getAbsolutePath();
                    }
                } else if (file.getParentFile() != null) {
                    str = file.getParentFile().getAbsolutePath();
                }
            } else {
                str = file.getAbsolutePath();
            }
            zipParameters.setDefaultFolderPath(str);
            ArrayList filesInDirectoryRec = Zip4jUtil.getFilesInDirectoryRec(file, zipParameters.isReadHiddenFiles());
            if (zipParameters.isIncludeRootFolder()) {
                if (filesInDirectoryRec == null) {
                    filesInDirectoryRec = new ArrayList();
                }
                filesInDirectoryRec.add(file);
            }
            addFiles(filesInDirectoryRec, zipParameters, progressMonitor, z);
        } else {
            throw new ZipException("cannot read folder: " + file.getAbsolutePath());
        }
    }

    private void checkParameters(ZipParameters zipParameters) throws ZipException {
        if (zipParameters == null) {
            throw new ZipException("cannot validate zip parameters");
        } else if (zipParameters.getCompressionMethod() != 0 && zipParameters.getCompressionMethod() != 8) {
            throw new ZipException("unsupported compression type");
        } else if (zipParameters.getCompressionMethod() == 8 && zipParameters.getCompressionLevel() < 0 && zipParameters.getCompressionLevel() > 9) {
            throw new ZipException("invalid compression level. compression level dor deflate should be in the range of 0-9");
        } else if (!zipParameters.isEncryptFiles()) {
            zipParameters.setAesKeyStrength(-1);
            zipParameters.setEncryptionMethod(-1);
        } else if (zipParameters.getEncryptionMethod() != 0 && zipParameters.getEncryptionMethod() != 99) {
            throw new ZipException("unsupported encryption method");
        } else if (zipParameters.getPassword() == null || zipParameters.getPassword().length <= 0) {
            throw new ZipException("input password is empty or null");
        }
    }

    private void removeFilesIfExists(ArrayList arrayList, ZipParameters zipParameters, ProgressMonitor progressMonitor) throws ZipException {
        ZipModel zipModel2 = this.zipModel;
        if (zipModel2 != null && zipModel2.getCentralDirectory() != null && this.zipModel.getCentralDirectory().getFileHeaders() != null && this.zipModel.getCentralDirectory().getFileHeaders().size() > 0) {
            RandomAccessFile randomAccessFile = null;
            for (int i = 0; i < arrayList.size(); i++) {
                try {
                    FileHeader fileHeader = Zip4jUtil.getFileHeader(this.zipModel, Zip4jUtil.getRelativeFileName(((File) arrayList.get(i)).getAbsolutePath(), zipParameters.getRootFolderInZip(), zipParameters.getDefaultFolderPath()));
                    if (fileHeader != null) {
                        if (randomAccessFile != null) {
                            randomAccessFile.close();
                            randomAccessFile = null;
                        }
                        ArchiveMaintainer archiveMaintainer = new ArchiveMaintainer();
                        progressMonitor.setCurrentOperation(2);
                        HashMap initRemoveZipFile = archiveMaintainer.initRemoveZipFile(this.zipModel, fileHeader, progressMonitor);
                        if (progressMonitor.isCancelAllTasks()) {
                            progressMonitor.setResult(3);
                            progressMonitor.setState(0);
                            if (randomAccessFile != null) {
                                try {
                                    randomAccessFile.close();
                                    return;
                                } catch (IOException unused) {
                                    return;
                                }
                            } else {
                                return;
                            }
                        } else {
                            progressMonitor.setCurrentOperation(0);
                            if (randomAccessFile == null) {
                                randomAccessFile = prepareFileOutputStream();
                                if (!(initRemoveZipFile == null || initRemoveZipFile.get(InternalZipConstants.OFFSET_CENTRAL_DIR) == null)) {
                                    try {
                                        long parseLong = Long.parseLong((String) initRemoveZipFile.get(InternalZipConstants.OFFSET_CENTRAL_DIR));
                                        if (parseLong >= 0) {
                                            randomAccessFile.seek(parseLong);
                                        }
                                    } catch (NumberFormatException unused2) {
                                        throw new ZipException("NumberFormatException while parsing offset central directory. Cannot update already existing file header");
                                    } catch (Exception unused3) {
                                        throw new ZipException("Error while parsing offset central directory. Cannot update already existing file header");
                                    }
                                }
                            }
                        }
                    }
                } catch (IOException e) {
                    throw new ZipException(e);
                } catch (Throwable th) {
                    if (randomAccessFile != null) {
                        try {
                            randomAccessFile.close();
                        } catch (IOException unused4) {
                        }
                    }
                    throw th;
                }
            }
            if (randomAccessFile != null) {
                try {
                    randomAccessFile.close();
                } catch (IOException unused5) {
                }
            }
        }
    }

    private RandomAccessFile prepareFileOutputStream() throws ZipException {
        String zipFile = this.zipModel.getZipFile();
        if (Zip4jUtil.isStringNotNullAndNotEmpty(zipFile)) {
            try {
                File file = new File(zipFile);
                if (!file.getParentFile().exists()) {
                    file.getParentFile().mkdirs();
                }
                return new RandomAccessFile(file, InternalZipConstants.WRITE_MODE);
            } catch (FileNotFoundException e) {
                throw new ZipException(e);
            }
        } else {
            throw new ZipException("invalid output path");
        }
    }

    private EndCentralDirRecord createEndOfCentralDirectoryRecord() {
        EndCentralDirRecord endCentralDirRecord = new EndCentralDirRecord();
        endCentralDirRecord.setSignature(InternalZipConstants.ENDSIG);
        endCentralDirRecord.setNoOfThisDisk(0);
        endCentralDirRecord.setTotNoOfEntriesInCentralDir(0);
        endCentralDirRecord.setTotNoOfEntriesInCentralDirOnThisDisk(0);
        endCentralDirRecord.setOffsetOfStartOfCentralDir(0);
        return endCentralDirRecord;
    }

    private long calculateTotalWork(ArrayList arrayList, ZipParameters zipParameters) throws ZipException {
        long j;
        FileHeader fileHeader;
        if (arrayList != null) {
            long j2 = 0;
            for (int i = 0; i < arrayList.size(); i++) {
                if ((arrayList.get(i) instanceof File) && ((File) arrayList.get(i)).exists()) {
                    if (!zipParameters.isEncryptFiles() || zipParameters.getEncryptionMethod() != 0) {
                        j = Zip4jUtil.getFileLengh((File) arrayList.get(i));
                    } else {
                        j = Zip4jUtil.getFileLengh((File) arrayList.get(i)) * 2;
                    }
                    j2 += j;
                    if (!(this.zipModel.getCentralDirectory() == null || this.zipModel.getCentralDirectory().getFileHeaders() == null || this.zipModel.getCentralDirectory().getFileHeaders().size() <= 0 || (fileHeader = Zip4jUtil.getFileHeader(this.zipModel, Zip4jUtil.getRelativeFileName(((File) arrayList.get(i)).getAbsolutePath(), zipParameters.getRootFolderInZip(), zipParameters.getDefaultFolderPath()))) == null)) {
                        j2 += Zip4jUtil.getFileLengh(new File(this.zipModel.getZipFile())) - fileHeader.getCompressedSize();
                    }
                }
            }
            return j2;
        }
        throw new ZipException("file list is null, cannot calculate total work");
    }
}
